
# Copyright 2013 Cisco Systems, Inc.
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

""" This is auto-generated module containing Constants information. """

class NamingId:
	METHOD = "method"
	METHOD_SET = "methodSet"
	AAA_AUTH_REALM = "aaaAuthRealm"
	AAA_AUTH_REALM_FSM = "aaaAuthRealmFsm"
	AAA_AUTH_REALM_FSM_STAGE = "aaaAuthRealmFsmStage"
	AAA_CHANGE_SELF_PASSWORD = "aaaChangeSelfPassword"
	AAA_CHECK_COMPUTE_AUTH_TOKEN = "aaaCheckComputeAuthToken"
	AAA_CHECK_COMPUTE_EXT_ACCESS = "aaaCheckComputeExtAccess"
	AAA_CIMC_SESSION = "aaaCimcSession"
	AAA_CONSOLE_AUTH = "aaaConsoleAuth"
	AAA_DEFAULT_AUTH = "aaaDefaultAuth"
	AAA_DOMAIN = "aaaDomain"
	AAA_DOMAIN_AUTH = "aaaDomainAuth"
	AAA_EP_AUTH_PROFILE = "aaaEpAuthProfile"
	AAA_EP_FSM = "aaaEpFsm"
	AAA_EP_FSM_STAGE = "aaaEpFsmStage"
	AAA_EP_FSM_TASK = "aaaEpFsmTask"
	AAA_EP_LOGIN = "aaaEpLogin"
	AAA_EP_USER = "aaaEpUser"
	AAA_EXT_MGMT_CUT_THRU_TKN = "aaaExtMgmtCutThruTkn"
	AAA_GET_AUTH_TOKEN_CLIENT = "aaaGetAuthTokenClient"
	AAA_GET_KVMLAUNCH_URL = "aaaGetKVMLaunchUrl"
	AAA_GET_NCOMPUTE_AUTH_TOKEN_BY_DN = "aaaGetNComputeAuthTokenByDn"
	AAA_KEEP_ALIVE = "aaaKeepAlive"
	AAA_LDAP_EP = "aaaLdapEp"
	AAA_LDAP_EP_FSM = "aaaLdapEpFsm"
	AAA_LDAP_EP_FSM_STAGE = "aaaLdapEpFsmStage"
	AAA_LDAP_GROUP = "aaaLdapGroup"
	AAA_LDAP_GROUP_RULE = "aaaLdapGroupRule"
	AAA_LDAP_PROVIDER = "aaaLdapProvider"
	AAA_LOCALE = "aaaLocale"
	AAA_LOG = "aaaLog"
	AAA_LOGIN = "aaaLogin"
	AAA_LOGOUT = "aaaLogout"
	AAA_MOD_LR = "aaaModLR"
	AAA_ORG = "aaaOrg"
	AAA_PRE_LOGIN_BANNER = "aaaPreLoginBanner"
	AAA_PROVIDER_GROUP = "aaaProviderGroup"
	AAA_PROVIDER_REF = "aaaProviderRef"
	AAA_PWD_PROFILE = "aaaPwdProfile"
	AAA_RADIUS_EP = "aaaRadiusEp"
	AAA_RADIUS_EP_FSM = "aaaRadiusEpFsm"
	AAA_RADIUS_EP_FSM_STAGE = "aaaRadiusEpFsmStage"
	AAA_RADIUS_PROVIDER = "aaaRadiusProvider"
	AAA_REALM_FSM = "aaaRealmFsm"
	AAA_REALM_FSM_STAGE = "aaaRealmFsmStage"
	AAA_REALM_FSM_TASK = "aaaRealmFsmTask"
	AAA_REFRESH = "aaaRefresh"
	AAA_REMOTE_USER = "aaaRemoteUser"
	AAA_ROLE = "aaaRole"
	AAA_SESSION = "aaaSession"
	AAA_SESSION_INFO = "aaaSessionInfo"
	AAA_SESSION_INFO_TABLE = "aaaSessionInfoTable"
	AAA_SESSION_LR = "aaaSessionLR"
	AAA_SHELL_LOGIN = "aaaShellLogin"
	AAA_SSH_AUTH = "aaaSshAuth"
	AAA_TACACS_PLUS_EP = "aaaTacacsPlusEp"
	AAA_TACACS_PLUS_EP_FSM = "aaaTacacsPlusEpFsm"
	AAA_TACACS_PLUS_EP_FSM_STAGE = "aaaTacacsPlusEpFsmStage"
	AAA_TACACS_PLUS_PROVIDER = "aaaTacacsPlusProvider"
	AAA_TOKEN_LOGIN = "aaaTokenLogin"
	AAA_TOKEN_REFRESH = "aaaTokenRefresh"
	AAA_USER = "aaaUser"
	AAA_USER_DATA = "aaaUserData"
	AAA_USER_EP = "aaaUserEp"
	AAA_USER_EP_FSM = "aaaUserEpFsm"
	AAA_USER_EP_FSM_STAGE = "aaaUserEpFsmStage"
	AAA_USER_EP_FSM_TASK = "aaaUserEpFsmTask"
	AAA_USER_LOCALE = "aaaUserLocale"
	AAA_USER_ROLE = "aaaUserRole"
	AAA_WEB_LOGIN = "aaaWebLogin"
	ADAPTOR_CAP_QUAL = "adaptorCapQual"
	ADAPTOR_CAP_SPEC = "adaptorCapSpec"
	ADAPTOR_DIAG_CAP = "adaptorDiagCap"
	ADAPTOR_ETH_COMP_QUEUE_PROFILE = "adaptorEthCompQueueProfile"
	ADAPTOR_ETH_FAILOVER_PROFILE = "adaptorEthFailoverProfile"
	ADAPTOR_ETH_INTERRUPT_PROFILE = "adaptorEthInterruptProfile"
	ADAPTOR_ETH_OFFLOAD_PROFILE = "adaptorEthOffloadProfile"
	ADAPTOR_ETH_PORT_BY_SIZE_LARGE_STATS = "adaptorEthPortBySizeLargeStats"
	ADAPTOR_ETH_PORT_BY_SIZE_LARGE_STATS_HIST = "adaptorEthPortBySizeLargeStatsHist"
	ADAPTOR_ETH_PORT_BY_SIZE_SMALL_STATS = "adaptorEthPortBySizeSmallStats"
	ADAPTOR_ETH_PORT_BY_SIZE_SMALL_STATS_HIST = "adaptorEthPortBySizeSmallStatsHist"
	ADAPTOR_ETH_PORT_ERR_STATS = "adaptorEthPortErrStats"
	ADAPTOR_ETH_PORT_ERR_STATS_HIST = "adaptorEthPortErrStatsHist"
	ADAPTOR_ETH_PORT_MCAST_STATS = "adaptorEthPortMcastStats"
	ADAPTOR_ETH_PORT_MCAST_STATS_HIST = "adaptorEthPortMcastStatsHist"
	ADAPTOR_ETH_PORT_OUTSIZED_STATS = "adaptorEthPortOutsizedStats"
	ADAPTOR_ETH_PORT_OUTSIZED_STATS_HIST = "adaptorEthPortOutsizedStatsHist"
	ADAPTOR_ETH_PORT_STATS = "adaptorEthPortStats"
	ADAPTOR_ETH_PORT_STATS_HIST = "adaptorEthPortStatsHist"
	ADAPTOR_ETH_RECV_QUEUE_PROFILE = "adaptorEthRecvQueueProfile"
	ADAPTOR_ETH_WORK_QUEUE_PROFILE = "adaptorEthWorkQueueProfile"
	ADAPTOR_ETHER_IF_STATS = "adaptorEtherIfStats"
	ADAPTOR_ETHER_IF_STATS_HIST = "adaptorEtherIfStatsHist"
	ADAPTOR_EXT_ETH_IF = "adaptorExtEthIf"
	ADAPTOR_EXT_ETH_IF_FSM = "adaptorExtEthIfFsm"
	ADAPTOR_EXT_ETH_IF_FSM_STAGE = "adaptorExtEthIfFsmStage"
	ADAPTOR_EXT_ETH_IF_FSM_TASK = "adaptorExtEthIfFsmTask"
	ADAPTOR_EXT_ETH_IF_PC = "adaptorExtEthIfPc"
	ADAPTOR_EXT_ETH_IF_PC_EP = "adaptorExtEthIfPcEp"
	ADAPTOR_EXT_IP_V6_RSS_HASH_PROFILE = "adaptorExtIpV6RssHashProfile"
	ADAPTOR_FAMILY_TYPE_DEF = "adaptorFamilyTypeDef"
	ADAPTOR_FC_CDB_WORK_QUEUE_PROFILE = "adaptorFcCdbWorkQueueProfile"
	ADAPTOR_FC_ERROR_RECOVERY_PROFILE = "adaptorFcErrorRecoveryProfile"
	ADAPTOR_FC_IF_EVENT_STATS = "adaptorFcIfEventStats"
	ADAPTOR_FC_IF_EVENT_STATS_HIST = "adaptorFcIfEventStatsHist"
	ADAPTOR_FC_IF_FC4_STATS = "adaptorFcIfFC4Stats"
	ADAPTOR_FC_IF_FC4_STATS_HIST = "adaptorFcIfFC4StatsHist"
	ADAPTOR_FC_IF_FRAME_STATS = "adaptorFcIfFrameStats"
	ADAPTOR_FC_IF_FRAME_STATS_HIST = "adaptorFcIfFrameStatsHist"
	ADAPTOR_FC_INTERRUPT_PROFILE = "adaptorFcInterruptProfile"
	ADAPTOR_FC_OEIF = "adaptorFcOEIf"
	ADAPTOR_FC_PORT_FLOGI_PROFILE = "adaptorFcPortFLogiProfile"
	ADAPTOR_FC_PORT_PLOGI_PROFILE = "adaptorFcPortPLogiProfile"
	ADAPTOR_FC_PORT_PROFILE = "adaptorFcPortProfile"
	ADAPTOR_FC_PORT_STATS = "adaptorFcPortStats"
	ADAPTOR_FC_PORT_STATS_HIST = "adaptorFcPortStatsHist"
	ADAPTOR_FC_RECV_QUEUE_PROFILE = "adaptorFcRecvQueueProfile"
	ADAPTOR_FC_WORK_QUEUE_PROFILE = "adaptorFcWorkQueueProfile"
	ADAPTOR_FRU_CAP_PROVIDER = "adaptorFruCapProvider"
	ADAPTOR_FRU_CAP_REF = "adaptorFruCapRef"
	ADAPTOR_FW_CAP_PROVIDER = "adaptorFwCapProvider"
	ADAPTOR_HOST_ETH_IF = "adaptorHostEthIf"
	ADAPTOR_HOST_ETH_IF_FSM = "adaptorHostEthIfFsm"
	ADAPTOR_HOST_ETH_IF_FSM_STAGE = "adaptorHostEthIfFsmStage"
	ADAPTOR_HOST_ETH_IF_FSM_TASK = "adaptorHostEthIfFsmTask"
	ADAPTOR_HOST_ETH_IF_PROFILE = "adaptorHostEthIfProfile"
	ADAPTOR_HOST_FC_IF = "adaptorHostFcIf"
	ADAPTOR_HOST_FC_IF_FSM = "adaptorHostFcIfFsm"
	ADAPTOR_HOST_FC_IF_FSM_STAGE = "adaptorHostFcIfFsmStage"
	ADAPTOR_HOST_FC_IF_FSM_TASK = "adaptorHostFcIfFsmTask"
	ADAPTOR_HOST_FC_IF_PROFILE = "adaptorHostFcIfProfile"
	ADAPTOR_HOST_ISCSI_IF = "adaptorHostIscsiIf"
	ADAPTOR_HOST_ISCSI_IF_PROFILE = "adaptorHostIscsiIfProfile"
	ADAPTOR_HOST_MGMT_CAP = "adaptorHostMgmtCap"
	ADAPTOR_HOST_SERVICE_ETH_IF = "adaptorHostServiceEthIf"
	ADAPTOR_HOSTETH_HW_ADDR_CAP = "adaptorHostethHwAddrCap"
	ADAPTOR_HOSTFC_HW_ADDR_CAP = "adaptorHostfcHwAddrCap"
	ADAPTOR_ISCSI_CAP = "adaptorIScsiCap"
	ADAPTOR_IP_V4_RSS_HASH_PROFILE = "adaptorIpV4RssHashProfile"
	ADAPTOR_IP_V6_RSS_HASH_PROFILE = "adaptorIpV6RssHashProfile"
	ADAPTOR_ISCSI_AUTH = "adaptorIscsiAuth"
	ADAPTOR_ISCSI_PROT = "adaptorIscsiProt"
	ADAPTOR_ISCSI_TARGET_IF = "adaptorIscsiTargetIf"
	ADAPTOR_LAN_CAP = "adaptorLanCap"
	ADAPTOR_LLDP_CAP = "adaptorLldpCap"
	ADAPTOR_MENLO_BASE_ERROR_STATS = "adaptorMenloBaseErrorStats"
	ADAPTOR_MENLO_BASE_ERROR_STATS_HIST = "adaptorMenloBaseErrorStatsHist"
	ADAPTOR_MENLO_DCE_PORT_STATS = "adaptorMenloDcePortStats"
	ADAPTOR_MENLO_DCE_PORT_STATS_HIST = "adaptorMenloDcePortStatsHist"
	ADAPTOR_MENLO_ETH_ERROR_STATS = "adaptorMenloEthErrorStats"
	ADAPTOR_MENLO_ETH_ERROR_STATS_HIST = "adaptorMenloEthErrorStatsHist"
	ADAPTOR_MENLO_ETH_STATS = "adaptorMenloEthStats"
	ADAPTOR_MENLO_ETH_STATS_HIST = "adaptorMenloEthStatsHist"
	ADAPTOR_MENLO_FC_ERROR_STATS = "adaptorMenloFcErrorStats"
	ADAPTOR_MENLO_FC_ERROR_STATS_HIST = "adaptorMenloFcErrorStatsHist"
	ADAPTOR_MENLO_FC_STATS = "adaptorMenloFcStats"
	ADAPTOR_MENLO_FC_STATS_HIST = "adaptorMenloFcStatsHist"
	ADAPTOR_MENLO_HOST_PORT_STATS = "adaptorMenloHostPortStats"
	ADAPTOR_MENLO_HOST_PORT_STATS_HIST = "adaptorMenloHostPortStatsHist"
	ADAPTOR_MENLO_MCPU_ERROR_STATS = "adaptorMenloMcpuErrorStats"
	ADAPTOR_MENLO_MCPU_ERROR_STATS_HIST = "adaptorMenloMcpuErrorStatsHist"
	ADAPTOR_MENLO_MCPU_STATS = "adaptorMenloMcpuStats"
	ADAPTOR_MENLO_MCPU_STATS_HIST = "adaptorMenloMcpuStatsHist"
	ADAPTOR_MENLO_NET_EG_STATS = "adaptorMenloNetEgStats"
	ADAPTOR_MENLO_NET_EG_STATS_HIST = "adaptorMenloNetEgStatsHist"
	ADAPTOR_MENLO_NET_IN_STATS = "adaptorMenloNetInStats"
	ADAPTOR_MENLO_NET_IN_STATS_HIST = "adaptorMenloNetInStatsHist"
	ADAPTOR_MENLO_QERROR_STATS = "adaptorMenloQErrorStats"
	ADAPTOR_MENLO_QERROR_STATS_HIST = "adaptorMenloQErrorStatsHist"
	ADAPTOR_MENLO_QSTATS = "adaptorMenloQStats"
	ADAPTOR_MENLO_QSTATS_HIST = "adaptorMenloQStatsHist"
	ADAPTOR_NW_MGMT_CAP = "adaptorNwMgmtCap"
	ADAPTOR_PROTOCOL_PROFILE = "adaptorProtocolProfile"
	ADAPTOR_QUAL = "adaptorQual"
	ADAPTOR_RSS_PROFILE = "adaptorRssProfile"
	ADAPTOR_SAN_CAP = "adaptorSanCap"
	ADAPTOR_UNIT = "adaptorUnit"
	ADAPTOR_UNIT_ASSOC_CTX = "adaptorUnitAssocCtx"
	ADAPTOR_UNIT_EXTN = "adaptorUnitExtn"
	ADAPTOR_UPLINK_HW_ADDR_CAP = "adaptorUplinkHwAddrCap"
	ADAPTOR_USNIC_CONN_DEF = "adaptorUsnicConnDef"
	ADAPTOR_VLAN = "adaptorVlan"
	ADAPTOR_VNIC_STATS = "adaptorVnicStats"
	ADAPTOR_VNIC_STATS_HIST = "adaptorVnicStatsHist"
	ADAPTOR_VSAN = "adaptorVsan"
	ALLBITS_FILTER = "allbitsFilter"
	AND_FILTER = "andFilter"
	ANYBIT_FILTER = "anybitFilter"
	APE_BOOT_PNU_OS = "apeBootPnuOs"
	APE_CONFIGURE_CMCLIF = "apeConfigureCMCLIF"
	APE_CONTROLLER_CHASSIS = "apeControllerChassis"
	APE_CONTROLLER_EEPROM = "apeControllerEeprom"
	APE_CONTROLLER_MANAGER = "apeControllerManager"
	APE_CREATE_HVVNIC = "apeCreateHVVnic"
	APE_CREATE_SFISH = "apeCreateSfish"
	APE_CREATE_VMVNIC = "apeCreateVMVnic"
	APE_DCOS_AG_MANAGER = "apeDcosAgManager"
	APE_DELETE_HVVNIC = "apeDeleteHVVnic"
	APE_DELETE_SFISH = "apeDeleteSfish"
	APE_DELETE_VMVNIC = "apeDeleteVMVnic"
	APE_FRU = "apeFru"
	APE_GET_ADAPTOR_CONNECTIVITY = "apeGetAdaptorConnectivity"
	APE_GET_PNU_OSINVENTORY = "apeGetPnuOSInventory"
	APE_GET_SWITCH_APE_FRU = "apeGetSwitchApeFru"
	APE_HOST_AGENT = "apeHostAgent"
	APE_INJECT_STIMULI = "apeInjectStimuli"
	APE_INSERT_NEW_CHASSIS = "apeInsertNewChassis"
	APE_INSERT_NEW_FEX = "apeInsertNewFex"
	APE_INSERT_NEW_RACK = "apeInsertNewRack"
	APE_ISSUE_CHASSIS_ID = "apeIssueChassisId"
	APE_ISSUE_FEX_ID = "apeIssueFexId"
	APE_ISSUE_RACK_ID = "apeIssueRackId"
	APE_LANBOOT = "apeLANBoot"
	APE_LOCAL_DISK_BOOT = "apeLocalDiskBoot"
	APE_MANAGER = "apeManager"
	APE_MC = "apeMc"
	APE_MC_GET = "apeMcGet"
	APE_MC_GET_BIOS_TOKENS = "apeMcGetBiosTokens"
	APE_MC_GET_PARAM = "apeMcGetParam"
	APE_MC_GET_SMBIOS = "apeMcGetSmbios"
	APE_MC_SET = "apeMcSet"
	APE_MC_TABLE = "apeMcTable"
	APE_MENLO = "apeMenlo"
	APE_MENLO_VNIC = "apeMenloVnic"
	APE_MENLO_VNIC_STATS = "apeMenloVnicStats"
	APE_MUX_OFFLINE = "apeMuxOffline"
	APE_NIC_AG_MANAGER = "apeNicAgManager"
	APE_PALO = "apePalo"
	APE_PALO_VNIC = "apePaloVnic"
	APE_PALO_VNIC_STATS = "apePaloVnicStats"
	APE_PARAM = "apeParam"
	APE_READING = "apeReading"
	APE_SANBOOT = "apeSANBoot"
	APE_SDR = "apeSdr"
	APE_SET_ADAPTOR_FIRMWARE_VERSION = "apeSetAdaptorFirmwareVersion"
	APE_SET_APE_SENSOR_READING = "apeSetApeSensorReading"
	APE_SET_FLEX_FLASH_CONTROLLER_FIRMWARE_VERSION = "apeSetFlexFlashControllerFirmwareVersion"
	APE_SET_FLEX_FLASH_CONTROLLER_STATE = "apeSetFlexFlashControllerState"
	APE_SET_FLEX_FLASH_VIRTUAL_RAID_INFORMATION = "apeSetFlexFlashVirtualRaidInformation"
	APE_SET_SERVER_LIFE_CYCLE = "apeSetServerLifeCycle"
	APE_SET_SWITCH_INVENTORY = "apeSetSwitchInventory"
	APE_SWITCH_FIRMWARE_INV = "apeSwitchFirmwareInv"
	APE_UPDATE_APE_FIRMWARE_PARAM_TABLE = "apeUpdateApeFirmwareParamTable"
	APE_UPDATE_BIOSFIRMWARE_VERSION = "apeUpdateBIOSFirmwareVersion"
	APE_UPDATE_STORAGE_CTLR_FIRMWARE_VERSION = "apeUpdateStorageCtlrFirmwareVersion"
	APE_VIRTUAL_MEDIA_BOOT = "apeVirtualMediaBoot"
	BIOS_BOT = "biosBOT"
	BIOS_BOOT_DEV = "biosBootDev"
	BIOS_BOOT_DEV_GRP = "biosBootDevGrp"
	BIOS_FEATURE_REF = "biosFeatureRef"
	BIOS_PARAMETER_REF = "biosParameterRef"
	BIOS_REF = "biosRef"
	BIOS_SETTING_REF = "biosSettingRef"
	BIOS_SETTINGS = "biosSettings"
	BIOS_UNIT = "biosUnit"
	BIOS_VIDENTITY_PARAMS = "biosVIdentityParams"
	BIOS_VPROFILE = "biosVProfile"
	BIOS_VF_ACPI10_SUPPORT = "biosVfACPI10Support"
	BIOS_VF_ASSERT_NMION_PERR = "biosVfAssertNMIOnPERR"
	BIOS_VF_ASSERT_NMION_SERR = "biosVfAssertNMIOnSERR"
	BIOS_VF_BOOT_OPTION_RETRY = "biosVfBootOptionRetry"
	BIOS_VF_CPUPERFORMANCE = "biosVfCPUPerformance"
	BIOS_VF_CONSOLE_REDIRECTION = "biosVfConsoleRedirection"
	BIOS_VF_CORE_MULTI_PROCESSING = "biosVfCoreMultiProcessing"
	BIOS_VF_DIRECT_CACHE_ACCESS = "biosVfDirectCacheAccess"
	BIOS_VF_DRAM_REFRESH_RATE = "biosVfDramRefreshRate"
	BIOS_VF_ENHANCED_INTEL_SPEED_STEP_TECH = "biosVfEnhancedIntelSpeedStepTech"
	BIOS_VF_EXECUTE_DISABLE_BIT = "biosVfExecuteDisableBit"
	BIOS_VF_FRONT_PANEL_LOCKOUT = "biosVfFrontPanelLockout"
	BIOS_VF_INTEL_ENTRY_SASRAIDMODULE = "biosVfIntelEntrySASRAIDModule"
	BIOS_VF_INTEL_HYPER_THREADING_TECH = "biosVfIntelHyperThreadingTech"
	BIOS_VF_INTEL_TURBO_BOOST_TECH = "biosVfIntelTurboBoostTech"
	BIOS_VF_INTEL_VTFOR_DIRECTED_IO = "biosVfIntelVTForDirectedIO"
	BIOS_VF_INTEL_VIRTUALIZATION_TECHNOLOGY = "biosVfIntelVirtualizationTechnology"
	BIOS_VF_LOCAL_X2_APIC = "biosVfLocalX2Apic"
	BIOS_VF_LV_DIMMSUPPORT = "biosVfLvDIMMSupport"
	BIOS_VF_MAX_VARIABLE_MTRRSETTING = "biosVfMaxVariableMTRRSetting"
	BIOS_VF_MAXIMUM_MEMORY_BELOW4_GB = "biosVfMaximumMemoryBelow4GB"
	BIOS_VF_MEMORY_MAPPED_IOABOVE4_GB = "biosVfMemoryMappedIOAbove4GB"
	BIOS_VF_MIRRORING_MODE = "biosVfMirroringMode"
	BIOS_VF_NUMAOPTIMIZED = "biosVfNUMAOptimized"
	BIOS_VF_OSBOOT_WATCHDOG_TIMER = "biosVfOSBootWatchdogTimer"
	BIOS_VF_OSBOOT_WATCHDOG_TIMER_POLICY = "biosVfOSBootWatchdogTimerPolicy"
	BIOS_VF_OSBOOT_WATCHDOG_TIMER_TIMEOUT = "biosVfOSBootWatchdogTimerTimeout"
	BIOS_VF_ONBOARD_SATACONTROLLER = "biosVfOnboardSATAController"
	BIOS_VF_ONBOARD_STORAGE = "biosVfOnboardStorage"
	BIOS_VF_OPTION_ROMENABLE = "biosVfOptionROMEnable"
	BIOS_VF_OPTION_ROMLOAD = "biosVfOptionROMLoad"
	BIOS_VF_PCISLOT_OPTION_ROMENABLE = "biosVfPCISlotOptionROMEnable"
	BIOS_VF_POSTERROR_PAUSE = "biosVfPOSTErrorPause"
	BIOS_VF_PACKAGE_CSTATE_LIMIT = "biosVfPackageCStateLimit"
	BIOS_VF_PROCESSOR_C1_E = "biosVfProcessorC1E"
	BIOS_VF_PROCESSOR_C3_REPORT = "biosVfProcessorC3Report"
	BIOS_VF_PROCESSOR_C6_REPORT = "biosVfProcessorC6Report"
	BIOS_VF_PROCESSOR_C7_REPORT = "biosVfProcessorC7Report"
	BIOS_VF_PROCESSOR_CSTATE = "biosVfProcessorCState"
	BIOS_VF_QUIET_BOOT = "biosVfQuietBoot"
	BIOS_VF_RESUME_ON_ACPOWER_LOSS = "biosVfResumeOnACPowerLoss"
	BIOS_VF_SELECT_MEMORY_RASCONFIGURATION = "biosVfSelectMemoryRASConfiguration"
	BIOS_VF_SERIAL_PORT_AENABLE = "biosVfSerialPortAEnable"
	BIOS_VF_SPARING_MODE = "biosVfSparingMode"
	BIOS_VF_SRIOV_CONFIG = "biosVfSriovConfig"
	BIOS_VF_UCSMBOOT_MODE_CONTROL = "biosVfUCSMBootModeControl"
	BIOS_VF_UCSMBOOT_ORDER_RULE_CONTROL = "biosVfUCSMBootOrderRuleControl"
	BIOS_VF_UEFIOSUSE_LEGACY_VIDEO = "biosVfUEFIOSUseLegacyVideo"
	BIOS_VF_USBBOOT_CONFIG = "biosVfUSBBootConfig"
	BIOS_VF_USBFRONT_PANEL_ACCESS_LOCK = "biosVfUSBFrontPanelAccessLock"
	BIOS_VF_USBSYSTEM_IDLE_POWER_OPTIMIZING_SETTING = "biosVfUSBSystemIdlePowerOptimizingSetting"
	BMC_SELCOUNTER = "bmcSELCounter"
	BW_FILTER = "bwFilter"
	CALLHOME_DEST = "callhomeDest"
	CALLHOME_EP = "callhomeEp"
	CALLHOME_EP_FSM = "callhomeEpFsm"
	CALLHOME_EP_FSM_STAGE = "callhomeEpFsmStage"
	CALLHOME_EP_FSM_TASK = "callhomeEpFsmTask"
	CALLHOME_PERIODIC_SYSTEM_INVENTORY = "callhomePeriodicSystemInventory"
	CALLHOME_POLICY = "callhomePolicy"
	CALLHOME_PROFILE = "callhomeProfile"
	CALLHOME_SMTP = "callhomeSmtp"
	CALLHOME_SOURCE = "callhomeSource"
	CALLHOME_TEST_ALERT = "callhomeTestAlert"
	CAPABILITY_CATALOGUE = "capabilityCatalogue"
	CAPABILITY_CATALOGUE_FSM = "capabilityCatalogueFsm"
	CAPABILITY_CATALOGUE_FSM_STAGE = "capabilityCatalogueFsmStage"
	CAPABILITY_CATALOGUE_FSM_TASK = "capabilityCatalogueFsmTask"
	CAPABILITY_EP = "capabilityEp"
	CAPABILITY_FEATURE_LIMITS = "capabilityFeatureLimits"
	CAPABILITY_MGMT_EXTENSION = "capabilityMgmtExtension"
	CAPABILITY_MGMT_EXTENSION_FSM = "capabilityMgmtExtensionFsm"
	CAPABILITY_MGMT_EXTENSION_FSM_STAGE = "capabilityMgmtExtensionFsmStage"
	CAPABILITY_MGMT_EXTENSION_FSM_TASK = "capabilityMgmtExtensionFsmTask"
	CAPABILITY_NETWORK_LIMITS = "capabilityNetworkLimits"
	CAPABILITY_STORAGE_LIMITS = "capabilityStorageLimits"
	CAPABILITY_SYSTEM_LIMITS = "capabilitySystemLimits"
	CAPABILITY_UPDATE = "capabilityUpdate"
	CAPABILITY_UPDATER = "capabilityUpdater"
	CAPABILITY_UPDATER_FSM = "capabilityUpdaterFsm"
	CAPABILITY_UPDATER_FSM_STAGE = "capabilityUpdaterFsmStage"
	CAPABILITY_UPDATER_FSM_TASK = "capabilityUpdaterFsmTask"
	CHANGE_CHANGED_OBJECT_REF = "changeChangedObjectRef"
	CLASS_ID = "classId"
	CLASS_ID_SET = "classIdSet"
	CLITEST_TYPE_TEST = "clitestTypeTest"
	CLITEST_TYPE_TEST2 = "clitestTypeTest2"
	CLITEST_TYPE_TEST_CHILD = "clitestTypeTestChild"
	COMM_CIMC_WEB_SERVICE = "commCimcWebService"
	COMM_CIMXML = "commCimxml"
	COMM_DATE_TIME = "commDateTime"
	COMM_DNS = "commDns"
	COMM_DNS_PROVIDER = "commDnsProvider"
	COMM_EVT_CHANNEL = "commEvtChannel"
	COMM_HTTP = "commHttp"
	COMM_HTTPS = "commHttps"
	COMM_NTP_PROVIDER = "commNtpProvider"
	COMM_SHELL_SVC_LIMITS = "commShellSvcLimits"
	COMM_SMASH_CLP = "commSmashCLP"
	COMM_SNMP = "commSnmp"
	COMM_SNMP_TRAP = "commSnmpTrap"
	COMM_SNMP_USER = "commSnmpUser"
	COMM_SSH = "commSsh"
	COMM_SVC_EP = "commSvcEp"
	COMM_SVC_EP_FSM = "commSvcEpFsm"
	COMM_SVC_EP_FSM_STAGE = "commSvcEpFsmStage"
	COMM_SVC_EP_FSM_TASK = "commSvcEpFsmTask"
	COMM_SYSLOG = "commSyslog"
	COMM_SYSLOG_CLIENT = "commSyslogClient"
	COMM_SYSLOG_CONSOLE = "commSyslogConsole"
	COMM_SYSLOG_FILE = "commSyslogFile"
	COMM_SYSLOG_MONITOR = "commSyslogMonitor"
	COMM_SYSLOG_SOURCE = "commSyslogSource"
	COMM_TELNET = "commTelnet"
	COMM_WEB_CHANNEL = "commWebChannel"
	COMM_WEB_SVC_LIMITS = "commWebSvcLimits"
	COMM_WSMAN = "commWsman"
	COMM_XML_CL_CONN_POLICY = "commXmlClConnPolicy"
	COMPUTE_AUTOCONFIG_POLICY = "computeAutoconfigPolicy"
	COMPUTE_BLADE = "computeBlade"
	COMPUTE_BLADE_DISC_POLICY = "computeBladeDiscPolicy"
	COMPUTE_BLADE_FSM = "computeBladeFsm"
	COMPUTE_BLADE_FSM_STAGE = "computeBladeFsmStage"
	COMPUTE_BLADE_FSM_TASK = "computeBladeFsmTask"
	COMPUTE_BLADE_INHERIT_POLICY = "computeBladeInheritPolicy"
	COMPUTE_BOARD = "computeBoard"
	COMPUTE_BOARD_CONTROLLER = "computeBoardController"
	COMPUTE_CHASSIS_CONN_POLICY = "computeChassisConnPolicy"
	COMPUTE_CHASSIS_DISC_POLICY = "computeChassisDiscPolicy"
	COMPUTE_CHASSIS_QUAL = "computeChassisQual"
	COMPUTE_DEFAULTS = "computeDefaults"
	COMPUTE_FW_SYNC_ACK = "computeFwSyncAck"
	COMPUTE_GET_INVENTORY = "computeGetInventory"
	COMPUTE_HEALTH_LED_SENSOR_ALARM = "computeHealthLedSensorAlarm"
	COMPUTE_IOHUB = "computeIOHub"
	COMPUTE_IOHUB_ENV_STATS = "computeIOHubEnvStats"
	COMPUTE_IOHUB_ENV_STATS_HIST = "computeIOHubEnvStatsHist"
	COMPUTE_MB_POWER_STATS = "computeMbPowerStats"
	COMPUTE_MB_POWER_STATS_HIST = "computeMbPowerStatsHist"
	COMPUTE_MB_TEMP_STATS = "computeMbTempStats"
	COMPUTE_MB_TEMP_STATS_HIST = "computeMbTempStatsHist"
	COMPUTE_MEMORY_CONFIG_POLICY = "computeMemoryConfigPolicy"
	COMPUTE_MEMORY_CONFIGURATION = "computeMemoryConfiguration"
	COMPUTE_MEMORY_UNIT_CONSTRAINT_DEF = "computeMemoryUnitConstraintDef"
	COMPUTE_PCIE_FATAL_COMPLETION_STATS = "computePCIeFatalCompletionStats"
	COMPUTE_PCIE_FATAL_PROTOCOL_STATS = "computePCIeFatalProtocolStats"
	COMPUTE_PCIE_FATAL_RECEIVE_STATS = "computePCIeFatalReceiveStats"
	COMPUTE_PCIE_FATAL_STATS = "computePCIeFatalStats"
	COMPUTE_PCI_CAP = "computePciCap"
	COMPUTE_PCI_SLOT_SCAN_DEF = "computePciSlotScanDef"
	COMPUTE_PHYSICAL_ASSOC_CTX = "computePhysicalAssocCtx"
	COMPUTE_PHYSICAL_FSM = "computePhysicalFsm"
	COMPUTE_PHYSICAL_FSM_STAGE = "computePhysicalFsmStage"
	COMPUTE_PHYSICAL_FSM_TASK = "computePhysicalFsmTask"
	COMPUTE_PHYSICAL_QUAL = "computePhysicalQual"
	COMPUTE_PLATFORM = "computePlatform"
	COMPUTE_PNU_OSIMAGE = "computePnuOSImage"
	COMPUTE_POOL = "computePool"
	COMPUTE_POOL_POLICY_REF = "computePoolPolicyRef"
	COMPUTE_POOLABLE = "computePoolable"
	COMPUTE_POOLED_RACK_UNIT = "computePooledRackUnit"
	COMPUTE_POOLED_SLOT = "computePooledSlot"
	COMPUTE_POOLING_POLICY = "computePoolingPolicy"
	COMPUTE_PSU_CONTROL = "computePsuControl"
	COMPUTE_PSU_POLICY = "computePsuPolicy"
	COMPUTE_QUAL = "computeQual"
	COMPUTE_RACK_QUAL = "computeRackQual"
	COMPUTE_RACK_UNIT = "computeRackUnit"
	COMPUTE_RACK_UNIT_FSM = "computeRackUnitFsm"
	COMPUTE_RACK_UNIT_FSM_STAGE = "computeRackUnitFsmStage"
	COMPUTE_RACK_UNIT_FSM_TASK = "computeRackUnitFsmTask"
	COMPUTE_RACK_UNIT_MB_TEMP_STATS = "computeRackUnitMbTempStats"
	COMPUTE_RACK_UNIT_MB_TEMP_STATS_HIST = "computeRackUnitMbTempStatsHist"
	COMPUTE_RTC_BATTERY = "computeRtcBattery"
	COMPUTE_SCRUB_POLICY = "computeScrubPolicy"
	COMPUTE_SERVER_DISC_POLICY = "computeServerDiscPolicy"
	COMPUTE_SERVER_DISC_POLICY_FSM = "computeServerDiscPolicyFsm"
	COMPUTE_SERVER_DISC_POLICY_FSM_STAGE = "computeServerDiscPolicyFsmStage"
	COMPUTE_SERVER_DISC_POLICY_FSM_TASK = "computeServerDiscPolicyFsmTask"
	COMPUTE_SERVER_MGMT_POLICY = "computeServerMgmtPolicy"
	COMPUTE_SLOT_QUAL = "computeSlotQual"
	COMPUTE_SUBSCRIBE = "computeSubscribe"
	CONFIG_CHECK_COMPATIBILITY = "configCheckCompatibility"
	CONFIG_CHECK_CONFORMANCE = "configCheckConformance"
	CONFIG_CHECK_FIRMWARE_UPDATABLE = "configCheckFirmwareUpdatable"
	CONFIG_CONF_FILTERED = "configConfFiltered"
	CONFIG_CONF_MO = "configConfMo"
	CONFIG_CONF_MO_GROUP = "configConfMoGroup"
	CONFIG_CONF_MOS = "configConfMos"
	CONFIG_CONF_RENAME = "configConfRename"
	CONFIG_CONFIG = "configConfig"
	CONFIG_ESTIMATE_IMPACT = "configEstimateImpact"
	CONFIG_FIND_DEPENDENCIES = "configFindDependencies"
	CONFIG_FIND_DNS_BY_CLASS_ID = "configFindDnsByClassId"
	CONFIG_FIND_HOST_PACK_DEPENDENCIES = "configFindHostPackDependencies"
	CONFIG_FIND_PERMITTED = "configFindPermitted"
	CONFIG_GET_ESTIMATE_IMPACT = "configGetEstimateImpact"
	CONFIG_GET_REMOTE_POLICIES = "configGetRemotePolicies"
	CONFIG_GET_XML_FILE = "configGetXmlFile"
	CONFIG_GET_XML_FILE_STR = "configGetXmlFileStr"
	CONFIG_IMPACT = "configImpact"
	CONFIG_INSTALL_ALL_IMPACT = "configInstallAllImpact"
	CONFIG_MANAGED_EP_IMPACT_RESPONSE = "configManagedEpImpactResponse"
	CONFIG_MAP = "configMap"
	CONFIG_MO_CHANGE_EVENT = "configMoChangeEvent"
	CONFIG_REFRESH_IDENTITY = "configRefreshIdentity"
	CONFIG_RELEASE_RESOLVE_CONTEXT = "configReleaseResolveContext"
	CONFIG_RENEW_RESOLVE_CONTEXT = "configRenewResolveContext"
	CONFIG_RESOLVE_CHILDREN = "configResolveChildren"
	CONFIG_RESOLVE_CHILDREN_SORTED = "configResolveChildrenSorted"
	CONFIG_RESOLVE_CLASS = "configResolveClass"
	CONFIG_RESOLVE_CLASS_SORTED = "configResolveClassSorted"
	CONFIG_RESOLVE_CLASSES = "configResolveClasses"
	CONFIG_RESOLVE_CLASSES_SORTED = "configResolveClassesSorted"
	CONFIG_RESOLVE_CONTEXT = "configResolveContext"
	CONFIG_RESOLVE_DN = "configResolveDn"
	CONFIG_RESOLVE_DNS = "configResolveDns"
	CONFIG_RESOLVE_PARENT = "configResolveParent"
	CONFIG_SCOPE = "configScope"
	CONFIG_SET = "configSet"
	CONFIG_SORTER = "configSorter"
	DCX_NS = "dcxNs"
	DCX_UNIVERSE = "dcxUniverse"
	DCX_VIF = "dcxVIf"
	DCX_VC = "dcxVc"
	DCX_VIF_EP = "dcxVifEp"
	DHCP_ACQUIRED = "dhcpAcquired"
	DHCP_INST = "dhcpInst"
	DHCP_LEASE = "dhcpLease"
	DIAG_BLADE_TEST = "diagBladeTest"
	DIAG_NETWORK_TEST = "diagNetworkTest"
	DIAG_RSLT = "diagRslt"
	DIAG_RUN_POLICY = "diagRunPolicy"
	DIAG_SRV_CAP_PROVIDER = "diagSrvCapProvider"
	DIAG_SRV_CTRL = "diagSrvCtrl"
	DN = "dn"
	DN_SET = "dnSet"
	DOMAIN_ENVIRONMENT_FEATURE = "domainEnvironmentFeature"
	DOMAIN_ENVIRONMENT_FEATURE_CONT = "domainEnvironmentFeatureCont"
	DOMAIN_ENVIRONMENT_PARAM = "domainEnvironmentParam"
	DOMAIN_NETWORK_FEATURE = "domainNetworkFeature"
	DOMAIN_NETWORK_FEATURE_CONT = "domainNetworkFeatureCont"
	DOMAIN_NETWORK_PARAM = "domainNetworkParam"
	DOMAIN_SERVER_FEATURE = "domainServerFeature"
	DOMAIN_SERVER_FEATURE_CONT = "domainServerFeatureCont"
	DOMAIN_SERVER_PARAM = "domainServerParam"
	DOMAIN_STORAGE_FEATURE = "domainStorageFeature"
	DOMAIN_STORAGE_FEATURE_CONT = "domainStorageFeatureCont"
	DOMAIN_STORAGE_PARAM = "domainStorageParam"
	DPSEC_MAC = "dpsecMac"
	EPQOS_DEFINITION = "epqosDefinition"
	EPQOS_DEFINITION_DEL_TASK = "epqosDefinitionDelTask"
	EPQOS_DEFINITION_DEL_TASK_FSM = "epqosDefinitionDelTaskFsm"
	EPQOS_DEFINITION_DEL_TASK_FSM_STAGE = "epqosDefinitionDelTaskFsmStage"
	EPQOS_DEFINITION_DEL_TASK_FSM_TASK = "epqosDefinitionDelTaskFsmTask"
	EPQOS_DEFINITION_FSM = "epqosDefinitionFsm"
	EPQOS_DEFINITION_FSM_STAGE = "epqosDefinitionFsmStage"
	EPQOS_DEFINITION_FSM_TASK = "epqosDefinitionFsmTask"
	EPQOS_EGRESS = "epqosEgress"
	EQ_FILTER = "eqFilter"
	EQUIPMENT_ADAPTOR_CONN_DEF = "equipmentAdaptorConnDef"
	EQUIPMENT_ADAPTOR_DEF = "equipmentAdaptorDef"
	EQUIPMENT_ADVANCED_BOOT_ORDER = "equipmentAdvancedBootOrder"
	EQUIPMENT_BASE_BOARD_CAP_PROVIDER = "equipmentBaseBoardCapProvider"
	EQUIPMENT_BEACON_CAP_PROVIDER = "equipmentBeaconCapProvider"
	EQUIPMENT_BEACON_LED = "equipmentBeaconLed"
	EQUIPMENT_BEACON_LED_FSM = "equipmentBeaconLedFsm"
	EQUIPMENT_BEACON_LED_FSM_STAGE = "equipmentBeaconLedFsmStage"
	EQUIPMENT_BEACON_LED_FSM_TASK = "equipmentBeaconLedFsmTask"
	EQUIPMENT_BIOS_DEF = "equipmentBiosDef"
	EQUIPMENT_BLADE_AGLIBRARY = "equipmentBladeAGLibrary"
	EQUIPMENT_BLADE_BIOS_CAP_PROVIDER = "equipmentBladeBiosCapProvider"
	EQUIPMENT_BLADE_CAP_PROVIDER = "equipmentBladeCapProvider"
	EQUIPMENT_BLADE_CONN_DEF = "equipmentBladeConnDef"
	EQUIPMENT_BLADE_IOMCONN_DEF = "equipmentBladeIOMConnDef"
	EQUIPMENT_BOARD_CONTROLLER_DEF = "equipmentBoardControllerDef"
	EQUIPMENT_CATALOG_CAP_PROVIDER = "equipmentCatalogCapProvider"
	EQUIPMENT_CHASSIS = "equipmentChassis"
	EQUIPMENT_CHASSIS_CAP_PROVIDER = "equipmentChassisCapProvider"
	EQUIPMENT_CHASSIS_FSM = "equipmentChassisFsm"
	EQUIPMENT_CHASSIS_FSM_STAGE = "equipmentChassisFsmStage"
	EQUIPMENT_CHASSIS_FSM_TASK = "equipmentChassisFsmTask"
	EQUIPMENT_CHASSIS_STATS = "equipmentChassisStats"
	EQUIPMENT_CHASSIS_STATS_HIST = "equipmentChassisStatsHist"
	EQUIPMENT_DBG_PLUGIN_CAP_PROVIDER = "equipmentDbgPluginCapProvider"
	EQUIPMENT_DIMM_ENTRY = "equipmentDimmEntry"
	EQUIPMENT_DIMM_MAPPING = "equipmentDimmMapping"
	EQUIPMENT_DISCOVERY_CAP = "equipmentDiscoveryCap"
	EQUIPMENT_DOWNGRADE_CONSTRAINT = "equipmentDowngradeConstraint"
	EQUIPMENT_FAN = "equipmentFan"
	EQUIPMENT_FAN_MODULE = "equipmentFanModule"
	EQUIPMENT_FAN_MODULE_CAP_PROVIDER = "equipmentFanModuleCapProvider"
	EQUIPMENT_FAN_MODULE_DEF = "equipmentFanModuleDef"
	EQUIPMENT_FAN_MODULE_STATS = "equipmentFanModuleStats"
	EQUIPMENT_FAN_MODULE_STATS_HIST = "equipmentFanModuleStatsHist"
	EQUIPMENT_FAN_STATS = "equipmentFanStats"
	EQUIPMENT_FAN_STATS_HIST = "equipmentFanStatsHist"
	EQUIPMENT_FEX = "equipmentFex"
	EQUIPMENT_FEX_CAP_PROVIDER = "equipmentFexCapProvider"
	EQUIPMENT_FEX_ENV_STATS = "equipmentFexEnvStats"
	EQUIPMENT_FEX_ENV_STATS_HIST = "equipmentFexEnvStatsHist"
	EQUIPMENT_FEX_FSM = "equipmentFexFsm"
	EQUIPMENT_FEX_FSM_STAGE = "equipmentFexFsmStage"
	EQUIPMENT_FEX_FSM_TASK = "equipmentFexFsmTask"
	EQUIPMENT_FEX_POWER_SUMMARY = "equipmentFexPowerSummary"
	EQUIPMENT_FEX_POWER_SUMMARY_HIST = "equipmentFexPowerSummaryHist"
	EQUIPMENT_FEX_PSU_INPUT_STATS = "equipmentFexPsuInputStats"
	EQUIPMENT_FEX_PSU_INPUT_STATS_HIST = "equipmentFexPsuInputStatsHist"
	EQUIPMENT_FIRMWARE_CONSTRAINT = "equipmentFirmwareConstraint"
	EQUIPMENT_GEM_CAP_PROVIDER = "equipmentGemCapProvider"
	EQUIPMENT_GEM_PORT_CAP = "equipmentGemPortCap"
	EQUIPMENT_GRAPHICS_CARD_CAP_PROVIDER = "equipmentGraphicsCardCapProvider"
	EQUIPMENT_GRAPHICS_CARD_CAP_REF = "equipmentGraphicsCardCapRef"
	EQUIPMENT_HDDFAULT_MON_DEF = "equipmentHDDFaultMonDef"
	EQUIPMENT_HEALTH_LED = "equipmentHealthLed"
	EQUIPMENT_HOST_IF_CAP_PROVIDER = "equipmentHostIfCapProvider"
	EQUIPMENT_IOCARD = "equipmentIOCard"
	EQUIPMENT_IOCARD_CAP_PROVIDER = "equipmentIOCardCapProvider"
	EQUIPMENT_IOCARD_FSM = "equipmentIOCardFsm"
	EQUIPMENT_IOCARD_FSM_STAGE = "equipmentIOCardFsmStage"
	EQUIPMENT_IOCARD_FSM_TASK = "equipmentIOCardFsmTask"
	EQUIPMENT_IOCARD_STATS = "equipmentIOCardStats"
	EQUIPMENT_IOCARD_STATS_HIST = "equipmentIOCardStatsHist"
	EQUIPMENT_IOCARD_TYPE_DEF = "equipmentIOCardTypeDef"
	EQUIPMENT_INBAND_MGMT_CAP = "equipmentInbandMgmtCap"
	EQUIPMENT_INDICATOR_LED = "equipmentIndicatorLed"
	EQUIPMENT_LOCAL_DISK_CAP_PROVIDER = "equipmentLocalDiskCapProvider"
	EQUIPMENT_LOCAL_DISK_CONTROLLER_CAP_PROVIDER = "equipmentLocalDiskControllerCapProvider"
	EQUIPMENT_LOCAL_DISK_CONTROLLER_CAP_REF = "equipmentLocalDiskControllerCapRef"
	EQUIPMENT_LOCAL_DISK_CONTROLLER_DEF = "equipmentLocalDiskControllerDef"
	EQUIPMENT_LOCAL_DISK_DEF = "equipmentLocalDiskDef"
	EQUIPMENT_LOCATOR_LED = "equipmentLocatorLed"
	EQUIPMENT_LOCATOR_LED_FSM = "equipmentLocatorLedFsm"
	EQUIPMENT_LOCATOR_LED_FSM_STAGE = "equipmentLocatorLedFsmStage"
	EQUIPMENT_LOCATOR_LED_FSM_TASK = "equipmentLocatorLedFsmTask"
	EQUIPMENT_MANUFACTURING_DEF = "equipmentManufacturingDef"
	EQUIPMENT_MEMORY_UNIT_CAP_PROVIDER = "equipmentMemoryUnitCapProvider"
	EQUIPMENT_MEMORY_UNIT_DISCOVERY_MODIFIER_DEF = "equipmentMemoryUnitDiscoveryModifierDef"
	EQUIPMENT_MGMT_CAP_PROVIDER = "equipmentMgmtCapProvider"
	EQUIPMENT_MGMT_EXT_CAP_PROVIDER = "equipmentMgmtExtCapProvider"
	EQUIPMENT_NETWORK_ELEMENT_FAN_STATS = "equipmentNetworkElementFanStats"
	EQUIPMENT_NETWORK_ELEMENT_FAN_STATS_HIST = "equipmentNetworkElementFanStatsHist"
	EQUIPMENT_POST = "equipmentPOST"
	EQUIPMENT_POSTCODE = "equipmentPOSTCode"
	EQUIPMENT_POSTCODE_REPORTER = "equipmentPOSTCodeReporter"
	EQUIPMENT_POSTCODE_TEMPLATE = "equipmentPOSTCodeTemplate"
	EQUIPMENT_PCI_DEF = "equipmentPciDef"
	EQUIPMENT_PHYSICAL_DEF = "equipmentPhysicalDef"
	EQUIPMENT_PICTURE = "equipmentPicture"
	EQUIPMENT_PORT_GROUP_AGGREGATION_DEF = "equipmentPortGroupAggregationDef"
	EQUIPMENT_PORT_GROUP_DEF = "equipmentPortGroupDef"
	EQUIPMENT_PORT_GROUP_SW_COMPLEX_DEF = "equipmentPortGroupSwComplexDef"
	EQUIPMENT_PORT_SW_COMPLEX_REF = "equipmentPortSwComplexRef"
	EQUIPMENT_PROCESSOR_UNIT_CAP_PROVIDER = "equipmentProcessorUnitCapProvider"
	EQUIPMENT_PROCESSOR_UNIT_DEF = "equipmentProcessorUnitDef"
	EQUIPMENT_PSU = "equipmentPsu"
	EQUIPMENT_PSU_CAP_PROVIDER = "equipmentPsuCapProvider"
	EQUIPMENT_PSU_DEF = "equipmentPsuDef"
	EQUIPMENT_PSU_INPUT_STATS = "equipmentPsuInputStats"
	EQUIPMENT_PSU_INPUT_STATS_HIST = "equipmentPsuInputStatsHist"
	EQUIPMENT_PSU_OUTPUT_STATS = "equipmentPsuOutputStats"
	EQUIPMENT_PSU_OUTPUT_STATS_HIST = "equipmentPsuOutputStatsHist"
	EQUIPMENT_PSU_STATS = "equipmentPsuStats"
	EQUIPMENT_PSU_STATS_HIST = "equipmentPsuStatsHist"
	EQUIPMENT_RACK_FAN_MODULE_DEF = "equipmentRackFanModuleDef"
	EQUIPMENT_RACK_UNIT_CAP_PROVIDER = "equipmentRackUnitCapProvider"
	EQUIPMENT_RACK_UNIT_FAN_STATS = "equipmentRackUnitFanStats"
	EQUIPMENT_RACK_UNIT_FAN_STATS_HIST = "equipmentRackUnitFanStatsHist"
	EQUIPMENT_RACK_UNIT_PSU_STATS = "equipmentRackUnitPsuStats"
	EQUIPMENT_RACK_UNIT_PSU_STATS_HIST = "equipmentRackUnitPsuStatsHist"
	EQUIPMENT_RAID_DEF = "equipmentRaidDef"
	EQUIPMENT_SECURE_BOOT = "equipmentSecureBoot"
	EQUIPMENT_SERVER_FEATURE_CAP = "equipmentServerFeatureCap"
	EQUIPMENT_SERVICE_DEF = "equipmentServiceDef"
	EQUIPMENT_SLOT_ARRAY = "equipmentSlotArray"
	EQUIPMENT_SLOT_ARRAY_REF = "equipmentSlotArrayRef"
	EQUIPMENT_SWITCH_CAP = "equipmentSwitchCap"
	EQUIPMENT_SWITCH_CAP_PROVIDER = "equipmentSwitchCapProvider"
	EQUIPMENT_SWITCH_CARD = "equipmentSwitchCard"
	EQUIPMENT_TPM = "equipmentTpm"
	EQUIPMENT_TPM_CAP_PROVIDER = "equipmentTpmCapProvider"
	EQUIPMENT_UNIFIED_PORT_CAP_PROVIDER = "equipmentUnifiedPortCapProvider"
	EQUIPMENT_VERSION_CONSTRAINT = "equipmentVersionConstraint"
	EQUIPMENT_XCVR = "equipmentXcvr"
	ETHER_ERR_STATS = "etherErrStats"
	ETHER_ERR_STATS_HIST = "etherErrStatsHist"
	ETHER_FCOE_INTERFACE_STATS = "etherFcoeInterfaceStats"
	ETHER_FCOE_INTERFACE_STATS_HIST = "etherFcoeInterfaceStatsHist"
	ETHER_LOSS_STATS = "etherLossStats"
	ETHER_LOSS_STATS_HIST = "etherLossStatsHist"
	ETHER_NIC_IF_CONFIG = "etherNicIfConfig"
	ETHER_PIO = "etherPIo"
	ETHER_PIO_END_POINT = "etherPIoEndPoint"
	ETHER_PIO_FSM = "etherPIoFsm"
	ETHER_PIO_FSM_STAGE = "etherPIoFsmStage"
	ETHER_PAUSE_STATS = "etherPauseStats"
	ETHER_PAUSE_STATS_HIST = "etherPauseStatsHist"
	ETHER_PORT_CHAN_ID_ELEM = "etherPortChanIdElem"
	ETHER_PORT_CHAN_ID_UNIVERSE = "etherPortChanIdUniverse"
	ETHER_RX_STATS = "etherRxStats"
	ETHER_RX_STATS_HIST = "etherRxStatsHist"
	ETHER_SERVER_INT_FIO = "etherServerIntFIo"
	ETHER_SERVER_INT_FIO_FSM = "etherServerIntFIoFsm"
	ETHER_SERVER_INT_FIO_FSM_STAGE = "etherServerIntFIoFsmStage"
	ETHER_SERVER_INT_FIO_FSM_TASK = "etherServerIntFIoFsmTask"
	ETHER_SERVER_INT_FIO_PC = "etherServerIntFIoPc"
	ETHER_SERVER_INT_FIO_PC_EP = "etherServerIntFIoPcEp"
	ETHER_SW_IF_CONFIG = "etherSwIfConfig"
	ETHER_SWITCH_INT_FIO = "etherSwitchIntFIo"
	ETHER_SWITCH_INT_FIO_PC = "etherSwitchIntFIoPc"
	ETHER_SWITCH_INT_FIO_PC_EP = "etherSwitchIntFIoPcEp"
	ETHER_TX_STATS = "etherTxStats"
	ETHER_TX_STATS_HIST = "etherTxStatsHist"
	EVENT_EP_CTRL = "eventEpCtrl"
	EVENT_HOLDER = "eventHolder"
	EVENT_INST = "eventInst"
	EVENT_LOG = "eventLog"
	EVENT_POLICY = "eventPolicy"
	EVENT_RECORD = "eventRecord"
	EVENT_REGISTER_EVENT_CHANNEL = "eventRegisterEventChannel"
	EVENT_REGISTER_EVENT_CHANNEL_RESP = "eventRegisterEventChannelResp"
	EVENT_SEND_EVENT = "eventSendEvent"
	EVENT_SEND_HEARTBEAT = "eventSendHeartbeat"
	EVENT_SUBSCRIBE = "eventSubscribe"
	EVENT_UN_REGISTER_EVENT_CHANNEL = "eventUnRegisterEventChannel"
	EVENT_UNSUBSCRIBE = "eventUnsubscribe"
	EXTMGMT_ARP_TARGETS = "extmgmtArpTargets"
	EXTMGMT_GATEWAY_PING = "extmgmtGatewayPing"
	EXTMGMT_IF = "extmgmtIf"
	EXTMGMT_IF_MON_POLICY = "extmgmtIfMonPolicy"
	EXTMGMT_MII_STATUS = "extmgmtMiiStatus"
	EXTMGMT_NDISC_TARGETS = "extmgmtNdiscTargets"
	EXTPOL_CLIENT = "extpolClient"
	EXTPOL_CLIENT_CONT = "extpolClientCont"
	EXTPOL_CONTROLLER = "extpolController"
	EXTPOL_CONTROLLER_CONT = "extpolControllerCont"
	EXTPOL_EP = "extpolEp"
	EXTPOL_EP_FSM = "extpolEpFsm"
	EXTPOL_EP_FSM_STAGE = "extpolEpFsmStage"
	EXTPOL_EP_FSM_TASK = "extpolEpFsmTask"
	EXTPOL_PROVIDER = "extpolProvider"
	EXTPOL_PROVIDER_CONT = "extpolProviderCont"
	EXTPOL_PROVIDER_FSM = "extpolProviderFsm"
	EXTPOL_PROVIDER_FSM_STAGE = "extpolProviderFsmStage"
	EXTPOL_PROVIDER_FSM_TASK = "extpolProviderFsmTask"
	EXTPOL_REGISTRY = "extpolRegistry"
	EXTPOL_REGISTRY_FSM = "extpolRegistryFsm"
	EXTPOL_REGISTRY_FSM_STAGE = "extpolRegistryFsmStage"
	EXTPOL_REGISTRY_FSM_TASK = "extpolRegistryFsmTask"
	EXTPOL_SYSTEM_CONTEXT = "extpolSystemContext"
	EXTVMM_EP = "extvmmEp"
	EXTVMM_EP_FSM = "extvmmEpFsm"
	EXTVMM_EP_FSM_STAGE = "extvmmEpFsmStage"
	EXTVMM_EP_FSM_TASK = "extvmmEpFsmTask"
	EXTVMM_FNDREFERENCE = "extvmmFNDReference"
	EXTVMM_FABRIC_NETWORK = "extvmmFabricNetwork"
	EXTVMM_FABRIC_NETWORK_DEFINITION = "extvmmFabricNetworkDefinition"
	EXTVMM_KEY_INST = "extvmmKeyInst"
	EXTVMM_KEY_RING = "extvmmKeyRing"
	EXTVMM_KEY_STORE = "extvmmKeyStore"
	EXTVMM_KEY_STORE_FSM = "extvmmKeyStoreFsm"
	EXTVMM_KEY_STORE_FSM_STAGE = "extvmmKeyStoreFsmStage"
	EXTVMM_KEY_STORE_FSM_TASK = "extvmmKeyStoreFsmTask"
	EXTVMM_MASTER_EXT_KEY = "extvmmMasterExtKey"
	EXTVMM_MASTER_EXT_KEY_FSM = "extvmmMasterExtKeyFsm"
	EXTVMM_MASTER_EXT_KEY_FSM_STAGE = "extvmmMasterExtKeyFsmStage"
	EXTVMM_MASTER_EXT_KEY_FSM_TASK = "extvmmMasterExtKeyFsmTask"
	EXTVMM_NETWORK_SETS = "extvmmNetworkSets"
	EXTVMM_NETWORK_SETS_FSM = "extvmmNetworkSetsFsm"
	EXTVMM_NETWORK_SETS_FSM_STAGE = "extvmmNetworkSetsFsmStage"
	EXTVMM_NETWORK_SETS_FSM_TASK = "extvmmNetworkSetsFsmTask"
	EXTVMM_PROVIDER = "extvmmProvider"
	EXTVMM_PROVIDER_FSM = "extvmmProviderFsm"
	EXTVMM_PROVIDER_FSM_STAGE = "extvmmProviderFsmStage"
	EXTVMM_PROVIDER_FSM_TASK = "extvmmProviderFsmTask"
	EXTVMM_SWITCH_DEL_TASK = "extvmmSwitchDelTask"
	EXTVMM_SWITCH_DEL_TASK_FSM = "extvmmSwitchDelTaskFsm"
	EXTVMM_SWITCH_DEL_TASK_FSM_STAGE = "extvmmSwitchDelTaskFsmStage"
	EXTVMM_SWITCH_DEL_TASK_FSM_TASK = "extvmmSwitchDelTaskFsmTask"
	EXTVMM_SWITCH_SET = "extvmmSwitchSet"
	EXTVMM_UP_LINK_PP = "extvmmUpLinkPP"
	EXTVMM_VMNDREF = "extvmmVMNDRef"
	EXTVMM_VMNETWORK = "extvmmVMNetwork"
	EXTVMM_VMNETWORK_DEFINITION = "extvmmVMNetworkDefinition"
	EXTVMM_VMNETWORK_SETS = "extvmmVMNetworkSets"
	FABRIC_BHVLAN = "fabricBHVlan"
	FABRIC_CDP_LINK_POLICY = "fabricCdpLinkPolicy"
	FABRIC_CHANGED_OBJECT_REF = "fabricChangedObjectRef"
	FABRIC_CHASSIS_EP = "fabricChassisEp"
	FABRIC_COMPUTE_PH_EP = "fabricComputePhEp"
	FABRIC_COMPUTE_SLOT_EP = "fabricComputeSlotEp"
	FABRIC_COMPUTE_SLOT_EP_FSM = "fabricComputeSlotEpFsm"
	FABRIC_COMPUTE_SLOT_EP_FSM_STAGE = "fabricComputeSlotEpFsmStage"
	FABRIC_COMPUTE_SLOT_EP_FSM_TASK = "fabricComputeSlotEpFsmTask"
	FABRIC_DCE_SRV = "fabricDceSrv"
	FABRIC_DCE_SW_SRV = "fabricDceSwSrv"
	FABRIC_DCE_SW_SRV_EP = "fabricDceSwSrvEp"
	FABRIC_DCE_SW_SRV_PC = "fabricDceSwSrvPc"
	FABRIC_DCE_SW_SRV_PC_EP = "fabricDceSwSrvPcEp"
	FABRIC_EP = "fabricEp"
	FABRIC_EP_MGR = "fabricEpMgr"
	FABRIC_EP_MGR_FSM = "fabricEpMgrFsm"
	FABRIC_EP_MGR_FSM_STAGE = "fabricEpMgrFsmStage"
	FABRIC_EP_MGR_FSM_TASK = "fabricEpMgrFsmTask"
	FABRIC_ETH_ESTC = "fabricEthEstc"
	FABRIC_ETH_ESTC_CLOUD = "fabricEthEstcCloud"
	FABRIC_ETH_ESTC_EP = "fabricEthEstcEp"
	FABRIC_ETH_ESTC_PC = "fabricEthEstcPc"
	FABRIC_ETH_ESTC_PC_EP = "fabricEthEstcPcEp"
	FABRIC_ETH_FLOW_MON_LAN = "fabricEthFlowMonLan"
	FABRIC_ETH_LAN = "fabricEthLan"
	FABRIC_ETH_LAN_EP = "fabricEthLanEp"
	FABRIC_ETH_LAN_FLOW_MONITORING = "fabricEthLanFlowMonitoring"
	FABRIC_ETH_LAN_PC = "fabricEthLanPc"
	FABRIC_ETH_LAN_PC_EP = "fabricEthLanPcEp"
	FABRIC_ETH_LINK_PROFILE = "fabricEthLinkProfile"
	FABRIC_ETH_MON = "fabricEthMon"
	FABRIC_ETH_MON_DEST_EP = "fabricEthMonDestEp"
	FABRIC_ETH_MON_FILT_EP = "fabricEthMonFiltEp"
	FABRIC_ETH_MON_FILT_REF = "fabricEthMonFiltRef"
	FABRIC_ETH_MON_LAN = "fabricEthMonLan"
	FABRIC_ETH_MON_SRC_EP = "fabricEthMonSrcEp"
	FABRIC_ETH_MON_SRC_REF = "fabricEthMonSrcRef"
	FABRIC_ETH_TARGET_EP = "fabricEthTargetEp"
	FABRIC_ETH_VLAN_PC = "fabricEthVlanPc"
	FABRIC_ETH_VLAN_PORT_EP = "fabricEthVlanPortEp"
	FABRIC_FC_ESTC = "fabricFcEstc"
	FABRIC_FC_ESTC_CLOUD = "fabricFcEstcCloud"
	FABRIC_FC_ESTC_EP = "fabricFcEstcEp"
	FABRIC_FC_MON = "fabricFcMon"
	FABRIC_FC_MON_DEST_EP = "fabricFcMonDestEp"
	FABRIC_FC_MON_FILT_EP = "fabricFcMonFiltEp"
	FABRIC_FC_MON_FILT_REF = "fabricFcMonFiltRef"
	FABRIC_FC_MON_SAN = "fabricFcMonSan"
	FABRIC_FC_MON_SRC_EP = "fabricFcMonSrcEp"
	FABRIC_FC_MON_SRC_REF = "fabricFcMonSrcRef"
	FABRIC_FC_SAN = "fabricFcSan"
	FABRIC_FC_SAN_EP = "fabricFcSanEp"
	FABRIC_FC_SAN_PC = "fabricFcSanPc"
	FABRIC_FC_SAN_PC_EP = "fabricFcSanPcEp"
	FABRIC_FC_VSAN_PC = "fabricFcVsanPc"
	FABRIC_FC_VSAN_PORT_EP = "fabricFcVsanPortEp"
	FABRIC_FCOE_ESTC_EP = "fabricFcoeEstcEp"
	FABRIC_FCOE_SAN_EP = "fabricFcoeSanEp"
	FABRIC_FCOE_SAN_PC = "fabricFcoeSanPc"
	FABRIC_FCOE_SAN_PC_EP = "fabricFcoeSanPcEp"
	FABRIC_FCOE_VSAN_PC = "fabricFcoeVsanPc"
	FABRIC_FCOE_VSAN_PORT_EP = "fabricFcoeVsanPortEp"
	FABRIC_FLOW_MON_DEFINITION = "fabricFlowMonDefinition"
	FABRIC_FLOW_MON_EXPORTER_PROFILE = "fabricFlowMonExporterProfile"
	FABRIC_IF = "fabricIf"
	FABRIC_LAN_ACCESS_MGR = "fabricLanAccessMgr"
	FABRIC_LAN_CLOUD = "fabricLanCloud"
	FABRIC_LAN_CLOUD_FSM = "fabricLanCloudFsm"
	FABRIC_LAN_CLOUD_FSM_STAGE = "fabricLanCloudFsmStage"
	FABRIC_LAN_CLOUD_FSM_TASK = "fabricLanCloudFsmTask"
	FABRIC_LAN_MON_CLOUD = "fabricLanMonCloud"
	FABRIC_LAN_PIN_GROUP = "fabricLanPinGroup"
	FABRIC_LAN_PIN_TARGET = "fabricLanPinTarget"
	FABRIC_LAST_ACKED_SLOT = "fabricLastAckedSlot"
	FABRIC_LOCALE = "fabricLocale"
	FABRIC_MULTICAST_POLICY = "fabricMulticastPolicy"
	FABRIC_NET_GROUP = "fabricNetGroup"
	FABRIC_NETFLOW_COLLECTOR = "fabricNetflowCollector"
	FABRIC_NETFLOW_IPV4_ADDR = "fabricNetflowIPv4Addr"
	FABRIC_NETFLOW_MON_EXPORTER = "fabricNetflowMonExporter"
	FABRIC_NETFLOW_MON_EXPORTER_REF = "fabricNetflowMonExporterRef"
	FABRIC_NETFLOW_MON_SESSION = "fabricNetflowMonSession"
	FABRIC_NETFLOW_MON_SRC_EP = "fabricNetflowMonSrcEp"
	FABRIC_NETFLOW_MON_SRC_REF = "fabricNetflowMonSrcRef"
	FABRIC_NETFLOW_MONITOR = "fabricNetflowMonitor"
	FABRIC_NETFLOW_MONITOR_REF = "fabricNetflowMonitorRef"
	FABRIC_NETFLOW_TIMEOUT_POLICY = "fabricNetflowTimeoutPolicy"
	FABRIC_ORG_VLAN_POLICY = "fabricOrgVlanPolicy"
	FABRIC_PATH = "fabricPath"
	FABRIC_PATH_CONN = "fabricPathConn"
	FABRIC_PATH_EP = "fabricPathEp"
	FABRIC_POOLABLE_VLAN = "fabricPoolableVlan"
	FABRIC_POOLED_VLAN = "fabricPooledVlan"
	FABRIC_SAN_CLOUD = "fabricSanCloud"
	FABRIC_SAN_CLOUD_FSM = "fabricSanCloudFsm"
	FABRIC_SAN_CLOUD_FSM_STAGE = "fabricSanCloudFsmStage"
	FABRIC_SAN_CLOUD_FSM_TASK = "fabricSanCloudFsmTask"
	FABRIC_SAN_MON_CLOUD = "fabricSanMonCloud"
	FABRIC_SAN_PIN_GROUP = "fabricSanPinGroup"
	FABRIC_SAN_PIN_TARGET = "fabricSanPinTarget"
	FABRIC_SW_CH_PH_EP = "fabricSwChPhEp"
	FABRIC_UDLD_LINK_POLICY = "fabricUdldLinkPolicy"
	FABRIC_UDLD_POLICY = "fabricUdldPolicy"
	FABRIC_VCON = "fabricVCon"
	FABRIC_VCON_PROFILE = "fabricVConProfile"
	FABRIC_VLAN = "fabricVlan"
	FABRIC_VLAN_EP = "fabricVlanEp"
	FABRIC_VLAN_GROUP_REQ = "fabricVlanGroupReq"
	FABRIC_VLAN_PERMIT = "fabricVlanPermit"
	FABRIC_VLAN_REQ = "fabricVlanReq"
	FABRIC_VNET_EP_SYNC_EP = "fabricVnetEpSyncEp"
	FABRIC_VNET_EP_SYNC_EP_FSM = "fabricVnetEpSyncEpFsm"
	FABRIC_VNET_EP_SYNC_EP_FSM_STAGE = "fabricVnetEpSyncEpFsmStage"
	FABRIC_VNET_EP_SYNC_EP_FSM_TASK = "fabricVnetEpSyncEpFsmTask"
	FABRIC_VSAN = "fabricVsan"
	FABRIC_VSAN_EP = "fabricVsanEp"
	FABRIC_VSAN_MEMBERSHIP = "fabricVsanMembership"
	FABRIC_ZONE_ID_UNIVERSE = "fabricZoneIdUniverse"
	FAULT_ACK_FAULT = "faultAckFault"
	FAULT_ACK_FAULTS = "faultAckFaults"
	FAULT_AFFECTED_CLASS = "faultAffectedClass"
	FAULT_HOLDER = "faultHolder"
	FAULT_INST = "faultInst"
	FAULT_LOCAL_TYPED_HOLDER = "faultLocalTypedHolder"
	FAULT_POLICY = "faultPolicy"
	FAULT_RESOLVE_FAULT = "faultResolveFault"
	FAULT_SUPPRESS_POLICY = "faultSuppressPolicy"
	FAULT_SUPPRESS_POLICY_ITEM = "faultSuppressPolicyItem"
	FAULT_SUPPRESS_TASK = "faultSuppressTask"
	FC_ERR_STATS = "fcErrStats"
	FC_ERR_STATS_HIST = "fcErrStatsHist"
	FC_NIC_IF_CONFIG = "fcNicIfConfig"
	FC_PIO = "fcPIo"
	FC_PIO_FSM = "fcPIoFsm"
	FC_PIO_FSM_STAGE = "fcPIoFsmStage"
	FC_STATS = "fcStats"
	FC_STATS_HIST = "fcStatsHist"
	FC_SW_IF_CONFIG = "fcSwIfConfig"
	FCPOOL_ADDR = "fcpoolAddr"
	FCPOOL_BLOCK = "fcpoolBlock"
	FCPOOL_BOOT_TARGET = "fcpoolBootTarget"
	FCPOOL_FORMAT = "fcpoolFormat"
	FCPOOL_INITIATOR = "fcpoolInitiator"
	FCPOOL_INITIATOR_EP = "fcpoolInitiatorEp"
	FCPOOL_INITIATORS = "fcpoolInitiators"
	FCPOOL_POOLABLE = "fcpoolPoolable"
	FCPOOL_UNIVERSE = "fcpoolUniverse"
	FILTER_FILTER = "filterFilter"
	FIRMWARE_ACK = "firmwareAck"
	FIRMWARE_AUTO_SYNC_POLICY = "firmwareAutoSyncPolicy"
	FIRMWARE_BLADE = "firmwareBlade"
	FIRMWARE_BOOT_DEFINITION = "firmwareBootDefinition"
	FIRMWARE_BOOT_UNIT = "firmwareBootUnit"
	FIRMWARE_BUNDLE_INFO = "firmwareBundleInfo"
	FIRMWARE_BUNDLE_INFO_DIGEST = "firmwareBundleInfoDigest"
	FIRMWARE_BUNDLE_TYPE = "firmwareBundleType"
	FIRMWARE_BUNDLE_TYPE_CAP_PROVIDER = "firmwareBundleTypeCapProvider"
	FIRMWARE_CATALOG_PACK = "firmwareCatalogPack"
	FIRMWARE_CATALOGUE = "firmwareCatalogue"
	FIRMWARE_COMP_SOURCE = "firmwareCompSource"
	FIRMWARE_COMP_TARGET = "firmwareCompTarget"
	FIRMWARE_COMPUTE_HOST_PACK = "firmwareComputeHostPack"
	FIRMWARE_COMPUTE_MGMT_PACK = "firmwareComputeMgmtPack"
	FIRMWARE_DEPENDENCY = "firmwareDependency"
	FIRMWARE_DIST_IMAGE = "firmwareDistImage"
	FIRMWARE_DISTRIBUTABLE = "firmwareDistributable"
	FIRMWARE_DISTRIBUTABLE_FSM = "firmwareDistributableFsm"
	FIRMWARE_DISTRIBUTABLE_FSM_STAGE = "firmwareDistributableFsmStage"
	FIRMWARE_DISTRIBUTABLE_FSM_TASK = "firmwareDistributableFsmTask"
	FIRMWARE_DOWNLOADER = "firmwareDownloader"
	FIRMWARE_DOWNLOADER_FSM = "firmwareDownloaderFsm"
	FIRMWARE_DOWNLOADER_FSM_STAGE = "firmwareDownloaderFsmStage"
	FIRMWARE_DOWNLOADER_FSM_TASK = "firmwareDownloaderFsmTask"
	FIRMWARE_HOST = "firmwareHost"
	FIRMWARE_HOST_PACK_MOD_IMPACT = "firmwareHostPackModImpact"
	FIRMWARE_IMAGE = "firmwareImage"
	FIRMWARE_IMAGE_FSM = "firmwareImageFsm"
	FIRMWARE_IMAGE_FSM_STAGE = "firmwareImageFsmStage"
	FIRMWARE_IMAGE_FSM_TASK = "firmwareImageFsmTask"
	FIRMWARE_INFRA = "firmwareInfra"
	FIRMWARE_INFRA_PACK = "firmwareInfraPack"
	FIRMWARE_INSTALL_IMPACT = "firmwareInstallImpact"
	FIRMWARE_INSTALLABLE = "firmwareInstallable"
	FIRMWARE_PACK_ITEM = "firmwarePackItem"
	FIRMWARE_RACK = "firmwareRack"
	FIRMWARE_RUNNING = "firmwareRunning"
	FIRMWARE_SPEC = "firmwareSpec"
	FIRMWARE_STATUS = "firmwareStatus"
	FIRMWARE_SYSTEM = "firmwareSystem"
	FIRMWARE_SYSTEM_COMP_CHECK_RESULT = "firmwareSystemCompCheckResult"
	FIRMWARE_SYSTEM_FSM = "firmwareSystemFsm"
	FIRMWARE_SYSTEM_FSM_STAGE = "firmwareSystemFsmStage"
	FIRMWARE_SYSTEM_FSM_TASK = "firmwareSystemFsmTask"
	FIRMWARE_TYPE = "firmwareType"
	FIRMWARE_UPDATABLE = "firmwareUpdatable"
	FIRMWARE_UPGRADE_CONSTRAINT = "firmwareUpgradeConstraint"
	FIRMWARE_UPGRADE_DETAIL = "firmwareUpgradeDetail"
	FIRMWARE_UPGRADE_INFO = "firmwareUpgradeInfo"
	FLOWCTRL_DEFINITION = "flowctrlDefinition"
	FLOWCTRL_ITEM = "flowctrlItem"
	FSM_DEBUG_ACTION = "fsmDebugAction"
	FSM_STATUS = "fsmStatus"
	GE_FILTER = "geFilter"
	GMETA_CLASS = "gmetaClass"
	GMETA_EP = "gmetaEp"
	GMETA_HOLDER = "gmetaHolder"
	GMETA_HOLDER_FSM = "gmetaHolderFsm"
	GMETA_HOLDER_FSM_STAGE = "gmetaHolderFsmStage"
	GMETA_HOLDER_FSM_TASK = "gmetaHolderFsmTask"
	GMETA_POLICY_MAP_ELEMENT = "gmetaPolicyMapElement"
	GMETA_POLICY_MAP_HOLDER = "gmetaPolicyMapHolder"
	GMETA_PROP = "gmetaProp"
	GRAPHICS_CARD = "graphicsCard"
	GRAPHICS_CONTROLLER = "graphicsController"
	GT_FILTER = "gtFilter"
	HOSTIMG_POLICY = "hostimgPolicy"
	HOSTIMG_TARGET = "hostimgTarget"
	ID = "id"
	ID_SET = "idSet"
	IDENT_IDENT_CTX = "identIdentCtx"
	IDENT_IDENT_REQUEST = "identIdentRequest"
	IDENT_IDENT_REQUEST_FSM = "identIdentRequestFsm"
	IDENT_IDENT_REQUEST_FSM_STAGE = "identIdentRequestFsmStage"
	IDENT_IDENT_REQUEST_FSM_TASK = "identIdentRequestFsmTask"
	IDENT_META_SYSTEM = "identMetaSystem"
	IDENT_META_SYSTEM_FSM = "identMetaSystemFsm"
	IDENT_META_SYSTEM_FSM_STAGE = "identMetaSystemFsmStage"
	IDENT_META_SYSTEM_FSM_TASK = "identMetaSystemFsmTask"
	IDENT_META_VERSE = "identMetaVerse"
	IDENT_REQUEST_EP = "identRequestEp"
	IDENT_SYS_INFO = "identSysInfo"
	IMGPROV_POLICY = "imgprovPolicy"
	IMGPROV_TARGET = "imgprovTarget"
	IMGSEC_KEY = "imgsecKey"
	IMGSEC_POLICY = "imgsecPolicy"
	INITIATOR_FC_INITIATOR_EP = "initiatorFcInitiatorEp"
	INITIATOR_GROUP_EP = "initiatorGroupEp"
	INITIATOR_ISCSI_INITIATOR_EP = "initiatorIScsiInitiatorEp"
	INITIATOR_LUN_EP = "initiatorLunEp"
	INITIATOR_MEMBER_EP = "initiatorMemberEp"
	INITIATOR_REQUESTOR_EP = "initiatorRequestorEp"
	INITIATOR_REQUESTOR_GRP_EP = "initiatorRequestorGrpEp"
	INITIATOR_STORE_EP = "initiatorStoreEp"
	INITIATOR_UNIT_EP = "initiatorUnitEp"
	IP_DNS_SUFFIX = "ipDnsSuffix"
	IP_IPV4_DNS = "ipIPv4Dns"
	IP_IPV4_WINS_SERVER = "ipIPv4WinsServer"
	IP_IP_V4_STATIC_ADDR = "ipIpV4StaticAddr"
	IP_IP_V4_STATIC_TARGET_ADDR = "ipIpV4StaticTargetAddr"
	IP_SERVICE_IF = "ipServiceIf"
	IPPOOL_ADDR = "ippoolAddr"
	IPPOOL_BLOCK = "ippoolBlock"
	IPPOOL_IP_V6_ADDR = "ippoolIpV6Addr"
	IPPOOL_IP_V6_BLOCK = "ippoolIpV6Block"
	IPPOOL_IP_V6_POOLED = "ippoolIpV6Pooled"
	IPPOOL_POOL = "ippoolPool"
	IPPOOL_POOLABLE = "ippoolPoolable"
	IPPOOL_POOLED = "ippoolPooled"
	IPPOOL_UNIVERSE = "ippoolUniverse"
	IQNPOOL_ADDR = "iqnpoolAddr"
	IQNPOOL_BLOCK = "iqnpoolBlock"
	IQNPOOL_FORMAT = "iqnpoolFormat"
	IQNPOOL_POOL = "iqnpoolPool"
	IQNPOOL_POOLABLE = "iqnpoolPoolable"
	IQNPOOL_POOLED = "iqnpoolPooled"
	IQNPOOL_UNIVERSE = "iqnpoolUniverse"
	ISCSI_AUTH_PROFILE = "iscsiAuthProfile"
	LE_FILTER = "leFilter"
	LICENSE_CONTENTS = "licenseContents"
	LICENSE_DOWNLOADER = "licenseDownloader"
	LICENSE_DOWNLOADER_FSM = "licenseDownloaderFsm"
	LICENSE_DOWNLOADER_FSM_STAGE = "licenseDownloaderFsmStage"
	LICENSE_DOWNLOADER_FSM_TASK = "licenseDownloaderFsmTask"
	LICENSE_EP = "licenseEp"
	LICENSE_FEATURE = "licenseFeature"
	LICENSE_FEATURE_CAP_PROVIDER = "licenseFeatureCapProvider"
	LICENSE_FEATURE_LINE = "licenseFeatureLine"
	LICENSE_FILE = "licenseFile"
	LICENSE_FILE_FSM = "licenseFileFsm"
	LICENSE_FILE_FSM_STAGE = "licenseFileFsmStage"
	LICENSE_FILE_FSM_TASK = "licenseFileFsmTask"
	LICENSE_INSTANCE = "licenseInstance"
	LICENSE_INSTANCE_FSM = "licenseInstanceFsm"
	LICENSE_INSTANCE_FSM_STAGE = "licenseInstanceFsmStage"
	LICENSE_INSTANCE_FSM_TASK = "licenseInstanceFsmTask"
	LICENSE_PROP = "licenseProp"
	LICENSE_SERVER_HOST_ID = "licenseServerHostId"
	LICENSE_SOURCE = "licenseSource"
	LICENSE_SOURCE_FILE = "licenseSourceFile"
	LLDP_ACQUIRED = "lldpAcquired"
	LOGGING_SYNC_OCNS = "loggingSyncOcns"
	LS_AGENT_POLICY = "lsAgentPolicy"
	LS_BINDING = "lsBinding"
	LS_CLONE = "lsClone"
	LS_FC_LOCALE = "lsFcLocale"
	LS_FC_ZONE = "lsFcZone"
	LS_FC_ZONE_GROUP = "lsFcZoneGroup"
	LS_INSTANTIATE_NNAMED_TEMPLATE = "lsInstantiateNNamedTemplate"
	LS_INSTANTIATE_NTEMPLATE = "lsInstantiateNTemplate"
	LS_INSTANTIATE_TEMPLATE = "lsInstantiateTemplate"
	LS_ISSUES = "lsIssues"
	LS_POWER = "lsPower"
	LS_REQUIREMENT = "lsRequirement"
	LS_RESOLVE_TEMPLATES = "lsResolveTemplates"
	LS_SERVER = "lsServer"
	LS_SERVER_ASSOC_CTX = "lsServerAssocCtx"
	LS_SERVER_EXTENSION = "lsServerExtension"
	LS_SERVER_FSM = "lsServerFsm"
	LS_SERVER_FSM_STAGE = "lsServerFsmStage"
	LS_SERVER_FSM_TASK = "lsServerFsmTask"
	LS_TEMPLATISE = "lsTemplatise"
	LS_TIER = "lsTier"
	LS_UUID_HISTORY = "lsUuidHistory"
	LS_VCON_ASSIGN = "lsVConAssign"
	LS_VERSION_BEH = "lsVersionBeh"
	LS_ZONE_INITIATOR_MEMBER = "lsZoneInitiatorMember"
	LS_ZONE_TARGET_MEMBER = "lsZoneTargetMember"
	LSBOOT_BOOT_SECURITY = "lsbootBootSecurity"
	LSBOOT_DEF = "lsbootDef"
	LSBOOT_DEFAULT_LOCAL_IMAGE = "lsbootDefaultLocalImage"
	LSBOOT_ISCSI = "lsbootIScsi"
	LSBOOT_ISCSI_IMAGE_PATH = "lsbootIScsiImagePath"
	LSBOOT_LAN = "lsbootLan"
	LSBOOT_LAN_IMAGE_PATH = "lsbootLanImagePath"
	LSBOOT_LOCAL_HDD_IMAGE = "lsbootLocalHddImage"
	LSBOOT_LOCAL_STORAGE = "lsbootLocalStorage"
	LSBOOT_POLICY = "lsbootPolicy"
	LSBOOT_SAN = "lsbootSan"
	LSBOOT_SAN_CAT_SAN_IMAGE = "lsbootSanCatSanImage"
	LSBOOT_SAN_CAT_SAN_IMAGE_PATH = "lsbootSanCatSanImagePath"
	LSBOOT_SAN_IMAGE = "lsbootSanImage"
	LSBOOT_SAN_IMAGE_PATH = "lsbootSanImagePath"
	LSBOOT_STORAGE = "lsbootStorage"
	LSBOOT_USB_EXTERNAL_IMAGE = "lsbootUsbExternalImage"
	LSBOOT_USB_FLASH_STORAGE_IMAGE = "lsbootUsbFlashStorageImage"
	LSBOOT_USB_INTERNAL_IMAGE = "lsbootUsbInternalImage"
	LSBOOT_VIRTUAL_MEDIA = "lsbootVirtualMedia"
	LSMAINT_ACK = "lsmaintAck"
	LSMAINT_MAINT_POLICY = "lsmaintMaintPolicy"
	LT_FILTER = "ltFilter"
	MACPOOL_ADDR = "macpoolAddr"
	MACPOOL_BLOCK = "macpoolBlock"
	MACPOOL_FORMAT = "macpoolFormat"
	MACPOOL_POOL = "macpoolPool"
	MACPOOL_POOLABLE = "macpoolPoolable"
	MACPOOL_POOLED = "macpoolPooled"
	MACPOOL_UNIVERSE = "macpoolUniverse"
	MEMORY_ARRAY = "memoryArray"
	MEMORY_ARRAY_ENV_STATS = "memoryArrayEnvStats"
	MEMORY_ARRAY_ENV_STATS_HIST = "memoryArrayEnvStatsHist"
	MEMORY_BUFFER_UNIT = "memoryBufferUnit"
	MEMORY_BUFFER_UNIT_ENV_STATS = "memoryBufferUnitEnvStats"
	MEMORY_BUFFER_UNIT_ENV_STATS_HIST = "memoryBufferUnitEnvStatsHist"
	MEMORY_ERROR_STATS = "memoryErrorStats"
	MEMORY_QUAL = "memoryQual"
	MEMORY_RUNTIME = "memoryRuntime"
	MEMORY_RUNTIME_HIST = "memoryRuntimeHist"
	MEMORY_UNIT = "memoryUnit"
	MEMORY_UNIT_ENV_STATS = "memoryUnitEnvStats"
	MEMORY_UNIT_ENV_STATS_HIST = "memoryUnitEnvStatsHist"
	METHOD_VESSEL = "methodVessel"
	MGMT_ACCESS_POLICY = "mgmtAccessPolicy"
	MGMT_ACCESS_POLICY_ITEM = "mgmtAccessPolicyItem"
	MGMT_ACCESS_PORT = "mgmtAccessPort"
	MGMT_BACKUP = "mgmtBackup"
	MGMT_BACKUP_FSM = "mgmtBackupFsm"
	MGMT_BACKUP_FSM_STAGE = "mgmtBackupFsmStage"
	MGMT_BACKUP_FSM_TASK = "mgmtBackupFsmTask"
	MGMT_BACKUP_POLICY = "mgmtBackupPolicy"
	MGMT_BACKUP_POLICY_FSM = "mgmtBackupPolicyFsm"
	MGMT_BACKUP_POLICY_FSM_STAGE = "mgmtBackupPolicyFsmStage"
	MGMT_CFG_EXPORT_POLICY = "mgmtCfgExportPolicy"
	MGMT_CFG_EXPORT_POLICY_FSM = "mgmtCfgExportPolicyFsm"
	MGMT_CFG_EXPORT_POLICY_FSM_STAGE = "mgmtCfgExportPolicyFsmStage"
	MGMT_CONNECTION = "mgmtConnection"
	MGMT_CONTROLLER = "mgmtController"
	MGMT_CONTROLLER_FSM = "mgmtControllerFsm"
	MGMT_CONTROLLER_FSM_STAGE = "mgmtControllerFsmStage"
	MGMT_CONTROLLER_FSM_TASK = "mgmtControllerFsmTask"
	MGMT_ENTITY = "mgmtEntity"
	MGMT_EXPORT_POLICY_FSM = "mgmtExportPolicyFsm"
	MGMT_EXPORT_POLICY_FSM_STAGE = "mgmtExportPolicyFsmStage"
	MGMT_EXPORT_POLICY_FSM_TASK = "mgmtExportPolicyFsmTask"
	MGMT_IPV6_IF_ADDR = "mgmtIPv6IfAddr"
	MGMT_IPV6_IF_ADDR_FSM = "mgmtIPv6IfAddrFsm"
	MGMT_IPV6_IF_ADDR_FSM_STAGE = "mgmtIPv6IfAddrFsmStage"
	MGMT_IPV6_IF_ADDR_FSM_TASK = "mgmtIPv6IfAddrFsmTask"
	MGMT_IPV6_IF_CONFIG = "mgmtIPv6IfConfig"
	MGMT_IF = "mgmtIf"
	MGMT_IF_FSM = "mgmtIfFsm"
	MGMT_IF_FSM_STAGE = "mgmtIfFsmStage"
	MGMT_IF_FSM_TASK = "mgmtIfFsmTask"
	MGMT_IMPORTER = "mgmtImporter"
	MGMT_IMPORTER_FSM = "mgmtImporterFsm"
	MGMT_IMPORTER_FSM_STAGE = "mgmtImporterFsmStage"
	MGMT_IMPORTER_FSM_TASK = "mgmtImporterFsmTask"
	MGMT_INBAND_PROFILE = "mgmtInbandProfile"
	MGMT_INT_AUTH_POLICY = "mgmtIntAuthPolicy"
	MGMT_INTERFACE = "mgmtInterface"
	MGMT_PMON_ENTRY = "mgmtPmonEntry"
	MGMT_PROF_DERIVED_INTERFACE = "mgmtProfDerivedInterface"
	MGMT_RESOLVE_BACKUP_FILENAMES = "mgmtResolveBackupFilenames"
	MGMT_VNET = "mgmtVnet"
	NE_FILTER = "neFilter"
	NETWORK_ELEMENT = "networkElement"
	NETWORK_IF_STATS = "networkIfStats"
	NETWORK_OPER_LEVEL = "networkOperLevel"
	NFS_EP = "nfsEp"
	NFS_MOUNT_DEF = "nfsMountDef"
	NFS_MOUNT_DEF_FSM = "nfsMountDefFsm"
	NFS_MOUNT_DEF_FSM_STAGE = "nfsMountDefFsmStage"
	NFS_MOUNT_DEF_FSM_TASK = "nfsMountDefFsmTask"
	NFS_MOUNT_INST = "nfsMountInst"
	NFS_MOUNT_INST_FSM = "nfsMountInstFsm"
	NFS_MOUNT_INST_FSM_STAGE = "nfsMountInstFsmStage"
	NFS_MOUNT_INST_FSM_TASK = "nfsMountInstFsmTask"
	NOT_FILTER = "notFilter"
	NWCTRL_DEFINITION = "nwctrlDefinition"
	OBSERVE_FILTER = "observeFilter"
	OBSERVE_OBSERVED = "observeObserved"
	OBSERVE_OBSERVED_CONT = "observeObservedCont"
	OBSERVE_OBSERVED_FSM = "observeObservedFsm"
	OBSERVE_OBSERVED_FSM_STAGE = "observeObservedFsmStage"
	OBSERVE_OBSERVED_FSM_TASK = "observeObservedFsmTask"
	OR_FILTER = "orFilter"
	ORG_ORG = "orgOrg"
	ORG_RESOLVE_ELEMENTS = "orgResolveElements"
	ORG_RESOLVE_LOGICAL_PARENTS = "orgResolveLogicalParents"
	ORG_SOURCE_MASK = "orgSourceMask"
	OS_AGENT = "osAgent"
	OS_INSTANCE = "osInstance"
	PAIR = "pair"
	PCI_EQUIP_SLOT = "pciEquipSlot"
	PCI_UNIT = "pciUnit"
	PKI_CERT_REQ = "pkiCertReq"
	PKI_EP = "pkiEp"
	PKI_EP_FSM = "pkiEpFsm"
	PKI_EP_FSM_STAGE = "pkiEpFsmStage"
	PKI_EP_FSM_TASK = "pkiEpFsmTask"
	PKI_KEY_RING = "pkiKeyRing"
	PKI_TP = "pkiTP"
	POLICY_CENTRALE_SYNC = "policyCentraleSync"
	POLICY_COMMUNICATION = "policyCommunication"
	POLICY_CONFIG_BACKUP = "policyConfigBackup"
	POLICY_CONTROL_EP = "policyControlEp"
	POLICY_CONTROL_EP_FSM = "policyControlEpFsm"
	POLICY_CONTROL_EP_FSM_STAGE = "policyControlEpFsmStage"
	POLICY_CONTROL_EP_FSM_TASK = "policyControlEpFsmTask"
	POLICY_CONTROLLED_INSTANCE = "policyControlledInstance"
	POLICY_CONTROLLED_TYPE = "policyControlledType"
	POLICY_CONTROLLED_TYPE_FSM = "policyControlledTypeFsm"
	POLICY_CONTROLLED_TYPE_FSM_STAGE = "policyControlledTypeFsmStage"
	POLICY_CONTROLLED_TYPE_FSM_TASK = "policyControlledTypeFsmTask"
	POLICY_DATE_TIME = "policyDateTime"
	POLICY_DIGEST = "policyDigest"
	POLICY_DISCOVERY = "policyDiscovery"
	POLICY_DNS = "policyDns"
	POLICY_ELEMENT = "policyElement"
	POLICY_FAULT = "policyFault"
	POLICY_INFRA_FIRMWARE = "policyInfraFirmware"
	POLICY_LOCAL_MAP = "policyLocalMap"
	POLICY_MEP = "policyMEp"
	POLICY_MONITORING = "policyMonitoring"
	POLICY_POLICY_EP = "policyPolicyEp"
	POLICY_POLICY_REQUESTOR = "policyPolicyRequestor"
	POLICY_POLICY_SCOPE = "policyPolicyScope"
	POLICY_POLICY_SCOPE_CONT = "policyPolicyScopeCont"
	POLICY_POLICY_SCOPE_CONTEXT = "policyPolicyScopeContext"
	POLICY_POLICY_SCOPE_FSM = "policyPolicyScopeFsm"
	POLICY_POLICY_SCOPE_FSM_STAGE = "policyPolicyScopeFsmStage"
	POLICY_POLICY_SCOPE_FSM_TASK = "policyPolicyScopeFsmTask"
	POLICY_POWER_MGMT = "policyPowerMgmt"
	POLICY_PSU = "policyPsu"
	POLICY_REF_REQ = "policyRefReq"
	POLICY_RESOLVE_NAMES = "policyResolveNames"
	POLICY_SECURITY = "policySecurity"
	POLICY_SET_CENTRALE_STORAGE = "policySetCentraleStorage"
	POOL_RESOLVE_IN_SCOPE = "poolResolveInScope"
	PORT_DOMAIN_EP = "portDomainEp"
	PORT_GROUP = "portGroup"
	PORT_PIO_FSM = "portPIoFsm"
	PORT_PIO_FSM_STAGE = "portPIoFsmStage"
	PORT_PIO_FSM_TASK = "portPIoFsmTask"
	PORT_TRUST_MODE = "portTrustMode"
	POWER_BUDGET = "powerBudget"
	POWER_CHASSIS_MEMBER = "powerChassisMember"
	POWER_EP = "powerEp"
	POWER_GROUP = "powerGroup"
	POWER_GROUP_ADDITION_POLICY = "powerGroupAdditionPolicy"
	POWER_GROUP_QUAL = "powerGroupQual"
	POWER_GROUP_STATS = "powerGroupStats"
	POWER_GROUP_STATS_HIST = "powerGroupStatsHist"
	POWER_MGMT_POLICY = "powerMgmtPolicy"
	POWER_PLACEMENT = "powerPlacement"
	POWER_POLICY = "powerPolicy"
	POWER_PRIO_WGHT = "powerPrioWght"
	POWER_RACK_UNIT_MEMBER = "powerRackUnitMember"
	PROC_DOER = "procDoer"
	PROC_MANAGER = "procManager"
	PROC_PRT = "procPrt"
	PROC_PRT_COUNTS = "procPrtCounts"
	PROC_STIMULUS_COUNTS = "procStimulusCounts"
	PROC_SVC = "procSvc"
	PROC_TX_COUNTS = "procTxCounts"
	PROCESSOR_CORE = "processorCore"
	PROCESSOR_ENV_STATS = "processorEnvStats"
	PROCESSOR_ENV_STATS_HIST = "processorEnvStatsHist"
	PROCESSOR_ERROR_STATS = "processorErrorStats"
	PROCESSOR_QUAL = "processorQual"
	PROCESSOR_RUNTIME = "processorRuntime"
	PROCESSOR_RUNTIME_HIST = "processorRuntimeHist"
	PROCESSOR_THREAD = "processorThread"
	PROCESSOR_UNIT = "processorUnit"
	PROCESSOR_UNIT_ASSOC_CTX = "processorUnitAssocCtx"
	QOSCLASS_DEFINITION = "qosclassDefinition"
	QOSCLASS_DEFINITION_FSM = "qosclassDefinitionFsm"
	QOSCLASS_DEFINITION_FSM_STAGE = "qosclassDefinitionFsmStage"
	QOSCLASS_DEFINITION_FSM_TASK = "qosclassDefinitionFsmTask"
	QOSCLASS_ETH_BE = "qosclassEthBE"
	QOSCLASS_ETH_CLASSIFIED = "qosclassEthClassified"
	QOSCLASS_FC = "qosclassFc"
	QUERYRESULT_DEPENDENCY = "queryresultDependency"
	QUERYRESULT_USAGE = "queryresultUsage"
	SOL_CONFIG = "solConfig"
	SOL_IF = "solIf"
	SOL_POLICY = "solPolicy"
	STATS_CLEAR_INTERVAL = "statsClearInterval"
	STATS_COLLECTION_POLICY = "statsCollectionPolicy"
	STATS_COLLECTION_POLICY_FSM = "statsCollectionPolicyFsm"
	STATS_COLLECTION_POLICY_FSM_STAGE = "statsCollectionPolicyFsmStage"
	STATS_COLLECTION_POLICY_FSM_TASK = "statsCollectionPolicyFsmTask"
	STATS_HOLDER = "statsHolder"
	STATS_RESOLVE_THRESHOLD_POLICY = "statsResolveThresholdPolicy"
	STATS_SUBSCRIBE = "statsSubscribe"
	STATS_THR32_DEFINITION = "statsThr32Definition"
	STATS_THR32_VALUE = "statsThr32Value"
	STATS_THR64_DEFINITION = "statsThr64Definition"
	STATS_THR64_VALUE = "statsThr64Value"
	STATS_THR_FLOAT_DEFINITION = "statsThrFloatDefinition"
	STATS_THR_FLOAT_VALUE = "statsThrFloatValue"
	STATS_THRESHOLD_CLASS = "statsThresholdClass"
	STATS_THRESHOLD_POLICY = "statsThresholdPolicy"
	STORAGE_AUTH_KEY = "storageAuthKey"
	STORAGE_CONNECTION_DEF = "storageConnectionDef"
	STORAGE_CONNECTION_POLICY = "storageConnectionPolicy"
	STORAGE_CONTROLLER = "storageController"
	STORAGE_DOMAIN_EP = "storageDomainEp"
	STORAGE_DRIVE = "storageDrive"
	STORAGE_ENCLOSURE = "storageEnclosure"
	STORAGE_EP_USER = "storageEpUser"
	STORAGE_ETHER_IF = "storageEtherIf"
	STORAGE_FC_IF = "storageFcIf"
	STORAGE_FC_TARGET_EP = "storageFcTargetEp"
	STORAGE_FC_TARGET_IF = "storageFcTargetIf"
	STORAGE_FLEX_FLASH_CARD = "storageFlexFlashCard"
	STORAGE_FLEX_FLASH_CONTROLLER = "storageFlexFlashController"
	STORAGE_FLEX_FLASH_DRIVE = "storageFlexFlashDrive"
	STORAGE_FLEX_FLASH_VIRTUAL_DRIVE = "storageFlexFlashVirtualDrive"
	STORAGE_ISCSI_TARGET_IF = "storageIScsiTargetIf"
	STORAGE_INI_GROUP = "storageIniGroup"
	STORAGE_INITIATOR = "storageInitiator"
	STORAGE_ITEM = "storageItem"
	STORAGE_LOCAL_DISK = "storageLocalDisk"
	STORAGE_LOCAL_DISK_CONFIG_DEF = "storageLocalDiskConfigDef"
	STORAGE_LOCAL_DISK_CONFIG_POLICY = "storageLocalDiskConfigPolicy"
	STORAGE_LOCAL_DISK_PARTITION = "storageLocalDiskPartition"
	STORAGE_LOCAL_DISK_SLOT_EP = "storageLocalDiskSlotEp"
	STORAGE_LOCAL_LUN = "storageLocalLun"
	STORAGE_LUN_DISK = "storageLunDisk"
	STORAGE_NODE_EP = "storageNodeEp"
	STORAGE_OPERATION = "storageOperation"
	STORAGE_QUAL = "storageQual"
	STORAGE_RAID_BATTERY = "storageRaidBattery"
	STORAGE_SYSTEM = "storageSystem"
	STORAGE_SYSTEM_FSM = "storageSystemFsm"
	STORAGE_SYSTEM_FSM_STAGE = "storageSystemFsmStage"
	STORAGE_SYSTEM_FSM_TASK = "storageSystemFsmTask"
	STORAGE_TRANSPORTABLE_FLASH_MODULE = "storageTransportableFlashModule"
	STORAGE_VIRTUAL_DRIVE = "storageVirtualDrive"
	STORAGE_VSAN_REF = "storageVsanRef"
	SW_ACCESS_DOMAIN = "swAccessDomain"
	SW_ACCESS_DOMAIN_FSM = "swAccessDomainFsm"
	SW_ACCESS_DOMAIN_FSM_STAGE = "swAccessDomainFsmStage"
	SW_ACCESS_DOMAIN_FSM_TASK = "swAccessDomainFsmTask"
	SW_ACCESS_EP = "swAccessEp"
	SW_CARD_ENV_STATS = "swCardEnvStats"
	SW_CARD_ENV_STATS_HIST = "swCardEnvStatsHist"
	SW_CMCLAN = "swCmclan"
	SW_ENV_STATS = "swEnvStats"
	SW_ENV_STATS_HIST = "swEnvStatsHist"
	SW_ETH_ESTC_EP = "swEthEstcEp"
	SW_ETH_ESTC_PC = "swEthEstcPc"
	SW_ETH_LAN_BORDER = "swEthLanBorder"
	SW_ETH_LAN_BORDER_FSM = "swEthLanBorderFsm"
	SW_ETH_LAN_BORDER_FSM_STAGE = "swEthLanBorderFsmStage"
	SW_ETH_LAN_BORDER_FSM_TASK = "swEthLanBorderFsmTask"
	SW_ETH_LAN_EP = "swEthLanEp"
	SW_ETH_LAN_FLOW_MON = "swEthLanFlowMon"
	SW_ETH_LAN_FLOW_MON_FSM = "swEthLanFlowMonFsm"
	SW_ETH_LAN_FLOW_MON_FSM_STAGE = "swEthLanFlowMonFsmStage"
	SW_ETH_LAN_FLOW_MON_FSM_TASK = "swEthLanFlowMonFsmTask"
	SW_ETH_LAN_MON = "swEthLanMon"
	SW_ETH_LAN_PC = "swEthLanPc"
	SW_ETH_MON = "swEthMon"
	SW_ETH_MON_DEST_EP = "swEthMonDestEp"
	SW_ETH_MON_FSM = "swEthMonFsm"
	SW_ETH_MON_FSM_STAGE = "swEthMonFsmStage"
	SW_ETH_MON_FSM_TASK = "swEthMonFsmTask"
	SW_ETH_MON_SRC_EP = "swEthMonSrcEp"
	SW_ETH_TARGET_EP = "swEthTargetEp"
	SW_FABRIC_ZONE_NS = "swFabricZoneNs"
	SW_FABRIC_ZONE_NS_OVERRIDE = "swFabricZoneNsOverride"
	SW_FC_ESTC_EP = "swFcEstcEp"
	SW_FC_MON = "swFcMon"
	SW_FC_MON_DEST_EP = "swFcMonDestEp"
	SW_FC_MON_FSM = "swFcMonFsm"
	SW_FC_MON_FSM_STAGE = "swFcMonFsmStage"
	SW_FC_MON_FSM_TASK = "swFcMonFsmTask"
	SW_FC_MON_SRC_EP = "swFcMonSrcEp"
	SW_FC_SAN_BORDER = "swFcSanBorder"
	SW_FC_SAN_BORDER_FSM = "swFcSanBorderFsm"
	SW_FC_SAN_BORDER_FSM_STAGE = "swFcSanBorderFsmStage"
	SW_FC_SAN_BORDER_FSM_TASK = "swFcSanBorderFsmTask"
	SW_FC_SAN_EP = "swFcSanEp"
	SW_FC_SAN_MON = "swFcSanMon"
	SW_FC_SAN_PC = "swFcSanPc"
	SW_FC_SERVER_ZONE_GROUP = "swFcServerZoneGroup"
	SW_FC_ZONE = "swFcZone"
	SW_FC_ZONE_SET = "swFcZoneSet"
	SW_FCOE_ESTC_EP = "swFcoeEstcEp"
	SW_FCOE_SAN_EP = "swFcoeSanEp"
	SW_FCOE_SAN_PC = "swFcoeSanPc"
	SW_IP_ROUTE = "swIpRoute"
	SW_NFEXPORTER_REF = "swNFExporterRef"
	SW_NETFLOW_EXPORTER = "swNetflowExporter"
	SW_NETFLOW_MON_SESSION = "swNetflowMonSession"
	SW_NETFLOW_MONITOR = "swNetflowMonitor"
	SW_NETFLOW_MONITOR_REF = "swNetflowMonitorRef"
	SW_NETFLOW_RECORD_DEF = "swNetflowRecordDef"
	SW_PHYS = "swPhys"
	SW_PHYS_ETHER_EP = "swPhysEtherEp"
	SW_PHYS_FC_EP = "swPhysFcEp"
	SW_PHYS_FSM = "swPhysFsm"
	SW_PHYS_FSM_STAGE = "swPhysFsmStage"
	SW_PHYS_FSM_TASK = "swPhysFsmTask"
	SW_SYSTEM_STATS = "swSystemStats"
	SW_SYSTEM_STATS_HIST = "swSystemStatsHist"
	SW_ULAN = "swUlan"
	SW_UTILITY_DOMAIN = "swUtilityDomain"
	SW_UTILITY_DOMAIN_FSM = "swUtilityDomainFsm"
	SW_UTILITY_DOMAIN_FSM_STAGE = "swUtilityDomainFsmStage"
	SW_UTILITY_DOMAIN_FSM_TASK = "swUtilityDomainFsmTask"
	SW_VIRT_L3_INTF = "swVirtL3Intf"
	SW_VLAN = "swVlan"
	SW_VLAN_GROUP = "swVlanGroup"
	SW_VLAN_PORT_NS = "swVlanPortNs"
	SW_VLAN_PORT_NS_OVERRIDE = "swVlanPortNsOverride"
	SW_VLAN_REF = "swVlanRef"
	SW_VSAN = "swVsan"
	SW_ZONE_INITIATOR_MEMBER = "swZoneInitiatorMember"
	SW_ZONE_TARGET_MEMBER = "swZoneTargetMember"
	SWAT_ACTION = "swatAction"
	SWAT_CONDITION = "swatCondition"
	SWAT_EXAMPLE = "swatExample"
	SWAT_GETSTATS = "swatGetstats"
	SWAT_INJECT = "swatInject"
	SWAT_INJECTION = "swatInjection"
	SWAT_RESULTSTATS = "swatResultstats"
	SWAT_TARGET = "swatTarget"
	SWAT_TRIGGER = "swatTrigger"
	SYNTHETIC_DIRECTORY = "syntheticDirectory"
	SYNTHETIC_FSOBJ_INVENTORY = "syntheticFSObjInventory"
	SYNTHETIC_FSOBJ_INVENTORY_B = "syntheticFSObjInventoryB"
	SYNTHETIC_FILE = "syntheticFile"
	SYNTHETIC_FILE_SYSTEM = "syntheticFileSystem"
	SYNTHETIC_FS_OBJ = "syntheticFsObj"
	SYNTHETIC_FS_OBJ_FSM = "syntheticFsObjFsm"
	SYNTHETIC_FS_OBJ_FSM_STAGE = "syntheticFsObjFsmStage"
	SYNTHETIC_FS_OBJ_FSM_TASK = "syntheticFsObjFsmTask"
	SYNTHETIC_TEST_TX = "syntheticTestTx"
	SYNTHETIC_TIME = "syntheticTime"
	SYSDEBUG_AUTO_CORE_FILE_EXPORT_TARGET = "sysdebugAutoCoreFileExportTarget"
	SYSDEBUG_AUTO_CORE_FILE_EXPORT_TARGET_FSM = "sysdebugAutoCoreFileExportTargetFsm"
	SYSDEBUG_AUTO_CORE_FILE_EXPORT_TARGET_FSM_STAGE = "sysdebugAutoCoreFileExportTargetFsmStage"
	SYSDEBUG_AUTO_CORE_FILE_EXPORT_TARGET_FSM_TASK = "sysdebugAutoCoreFileExportTargetFsmTask"
	SYSDEBUG_BACKUP_BEHAVIOR = "sysdebugBackupBehavior"
	SYSDEBUG_CORE = "sysdebugCore"
	SYSDEBUG_CORE_FILE_REPOSITORY = "sysdebugCoreFileRepository"
	SYSDEBUG_CORE_FSM = "sysdebugCoreFsm"
	SYSDEBUG_CORE_FSM_STAGE = "sysdebugCoreFsmStage"
	SYSDEBUG_CORE_FSM_TASK = "sysdebugCoreFsmTask"
	SYSDEBUG_EP = "sysdebugEp"
	SYSDEBUG_LOG_CONTROL_DESTINATION_FILE = "sysdebugLogControlDestinationFile"
	SYSDEBUG_LOG_CONTROL_DESTINATION_SYSLOG = "sysdebugLogControlDestinationSyslog"
	SYSDEBUG_LOG_CONTROL_DOMAIN = "sysdebugLogControlDomain"
	SYSDEBUG_LOG_CONTROL_EP = "sysdebugLogControlEp"
	SYSDEBUG_LOG_CONTROL_EP_FSM = "sysdebugLogControlEpFsm"
	SYSDEBUG_LOG_CONTROL_EP_FSM_STAGE = "sysdebugLogControlEpFsmStage"
	SYSDEBUG_LOG_CONTROL_EP_FSM_TASK = "sysdebugLogControlEpFsmTask"
	SYSDEBUG_LOG_CONTROL_MODULE = "sysdebugLogControlModule"
	SYSDEBUG_MEP_LOG = "sysdebugMEpLog"
	SYSDEBUG_MEP_LOG_POLICY = "sysdebugMEpLogPolicy"
	SYSDEBUG_MANUAL_CORE_FILE_EXPORT_TARGET = "sysdebugManualCoreFileExportTarget"
	SYSDEBUG_MANUAL_CORE_FILE_EXPORT_TARGET_FSM = "sysdebugManualCoreFileExportTargetFsm"
	SYSDEBUG_MANUAL_CORE_FILE_EXPORT_TARGET_FSM_STAGE = "sysdebugManualCoreFileExportTargetFsmStage"
	SYSDEBUG_MANUAL_CORE_FILE_EXPORT_TARGET_FSM_TASK = "sysdebugManualCoreFileExportTargetFsmTask"
	SYSDEBUG_TECH_SUP_FILE_REPOSITORY = "sysdebugTechSupFileRepository"
	SYSDEBUG_TECH_SUPPORT = "sysdebugTechSupport"
	SYSDEBUG_TECH_SUPPORT_CMD_OPT = "sysdebugTechSupportCmdOpt"
	SYSDEBUG_TECH_SUPPORT_FSM = "sysdebugTechSupportFsm"
	SYSDEBUG_TECH_SUPPORT_FSM_STAGE = "sysdebugTechSupportFsmStage"
	SYSDEBUG_TECH_SUPPORT_FSM_TASK = "sysdebugTechSupportFsmTask"
	SYSFILE_DIGEST = "sysfileDigest"
	SYSFILE_MUTATION = "sysfileMutation"
	SYSFILE_MUTATION_FSM = "sysfileMutationFsm"
	SYSFILE_MUTATION_FSM_STAGE = "sysfileMutationFsmStage"
	SYSFILE_MUTATION_FSM_TASK = "sysfileMutationFsmTask"
	TOP_META_INF = "topMetaInf"
	TOP_ROOT = "topRoot"
	TOP_SYS_DEFAULTS = "topSysDefaults"
	TOP_SYSTEM = "topSystem"
	TRIG_ABS_WINDOW = "trigAbsWindow"
	TRIG_CLIENT_TOKEN = "trigClientToken"
	TRIG_LOCAL_ABS_WINDOW = "trigLocalAbsWindow"
	TRIG_LOCAL_SCHED = "trigLocalSched"
	TRIG_META = "trigMeta"
	TRIG_PERFORM_TOKEN_ACTION = "trigPerformTokenAction"
	TRIG_RECURR_WINDOW = "trigRecurrWindow"
	TRIG_SCHED = "trigSched"
	TRIG_TEST = "trigTest"
	TRIG_TRIGGERED = "trigTriggered"
	UUIDPOOL_ADDR = "uuidpoolAddr"
	UUIDPOOL_BLOCK = "uuidpoolBlock"
	UUIDPOOL_FORMAT = "uuidpoolFormat"
	UUIDPOOL_POOL = "uuidpoolPool"
	UUIDPOOL_POOLABLE = "uuidpoolPoolable"
	UUIDPOOL_POOLED = "uuidpoolPooled"
	UUIDPOOL_UNIVERSE = "uuidpoolUniverse"
	VERSION_APPLICATION = "versionApplication"
	VERSION_EP = "versionEp"
	VM_COMPUTE_EP = "vmComputeEp"
	VM_DC = "vmDC"
	VM_DCORG = "vmDCOrg"
	VM_EP = "vmEp"
	VM_HBA = "vmHba"
	VM_HV = "vmHv"
	VM_INSTANCE = "vmInstance"
	VM_LIFE_CYCLE_POLICY = "vmLifeCyclePolicy"
	VM_LIFE_CYCLE_POLICY_FSM = "vmLifeCyclePolicyFsm"
	VM_LIFE_CYCLE_POLICY_FSM_STAGE = "vmLifeCyclePolicyFsmStage"
	VM_LIFE_CYCLE_POLICY_FSM_TASK = "vmLifeCyclePolicyFsmTask"
	VM_NIC = "vmNic"
	VM_ORG = "vmOrg"
	VM_SWITCH = "vmSwitch"
	VM_VIF = "vmVif"
	VM_VLAN = "vmVlan"
	VM_VNIC_PROF_CL = "vmVnicProfCl"
	VM_VNIC_PROF_INST = "vmVnicProfInst"
	VM_VSAN = "vmVsan"
	VNIC_BOOT_IP_POLICY = "vnicBootIpPolicy"
	VNIC_BOOT_TARGET = "vnicBootTarget"
	VNIC_CONN_DEF = "vnicConnDef"
	VNIC_DEF_BEH = "vnicDefBeh"
	VNIC_DYNAMIC_CON = "vnicDynamicCon"
	VNIC_DYNAMIC_CON_POLICY = "vnicDynamicConPolicy"
	VNIC_DYNAMIC_CON_POLICY_REF = "vnicDynamicConPolicyRef"
	VNIC_DYNAMIC_ID_UNIVERSE = "vnicDynamicIdUniverse"
	VNIC_DYNAMIC_PROVIDER = "vnicDynamicProvider"
	VNIC_DYNAMIC_PROVIDER_EP = "vnicDynamicProviderEp"
	VNIC_ETH_LIF = "vnicEthLif"
	VNIC_ETHER = "vnicEther"
	VNIC_ETHER_IF = "vnicEtherIf"
	VNIC_FC = "vnicFc"
	VNIC_FC_GROUP_DEF = "vnicFcGroupDef"
	VNIC_FC_GROUP_TEMPL = "vnicFcGroupTempl"
	VNIC_FC_IF = "vnicFcIf"
	VNIC_FC_LIF = "vnicFcLif"
	VNIC_FC_NODE = "vnicFcNode"
	VNIC_FC_OEIF = "vnicFcOEIf"
	VNIC_IPV4_DHCP = "vnicIPv4Dhcp"
	VNIC_IPV4_DNS = "vnicIPv4Dns"
	VNIC_IPV4_IF = "vnicIPv4If"
	VNIC_IPV4_ISCSI_ADDR = "vnicIPv4IscsiAddr"
	VNIC_IPV4_POOLED_ISCSI_ADDR = "vnicIPv4PooledIscsiAddr"
	VNIC_IPV4_STATIC_ROUTE = "vnicIPv4StaticRoute"
	VNIC_ISCSI = "vnicIScsi"
	VNIC_ISCSI_AUTO_TARGET_IF = "vnicIScsiAutoTargetIf"
	VNIC_ISCSI_BOOT_PARAMS = "vnicIScsiBootParams"
	VNIC_ISCSI_BOOT_VNIC = "vnicIScsiBootVnic"
	VNIC_ISCSI_LCP = "vnicIScsiLCP"
	VNIC_ISCSI_NODE = "vnicIScsiNode"
	VNIC_ISCSI_STATIC_TARGET_IF = "vnicIScsiStaticTargetIf"
	VNIC_INTERNAL_PROFILE = "vnicInternalProfile"
	VNIC_IP_V4_HISTORY = "vnicIpV4History"
	VNIC_IP_V4_MGMT_POOLED_ADDR = "vnicIpV4MgmtPooledAddr"
	VNIC_IP_V4_POOLED_ADDR = "vnicIpV4PooledAddr"
	VNIC_IP_V4_PROF_DERIVED_ADDR = "vnicIpV4ProfDerivedAddr"
	VNIC_IP_V4_STATIC_ADDR = "vnicIpV4StaticAddr"
	VNIC_IP_V6_HISTORY = "vnicIpV6History"
	VNIC_IP_V6_MGMT_POOLED_ADDR = "vnicIpV6MgmtPooledAddr"
	VNIC_IP_V6_STATIC_ADDR = "vnicIpV6StaticAddr"
	VNIC_IPC = "vnicIpc"
	VNIC_IPC_IF = "vnicIpcIf"
	VNIC_IQN_HISTORY = "vnicIqnHistory"
	VNIC_LAN_CONN_POLICY = "vnicLanConnPolicy"
	VNIC_LAN_CONN_TEMPL = "vnicLanConnTempl"
	VNIC_LIF_VLAN = "vnicLifVlan"
	VNIC_LIF_VSAN = "vnicLifVsan"
	VNIC_LUN = "vnicLun"
	VNIC_MAC_HISTORY = "vnicMacHistory"
	VNIC_OPROFILE_ALIAS = "vnicOProfileAlias"
	VNIC_PROFILE = "vnicProfile"
	VNIC_PROFILE_ALIAS = "vnicProfileAlias"
	VNIC_PROFILE_REF = "vnicProfileRef"
	VNIC_PROFILE_SET = "vnicProfileSet"
	VNIC_PROFILE_SET_FSM = "vnicProfileSetFsm"
	VNIC_PROFILE_SET_FSM_STAGE = "vnicProfileSetFsmStage"
	VNIC_PROFILE_SET_FSM_TASK = "vnicProfileSetFsmTask"
	VNIC_RACK_SERVER_DISCOVERY_PROFILE = "vnicRackServerDiscoveryProfile"
	VNIC_SAN_CONN_POLICY = "vnicSanConnPolicy"
	VNIC_SAN_CONN_TEMPL = "vnicSanConnTempl"
	VNIC_SCSI = "vnicScsi"
	VNIC_SCSI_IF = "vnicScsiIf"
	VNIC_USNIC_CON_POLICY = "vnicUsnicConPolicy"
	VNIC_USNIC_CON_POLICY_REF = "vnicUsnicConPolicyRef"
	VNIC_VHBA_BEH_POLICY = "vnicVhbaBehPolicy"
	VNIC_VLAN = "vnicVlan"
	VNIC_VMQ_CON_POLICY = "vnicVmqConPolicy"
	VNIC_VMQ_CON_POLICY_REF = "vnicVmqConPolicyRef"
	VNIC_VNIC_BEH_POLICY = "vnicVnicBehPolicy"
	VNIC_WWNN_HISTORY = "vnicWwnnHistory"
	VNIC_WWPN_HISTORY = "vnicWwpnHistory"
	WCARD_FILTER = "wcardFilter"

class YesOrNo:
	FALSE = "false"
	NO = "no"
	TRUE = "true"
	YES = "yes"

class NamingPropertyId:
	_ABORT_ERRORS = "AbortErrors"
	_ABORT_ERRORS15_MIN = "AbortErrors15Min"
	_ABORT_ERRORS15_MIN_H = "AbortErrors15MinH"
	_ABORT_ERRORS1_DAY = "AbortErrors1Day"
	_ABORT_ERRORS1_DAY_H = "AbortErrors1DayH"
	_ABORT_ERRORS1_HOUR = "AbortErrors1Hour"
	_ABORT_ERRORS1_HOUR_H = "AbortErrors1HourH"
	_ABORT_ERRORS1_WEEK = "AbortErrors1Week"
	_ABORT_ERRORS1_WEEK_H = "AbortErrors1WeekH"
	_ABORT_ERRORS2_WEEKS = "AbortErrors2Weeks"
	_ABORT_ERRORS2_WEEKS_H = "AbortErrors2WeeksH"
	_CONTROLLER_FW_VERSION = "ControllerFwVersion"
	_CONTROLLER_MODEL = "ControllerModel"
	_END_POINT_DN = "EndPointDn"
	_HDDMON_SUPPORT = "HDDMonSupport"
	_IPV4_ADDRESS = "IPv4Address"
	_MODULE_POWER = "ModulePower"
	_MODULE_POWER_AVG = "ModulePowerAvg"
	_MODULE_POWER_MAX = "ModulePowerMax"
	_MODULE_POWER_MIN = "ModulePowerMin"
	_PSU_TYPE = "PsuType"
	_SQETEST = "SQETest"
	_SQETEST_DELTA = "SQETestDelta"
	_SQETEST_DELTA_AVG = "SQETestDeltaAvg"
	_SQETEST_DELTA_MAX = "SQETestDeltaMax"
	_SQETEST_DELTA_MIN = "SQETestDeltaMin"
	_SLOT_OUTLET1 = "SlotOutlet1"
	_SLOT_OUTLET1_AVG = "SlotOutlet1Avg"
	_SLOT_OUTLET1_MAX = "SlotOutlet1Max"
	_SLOT_OUTLET1_MIN = "SlotOutlet1Min"
	_SLOT_OUTLET2 = "SlotOutlet2"
	_SLOT_OUTLET2_AVG = "SlotOutlet2Avg"
	_SLOT_OUTLET2_MAX = "SlotOutlet2Max"
	_SLOT_OUTLET2_MIN = "SlotOutlet2Min"
	_SLOT_OUTLET3 = "SlotOutlet3"
	_SLOT_OUTLET3_AVG = "SlotOutlet3Avg"
	_SLOT_OUTLET3_MAX = "SlotOutlet3Max"
	_SLOT_OUTLET3_MIN = "SlotOutlet3Min"
	_TIMEOUT_ERRORS = "TimeoutErrors"
	_TIMEOUT_ERRORS15_MIN = "TimeoutErrors15Min"
	_TIMEOUT_ERRORS15_MIN_H = "TimeoutErrors15MinH"
	_TIMEOUT_ERRORS1_DAY = "TimeoutErrors1Day"
	_TIMEOUT_ERRORS1_DAY_H = "TimeoutErrors1DayH"
	_TIMEOUT_ERRORS1_HOUR = "TimeoutErrors1Hour"
	_TIMEOUT_ERRORS1_HOUR_H = "TimeoutErrors1HourH"
	_TIMEOUT_ERRORS1_WEEK = "TimeoutErrors1Week"
	_TIMEOUT_ERRORS1_WEEK_H = "TimeoutErrors1WeekH"
	_TIMEOUT_ERRORS2_WEEKS = "TimeoutErrors2Weeks"
	_TIMEOUT_ERRORS2_WEEKS_H = "TimeoutErrors2WeeksH"
	_TYPE = "Type"
	A_PARTIAL_ENUM = "aPartialEnum"
	ABITMASK = "abitmask"
	ABS_QUANT = "absQuant"
	ACCESS = "access"
	ACCESS_POLICY = "accessPolicy"
	ACCESS_VLAN_PORT_COUNT = "accessVlanPortCount"
	ACCOUNT_STATUS = "accountStatus"
	ACHAR = "achar"
	ACHARBUF = "acharbuf"
	ACK = "ack"
	ACK_ACTION = "ackAction"
	ACK_PROGRESS_INDICATOR = "ackProgressIndicator"
	ACK_STATE = "ackState"
	ACKED = "acked"
	ACKED_BY = "ackedBy"
	ACQTS = "acqts"
	ACS_VIOLATION_ERRORS = "acsViolationErrors"
	ACS_VIOLATION_ERRORS15_MIN = "acsViolationErrors15Min"
	ACS_VIOLATION_ERRORS15_MIN_H = "acsViolationErrors15MinH"
	ACS_VIOLATION_ERRORS1_DAY = "acsViolationErrors1Day"
	ACS_VIOLATION_ERRORS1_DAY_H = "acsViolationErrors1DayH"
	ACS_VIOLATION_ERRORS1_HOUR = "acsViolationErrors1Hour"
	ACS_VIOLATION_ERRORS1_HOUR_H = "acsViolationErrors1HourH"
	ACS_VIOLATION_ERRORS1_WEEK = "acsViolationErrors1Week"
	ACS_VIOLATION_ERRORS1_WEEK_H = "acsViolationErrors1WeekH"
	ACS_VIOLATION_ERRORS2_WEEKS = "acsViolationErrors2Weeks"
	ACS_VIOLATION_ERRORS2_WEEKS_H = "acsViolationErrors2WeeksH"
	ACTION = "action"
	ACTIVE_STATUS = "activeStatus"
	ACTIVE_TIMEOUT = "activeTimeout"
	ACTIVITY_NAME = "activityName"
	ACTIVITY_TS = "activityTs"
	ACTUAL_WRITE_CACHE_POLICY = "actualWriteCachePolicy"
	ADAPTER_ID = "adapterId"
	ADAPTOR_EP = "adaptorEp"
	ADAPTOR_FAMILY = "adaptorFamily"
	ADAPTOR_ID = "adaptorId"
	ADAPTOR_PROFILE_NAME = "adaptorProfileName"
	ADAPTOR_SLOT_NUMBER = "adaptorSlotNumber"
	ADAPTOR_SLOT_SPAN = "adaptorSlotSpan"
	ADAPTOR_TYPE = "adaptorType"
	ADATE = "adate"
	ADATETIME = "adatetime"
	ADDR = "addr"
	ADDRESS = "address"
	ADDRESS_PARITY_ERRORS = "addressParityErrors"
	ADDRESS_PARITY_ERRORS15_MIN = "addressParityErrors15Min"
	ADDRESS_PARITY_ERRORS15_MIN_H = "addressParityErrors15MinH"
	ADDRESS_PARITY_ERRORS1_DAY = "addressParityErrors1Day"
	ADDRESS_PARITY_ERRORS1_DAY_H = "addressParityErrors1DayH"
	ADDRESS_PARITY_ERRORS1_HOUR = "addressParityErrors1Hour"
	ADDRESS_PARITY_ERRORS1_HOUR_H = "addressParityErrors1HourH"
	ADDRESS_PARITY_ERRORS1_WEEK = "addressParityErrors1Week"
	ADDRESS_PARITY_ERRORS1_WEEK_H = "addressParityErrors1WeekH"
	ADDRESS_PARITY_ERRORS2_WEEKS = "addressParityErrors2Weeks"
	ADDRESS_PARITY_ERRORS2_WEEKS_H = "addressParityErrors2WeeksH"
	ADDRESS_WIDTH = "addressWidth"
	ADMIN_COMMITTED = "adminCommitted"
	ADMIN_INBAND_IF_STATE = "adminInbandIfState"
	ADMIN_MEMORY_STATE = "adminMemoryState"
	ADMIN_PEAK = "adminPeak"
	ADMIN_POWER = "adminPower"
	ADMIN_POWER_STATE = "adminPowerState"
	ADMIN_PROP_MASK = "adminPropMask"
	ADMIN_SPEED = "adminSpeed"
	ADMIN_STATE = "adminState"
	ADMIN_TRANSPORT = "adminTransport"
	ADMIN_VCON = "adminVcon"
	ADP_VIF_ID = "adpVifId"
	ADV_BOOT_ORDER_APPLICABLE = "advBootOrderApplicable"
	AFFECTED = "affected"
	AFFECTED_OBJ = "affectedObj"
	AFFECTED_SERVER = "affectedServer"
	AFFECTED_SERVERS = "affectedServers"
	AFLOAT = "afloat"
	AGENT_POLICY_NAME = "agentPolicyName"
	AGGREGATION_CAP = "aggregationCap"
	AIRFLOW_DIRECTION = "airflowDirection"
	ALARM_DESC = "alarmDesc"
	ALARM_SEVERITY = "alarmSeverity"
	ALERT_GROUPS = "alertGroups"
	ALERT_THROTTLING_ADMIN_STATE = "alertThrottlingAdminState"
	ALIAS = "alias"
	ALIGN = "align"
	ALIGN_DELTA = "alignDelta"
	ALIGN_DELTA_AVG = "alignDeltaAvg"
	ALIGN_DELTA_MAX = "alignDeltaMax"
	ALIGN_DELTA_MIN = "alignDeltaMin"
	ALLOC_STATE = "allocState"
	ALLOC_STATUS = "allocStatus"
	ALLOWED_VNIC_TYPE = "allowedVnicType"
	ALWAYS_USE = "alwaysUse"
	AMAC = "amac"
	AMBIENT_TEMP = "ambientTemp"
	AMBIENT_TEMP_AVG = "ambientTempAvg"
	AMBIENT_TEMP_MAX = "ambientTempMax"
	AMBIENT_TEMP_MIN = "ambientTempMin"
	AND_OPERATION = "andOperation"
	ANENUM = "anenum"
	ANIPV4 = "anipv4"
	ANIPV6 = "anipv6"
	ANSBYTE = "ansbyte"
	ANSINT16 = "ansint16"
	ANSINT32 = "ansint32"
	ANSINT64 = "ansint64"
	APASSWORD = "apassword"
	API = "api"
	APP_CONNECTOR_ID = "appConnectorId"
	APP_TYPE = "appType"
	APPLY = "apply"
	ARANGE = "arange"
	ARCH = "arch"
	ARCSTRING = "arcstring"
	ARRAY = "array"
	ARXSTRING = "arxstring"
	ASIC = "asic"
	ASSIGN_STATE = "assignState"
	ASSIGNED = "assigned"
	ASSIGNED_TO_DN = "assignedToDn"
	ASSIGNMENT_ORDER = "assignmentOrder"
	ASSOC_STATE = "assocState"
	ASSOCIATION = "association"
	ASTRING = "astring"
	ATIME = "atime"
	ATTRIBUTE = "attribute"
	AUBYTE = "aubyte"
	AUDITS = "audits"
	AUINT16 = "auint16"
	AUINT32 = "auint32"
	AUINT64 = "auint64"
	AUTH = "auth"
	AUTH_DOMAIN = "authDomain"
	AUTH_PORT = "authPort"
	AUTH_PROFILE_NAME = "authProfileName"
	AUTH_USER = "authUser"
	AUTHORIZATION = "authorization"
	AUTO_DELETE = "autoDelete"
	AVAILABILITY = "availability"
	AVAILABLE = "available"
	AVAILABLE_AVG = "availableAvg"
	AVAILABLE_MAX = "availableMax"
	AVAILABLE_MEMORY = "availableMemory"
	AVAILABLE_MIN = "availableMin"
	AVAILABLE_POWER = "availablePower"
	AVAILABLE_POWER_AVG = "availablePowerAvg"
	AVAILABLE_POWER_MAX = "availablePowerMax"
	AVAILABLE_POWER_MIN = "availablePowerMin"
	AWWN = "awwn"
	BACKUP_COUNT = "backupCount"
	BAD_CRC_PACKETS = "badCrcPackets"
	BAD_CRC_PACKETS_DELTA = "badCrcPacketsDelta"
	BAD_CRC_PACKETS_DELTA_AVG = "badCrcPacketsDeltaAvg"
	BAD_CRC_PACKETS_DELTA_MAX = "badCrcPacketsDeltaMax"
	BAD_CRC_PACKETS_DELTA_MIN = "badCrcPacketsDeltaMin"
	BAD_LENGTH_PACKETS = "badLengthPackets"
	BAD_LENGTH_PACKETS_DELTA = "badLengthPacketsDelta"
	BAD_LENGTH_PACKETS_DELTA_AVG = "badLengthPacketsDeltaAvg"
	BAD_LENGTH_PACKETS_DELTA_MAX = "badLengthPacketsDeltaMax"
	BAD_LENGTH_PACKETS_DELTA_MIN = "badLengthPacketsDeltaMin"
	BANDWIDTH = "bandwidth"
	BANK = "bank"
	BASE_ADDR = "baseAddr"
	BASE_CONTAINER = "baseContainer"
	BASE_MAC = "baseMac"
	BASEDN = "basedn"
	BATTERY_TYPE = "batteryType"
	BBU_STATUS = "bbuStatus"
	BIOS_PROFILE_NAME = "biosProfileName"
	BIOS_SETTINGS_SCRUB = "biosSettingsScrub"
	BIOS_VERSION = "biosVersion"
	BITMASK = "bitmask"
	BLACK_LISTING = "blackListing"
	BLADE_BUNDLE_NAME = "bladeBundleName"
	BLADE_BUNDLE_VERSION = "bladeBundleVersion"
	BLADE_ID = "bladeId"
	BLKSIZE = "blksize"
	BLOCK_SIZE = "blockSize"
	BLOCKS = "blocks"
	BOARD_MANUFACTURER = "boardManufacturer"
	BOARD_MFG_TIME = "boardMfgTime"
	BOARD_PART_NO = "boardPartNo"
	BOARD_PRODUCT_NAME = "boardProductName"
	BOARD_SERIAL_NO = "boardSerialNo"
	BOARD_VID = "boardVid"
	BOOT = "boot"
	BOOT_DEV = "bootDev"
	BOOT_IP_POLICY_NAME = "bootIpPolicyName"
	BOOT_MODE = "bootMode"
	BOOT_ORDER_TYPE = "bootOrderType"
	BOOT_POLICY_NAME = "bootPolicyName"
	BOOT_TO_TARGET = "bootToTarget"
	BOOTABLE = "bootable"
	BORDER_PORT_ID = "borderPortId"
	BORDER_SLOT_ID = "borderSlotId"
	BORDER_VFC_ID = "borderVfcId"
	BORDER_VLAN_PORT_COUNT = "borderVlanPortCount"
	BROADCAST_PACKETS = "broadcastPackets"
	BROADCAST_PACKETS_DELTA = "broadcastPacketsDelta"
	BROADCAST_PACKETS_DELTA_AVG = "broadcastPacketsDeltaAvg"
	BROADCAST_PACKETS_DELTA_MAX = "broadcastPacketsDeltaMax"
	BROADCAST_PACKETS_DELTA_MIN = "broadcastPacketsDeltaMin"
	BUFFER_OVERFLOW_ERRORS = "bufferOverflowErrors"
	BUFFER_OVERFLOW_ERRORS15_MIN = "bufferOverflowErrors15Min"
	BUFFER_OVERFLOW_ERRORS15_MIN_H = "bufferOverflowErrors15MinH"
	BUFFER_OVERFLOW_ERRORS1_DAY = "bufferOverflowErrors1Day"
	BUFFER_OVERFLOW_ERRORS1_DAY_H = "bufferOverflowErrors1DayH"
	BUFFER_OVERFLOW_ERRORS1_HOUR = "bufferOverflowErrors1Hour"
	BUFFER_OVERFLOW_ERRORS1_HOUR_H = "bufferOverflowErrors1HourH"
	BUFFER_OVERFLOW_ERRORS1_WEEK = "bufferOverflowErrors1Week"
	BUFFER_OVERFLOW_ERRORS1_WEEK_H = "bufferOverflowErrors1WeekH"
	BUFFER_OVERFLOW_ERRORS2_WEEKS = "bufferOverflowErrors2Weeks"
	BUFFER_OVERFLOW_ERRORS2_WEEKS_H = "bufferOverflowErrors2WeeksH"
	BULKED = "bulked"
	BUNDLE_NAME = "bundleName"
	BUNDLE_VERSION = "bundleVersion"
	BURST = "burst"
	BW_PERCENT = "bwPercent"
	BYTES_RX = "bytesRx"
	BYTES_RX_DELTA = "bytesRxDelta"
	BYTES_RX_DELTA_AVG = "bytesRxDeltaAvg"
	BYTES_RX_DELTA_MAX = "bytesRxDeltaMax"
	BYTES_RX_DELTA_MIN = "bytesRxDeltaMin"
	BYTES_TX = "bytesTx"
	BYTES_TX_DELTA = "bytesTxDelta"
	BYTES_TX_DELTA_AVG = "bytesTxDeltaAvg"
	BYTES_TX_DELTA_MAX = "bytesTxDeltaMax"
	BYTES_TX_DELTA_MIN = "bytesTxDeltaMin"
	BYTES_EG = "bytes_eg"
	BYTES_IN = "bytes_in"
	C_TYPE = "cType"
	CACHE_SIZE = "cacheSize"
	CACHED = "cached"
	CACHED_AVG = "cachedAvg"
	CACHED_MAX = "cachedMax"
	CACHED_MIN = "cachedMin"
	CACHENOSPC = "cachenospc"
	CAN_BE_FRUED = "canBeFRUed"
	CAP_ACTION = "capAction"
	CAPABILITY = "capability"
	CAPACITY = "capacity"
	CAPACITY_PERCENTAGE = "capacityPercentage"
	CAPTION = "caption"
	CARD_HEALTH = "cardHealth"
	CARD_MODE = "cardMode"
	CARD_TYPE = "cardType"
	CARRIER_SENSE = "carrierSense"
	CARRIER_SENSE_DELTA = "carrierSenseDelta"
	CARRIER_SENSE_DELTA_AVG = "carrierSenseDeltaAvg"
	CARRIER_SENSE_DELTA_MAX = "carrierSenseDeltaMax"
	CARRIER_SENSE_DELTA_MIN = "carrierSenseDeltaMin"
	CATALOG_NAME = "catalogName"
	CATALOG_POWER = "catalogPower"
	CATALOG_VERSION = "catalogVersion"
	CATEGORY = "category"
	CAUSE = "cause"
	CDP = "cdp"
	CDP_LINK_POLICY_NAME = "cdpLinkPolicyName"
	CENTRALE_MO_DN = "centraleMoDn"
	CENTRALE_VNET_EP_DN = "centraleVnetEpDn"
	CERT = "cert"
	CERT_CHAIN = "certChain"
	CERT_FILE = "certFile"
	CERT_STATUS = "certStatus"
	CHANGE_BY = "changeBy"
	CHANGE_COUNT = "changeCount"
	CHANGE_DETAILS = "changeDetails"
	CHANGE_DURING_INTERVAL = "changeDuringInterval"
	CHANGE_INTERVAL = "changeInterval"
	CHANGE_MODE = "changeMode"
	CHANGE_SET = "changeSet"
	CHANGED_MO_CLASS_ID = "changedMoClassId"
	CHANGES = "changes"
	CHANNEL_STATE = "channelState"
	CHASSIS1 = "chassis1"
	CHASSIS2 = "chassis2"
	CHASSIS3 = "chassis3"
	CHASSIS_CIMC_ID = "chassisCimcId"
	CHASSIS_DEVICE_IO_STATE1 = "chassisDeviceIoState1"
	CHASSIS_DEVICE_IO_STATE2 = "chassisDeviceIoState2"
	CHASSIS_DEVICE_IO_STATE3 = "chassisDeviceIoState3"
	CHASSIS_DN = "chassisDn"
	CHASSIS_ID = "chassisId"
	CHASSIS_IOM_ID = "chassisIomId"
	CHASSIS_MAC = "chassisMac"
	CHASSIS_PART_NO = "chassisPartNo"
	CHASSIS_SERIAL_NO = "chassisSerialNo"
	CHECK_POINT = "checkPoint"
	CHECKPOINT_TRIG_TS = "checkpointTrigTs"
	CHECKSUM = "checksum"
	CHILD_ACTION = "childAction"
	CHILD_CLASS_ID = "childClassId"
	CIMC_ADAPTER_ID = "cimcAdapterId"
	CIMC_ADDR = "cimcAddr"
	CIMC_IDS = "cimcIds"
	CIPHER_SUITE = "cipherSuite"
	CIPHER_SUITE_MODE = "cipherSuiteMode"
	CL_INST_TYPE = "clInstType"
	CLASS_TYPE = "classType"
	CLEAR_ACTION = "clearAction"
	CLEAR_INTERVAL = "clearInterval"
	CLEAR_ON_BACKUP = "clearOnBackup"
	CLEAR_PWD_HISTORY = "clearPwdHistory"
	CLEI = "clei"
	CLI_ID = "cliId"
	CLIENT_CONFIG_STATE = "clientConfigState"
	CLIENT_TYPE = "clientType"
	CLOCK = "clock"
	CLOUD = "cloud"
	CLUSTER_STATE = "clusterState"
	CMOS_RESET_SUPPORTED = "cmosResetSupported"
	CMOS_VOLTAGE = "cmosVoltage"
	COALESCING_TIME = "coalescingTime"
	COALESCING_TYPE = "coalescingType"
	CODE = "code"
	COLL_INTERVAL = "collInterval"
	COLLECTION_INTERVAL = "collectionInterval"
	COLOR = "color"
	COMMUNITY = "community"
	COMP = "comp"
	COMPLETENESS = "completeness"
	COMPLETION = "completion"
	COMPLETION_TIME = "completionTime"
	COMPRESSION_TYPE = "compressionType"
	COMPUTE_EP_DN = "computeEpDn"
	COMPUTE_EP_VENDOR = "computeEpVendor"
	CON_LOGIN = "conLogin"
	CON_POLICY_NAME = "conPolicyName"
	CONCUR_CAP = "concurCap"
	CONF = "conf"
	CONF_MODE = "confMode"
	CONF_QUAL = "confQual"
	CONF_STATE = "confState"
	CONFIG_FAIL_REASON = "configFailReason"
	CONFIG_ISSUE = "configIssue"
	CONFIG_ISSUES = "configIssues"
	CONFIG_MESSAGE = "configMessage"
	CONFIG_QUALIFIER = "configQualifier"
	CONFIG_STATE = "configState"
	CONFIG_STATUS = "configStatus"
	CONFIG_STATUS_MESSAGE = "configStatusMessage"
	CONFIGURATION = "configuration"
	CONFIGURED_WRITE_CACHE_POLICY = "configuredWriteCachePolicy"
	CONN_PATH = "connPath"
	CONN_PROTOCOL = "connProtocol"
	CONN_STATUS = "connStatus"
	CONNECTION_PROTOCOL = "connectionProtocol"
	CONNECTION_TIME_OUT = "connectionTimeOut"
	CONS_DN = "consDn"
	CONS_TYPE = "consType"
	CONSTANT_NAME = "constantName"
	CONSTRAINT_TYPE = "constraintType"
	CONSUMED_POWER = "consumedPower"
	CONSUMED_POWER_AVG = "consumedPowerAvg"
	CONSUMED_POWER_MAX = "consumedPowerMax"
	CONSUMED_POWER_MIN = "consumedPowerMin"
	CONT_CLASS_ID = "contClassId"
	CONT_INST_ID = "contInstId"
	CONT_INST_ID_PROP_ID = "contInstIdPropId"
	CONTACT = "contact"
	CONTEXT = "context"
	CONTRACT = "contract"
	CONTROL_PLANE_MAC1 = "controlPlaneMac1"
	CONTROL_PLANE_MAC2 = "controlPlaneMac2"
	CONTROL_REQUESTS = "controlRequests"
	CONTROL_REQUESTS_DELTA = "controlRequestsDelta"
	CONTROL_REQUESTS_DELTA_AVG = "controlRequestsDeltaAvg"
	CONTROL_REQUESTS_DELTA_MAX = "controlRequestsDeltaMax"
	CONTROL_REQUESTS_DELTA_MIN = "controlRequestsDeltaMin"
	CONTROLLER_HEALTH = "controllerHealth"
	CONTROLLER_INDEX = "controllerIndex"
	CONTROLLER_REPORTED = "controllerReported"
	CONTROLLER_STATE = "controllerState"
	CONTROLLER_STATUS = "controllerStatus"
	CONVERTED_DN = "convertedDn"
	CONVERTED_EP_REF = "convertedEpRef"
	COOKIE = "cookie"
	CORES = "cores"
	CORES_ENABLED = "coresEnabled"
	CORRECTABLE_ERRORS = "correctableErrors"
	CORRECTABLE_ERRORS_DELTA = "correctableErrorsDelta"
	CORRECTABLE_ERRORS_DELTA_AVG = "correctableErrorsDeltaAvg"
	CORRECTABLE_ERRORS_DELTA_MAX = "correctableErrorsDeltaMax"
	CORRECTABLE_ERRORS_DELTA_MIN = "correctableErrorsDeltaMin"
	COS = "cos"
	COS_VALUE = "cosValue"
	COUNT = "count"
	COUNTRY = "country"
	CPU_ID = "cpuId"
	CRC_RX = "crcRx"
	CRC_RX_DELTA = "crcRxDelta"
	CRC_RX_DELTA_AVG = "crcRxDeltaAvg"
	CRC_RX_DELTA_MAX = "crcRxDeltaMax"
	CRC_RX_DELTA_MIN = "crcRxDeltaMin"
	CREATED = "created"
	CREATION_DATE = "creationDate"
	CREATION_TS = "creationTS"
	CREATION_TIME = "creationTime"
	CTIME = "ctime"
	CTPASSWORD = "ctpassword"
	CUR_REQ_POWER = "curReqPower"
	CURR_CAPACITY = "currCapacity"
	CURRENT = "current"
	CURRENT_AVG = "currentAvg"
	CURRENT_FSM = "currentFsm"
	CURRENT_MAX = "currentMax"
	CURRENT_MIN = "currentMin"
	CURRENT_POWER = "currentPower"
	CURRENT_TIME = "currentTime"
	CURRENT_ZONE_PREFIX = "currentZonePrefix"
	CUSTOMER = "customer"
	DATA = "data"
	DATA_PLANE_MAC1 = "dataPlaneMac1"
	DATA_PLANE_MAC2 = "dataPlaneMac2"
	DATA_PLANE_WWN1 = "dataPlaneWwn1"
	DATA_PLANE_WWN2 = "dataPlaneWwn2"
	DATA_SRC_APP_TYPE = "dataSrcAppType"
	DATA_SRC_SYS_ID = "dataSrcSysId"
	DATA_WIDTH = "dataWidth"
	DATABASE_VERSION = "databaseVersion"
	DATE = "date"
	DAY = "day"
	DBTXS = "dbtxs"
	DC_NAME = "dcName"
	DC_ORG = "dcOrg"
	DEEP_CHECKPOINT_TRIG_TS = "deepCheckpointTrigTs"
	DEESCALATING = "deescalating"
	DEF_DN = "defDn"
	DEF_GW = "defGw"
	DEF_INT_ID = "defIntId"
	DEF_LOGIN = "defLogin"
	DEF_QUANT = "defQuant"
	DEF_ROLE_POLICY = "defRolePolicy"
	DEFAULT_LEVEL = "defaultLevel"
	DEFAULT_NET = "defaultNet"
	DEFAULT_POLICY_NAME = "defaultPolicyName"
	DEFAULT_SIZE = "defaultSize"
	DEFAULT_VLAN = "defaultVlan"
	DEFAULT_VLAN_NAME = "defaultVlanName"
	DEFAULT_ZONING = "defaultZoning"
	DEFERRED_TX = "deferredTx"
	DEFERRED_TX_DELTA = "deferredTxDelta"
	DEFERRED_TX_DELTA_AVG = "deferredTxDeltaAvg"
	DEFERRED_TX_DELTA_MAX = "deferredTxDeltaMax"
	DEFERRED_TX_DELTA_MIN = "deferredTxDeltaMin"
	DEFINED_IN_IDM = "definedInIdm"
	DEL_FE_TS = "delFeTs"
	DELETED = "deleted"
	DEPLOY_FLAG = "deployFlag"
	DEPLOYMENT = "deployment"
	DEPLOYMENT_MODE = "deploymentMode"
	DEPRECATED = "deprecated"
	DEPTH = "depth"
	DERIVED_FROM_ID = "derivedFromId"
	DESCR = "descr"
	DESCRIPTION = "description"
	DEST_IP = "destIp"
	DESTINATION_IP = "destinationIp"
	DESTINATION_IP_ADDRESS = "destinationIpAddress"
	DESTINATION_NETMASK = "destinationNetmask"
	DESTINATION_PORT = "destinationPort"
	DETAIL = "detail"
	DEV = "dev"
	DEVICE = "device"
	DEVICE_ID = "deviceId"
	DEVICE_NAME = "deviceName"
	DEVICE_RAID_SUPPORT = "deviceRaidSupport"
	DEVICE_TYPE = "deviceType"
	DHCP_TIME_OUT = "dhcpTimeOut"
	DHCP_VENDOR_ID = "dhcpVendorId"
	DIAG_LLDP_TRANSMIT = "diagLldpTransmit"
	DIE1 = "die1"
	DIE1_AVG = "die1Avg"
	DIE1_MAX = "die1Max"
	DIE1_MIN = "die1Min"
	DIMM_BLACKLISTING_OPER_STATE = "dimmBlacklistingOperState"
	DIRECTION = "direction"
	DISC_TRIG_TS = "discTrigTs"
	DISCARD_RX = "discardRx"
	DISCARD_RX_DELTA = "discardRxDelta"
	DISCARD_RX_DELTA_AVG = "discardRxDeltaAvg"
	DISCARD_RX_DELTA_MAX = "discardRxDeltaMax"
	DISCARD_RX_DELTA_MIN = "discardRxDeltaMin"
	DISCARD_TX = "discardTx"
	DISCARD_TX_DELTA = "discardTxDelta"
	DISCARD_TX_DELTA_AVG = "discardTxDeltaAvg"
	DISCARD_TX_DELTA_MAX = "discardTxDeltaMax"
	DISCARD_TX_DELTA_MIN = "discardTxDeltaMin"
	DISCOVERY = "discovery"
	DISCOVERY_STATE = "discoveryState"
	DISK_SCRUB = "diskScrub"
	DISK_STATE = "diskState"
	DISKLESS = "diskless"
	DISR = "disr"
	DISTRO = "distro"
	DLLP_ERRORS = "dllpErrors"
	DLLP_ERRORS15_MIN = "dllpErrors15Min"
	DLLP_ERRORS15_MIN_H = "dllpErrors15MinH"
	DLLP_ERRORS1_DAY = "dllpErrors1Day"
	DLLP_ERRORS1_DAY_H = "dllpErrors1DayH"
	DLLP_ERRORS1_HOUR = "dllpErrors1Hour"
	DLLP_ERRORS1_HOUR_H = "dllpErrors1HourH"
	DLLP_ERRORS1_WEEK = "dllpErrors1Week"
	DLLP_ERRORS1_WEEK_H = "dllpErrors1WeekH"
	DLLP_ERRORS2_WEEKS = "dllpErrors2Weeks"
	DLLP_ERRORS2_WEEKS_H = "dllpErrors2WeeksH"
	DN = "dn"
	DNS = "dns"
	DOMAIN = "domain"
	DOWNLOAD_DATE = "downloadDate"
	DRIVE_CACHE = "driveCache"
	DRIVE_PERCENTAGE = "drivePercentage"
	DRIVE_PERCENTAGE_AVG = "drivePercentageAvg"
	DRIVE_PERCENTAGE_MAX = "drivePercentageMax"
	DRIVE_PERCENTAGE_MIN = "drivePercentageMin"
	DRIVE_STATE = "driveState"
	DRIVE_TYPE = "driveType"
	DROP = "drop"
	DROP_ACL = "dropAcl"
	DROP_ACL_DELTA = "dropAclDelta"
	DROP_ACL_DELTA_AVG = "dropAclDeltaAvg"
	DROP_ACL_DELTA_MAX = "dropAclDeltaMax"
	DROP_ACL_DELTA_MIN = "dropAclDeltaMin"
	DROP_CMD = "dropCmd"
	DROP_CMD_DELTA = "dropCmdDelta"
	DROP_CMD_DELTA_AVG = "dropCmdDeltaAvg"
	DROP_CMD_DELTA_MAX = "dropCmdDeltaMax"
	DROP_CMD_DELTA_MIN = "dropCmdDeltaMin"
	DROP_FC_LIF_INVALID = "dropFcLifInvalid"
	DROP_FC_LIF_INVALID_DELTA = "dropFcLifInvalidDelta"
	DROP_FC_LIF_INVALID_DELTA_AVG = "dropFcLifInvalidDeltaAvg"
	DROP_FC_LIF_INVALID_DELTA_MAX = "dropFcLifInvalidDeltaMax"
	DROP_FC_LIF_INVALID_DELTA_MIN = "dropFcLifInvalidDeltaMin"
	DROP_FC_MULTICAST = "dropFcMulticast"
	DROP_FC_MULTICAST_DELTA = "dropFcMulticastDelta"
	DROP_FC_MULTICAST_DELTA_AVG = "dropFcMulticastDeltaAvg"
	DROP_FC_MULTICAST_DELTA_MAX = "dropFcMulticastDeltaMax"
	DROP_FC_MULTICAST_DELTA_MIN = "dropFcMulticastDeltaMin"
	DROP_LIF_CFG_INVALID = "dropLifCfgInvalid"
	DROP_LIF_CFG_INVALID_DELTA = "dropLifCfgInvalidDelta"
	DROP_LIF_CFG_INVALID_DELTA_AVG = "dropLifCfgInvalidDeltaAvg"
	DROP_LIF_CFG_INVALID_DELTA_MAX = "dropLifCfgInvalidDeltaMax"
	DROP_LIF_CFG_INVALID_DELTA_MIN = "dropLifCfgInvalidDeltaMin"
	DROP_LIF_MAP_NO_HIT = "dropLifMapNoHit"
	DROP_LIF_MAP_NO_HIT_DELTA = "dropLifMapNoHitDelta"
	DROP_LIF_MAP_NO_HIT_DELTA_AVG = "dropLifMapNoHitDeltaAvg"
	DROP_LIF_MAP_NO_HIT_DELTA_MAX = "dropLifMapNoHitDeltaMax"
	DROP_LIF_MAP_NO_HIT_DELTA_MIN = "dropLifMapNoHitDeltaMin"
	DROP_NULL_PIF = "dropNullPif"
	DROP_NULL_PIF_DELTA = "dropNullPifDelta"
	DROP_NULL_PIF_DELTA_AVG = "dropNullPifDeltaAvg"
	DROP_NULL_PIF_DELTA_MAX = "dropNullPifDeltaMax"
	DROP_NULL_PIF_DELTA_MIN = "dropNullPifDeltaMin"
	DROP_OVERRUN = "dropOverrun"
	DROP_OVERRUN_DELTA = "dropOverrunDelta"
	DROP_OVERRUN_DELTA_AVG = "dropOverrunDeltaAvg"
	DROP_OVERRUN_DELTA_MAX = "dropOverrunDeltaMax"
	DROP_OVERRUN_DELTA_MIN = "dropOverrunDeltaMin"
	DROP_OVERRUN_N0 = "dropOverrunN0"
	DROP_OVERRUN_N0_DELTA = "dropOverrunN0Delta"
	DROP_OVERRUN_N0_DELTA_AVG = "dropOverrunN0DeltaAvg"
	DROP_OVERRUN_N0_DELTA_MAX = "dropOverrunN0DeltaMax"
	DROP_OVERRUN_N0_DELTA_MIN = "dropOverrunN0DeltaMin"
	DROP_OVERRUN_N1 = "dropOverrunN1"
	DROP_OVERRUN_N1_DELTA = "dropOverrunN1Delta"
	DROP_OVERRUN_N1_DELTA_AVG = "dropOverrunN1DeltaAvg"
	DROP_OVERRUN_N1_DELTA_MAX = "dropOverrunN1DeltaMax"
	DROP_OVERRUN_N1_DELTA_MIN = "dropOverrunN1DeltaMin"
	DROP_RUNT = "dropRunt"
	DROP_RUNT_DELTA = "dropRuntDelta"
	DROP_RUNT_DELTA_AVG = "dropRuntDeltaAvg"
	DROP_RUNT_DELTA_MAX = "dropRuntDeltaMax"
	DROP_RUNT_DELTA_MIN = "dropRuntDeltaMin"
	DROP_SRC_BIND = "dropSrcBind"
	DROP_SRC_BIND_DELTA = "dropSrcBindDelta"
	DROP_SRC_BIND_DELTA_AVG = "dropSrcBindDeltaAvg"
	DROP_SRC_BIND_DELTA_MAX = "dropSrcBindDeltaMax"
	DROP_SRC_BIND_DELTA_MIN = "dropSrcBindDeltaMin"
	DROPPED_RX = "droppedRx"
	DROPPED_RX_DELTA = "droppedRxDelta"
	DROPPED_RX_DELTA_AVG = "droppedRxDeltaAvg"
	DROPPED_RX_DELTA_MAX = "droppedRxDeltaMax"
	DROPPED_RX_DELTA_MIN = "droppedRxDeltaMin"
	DROPPED_TX = "droppedTx"
	DROPPED_TX_DELTA = "droppedTxDelta"
	DROPPED_TX_DELTA_AVG = "droppedTxDeltaAvg"
	DROPPED_TX_DELTA_MAX = "droppedTxDeltaMax"
	DROPPED_TX_DELTA_MIN = "droppedTxDeltaMin"
	DROPPED_PKTS_EG = "dropped_pkts_eg"
	DROPPED_PKTS_IN = "dropped_pkts_in"
	DSCP = "dscp"
	DST_DN = "dstDn"
	DUMPED_FRAMES = "dumpedFrames"
	DUMPED_FRAMES_DELTA = "dumpedFramesDelta"
	DUMPED_FRAMES_DELTA_AVG = "dumpedFramesDeltaAvg"
	DUMPED_FRAMES_DELTA_MAX = "dumpedFramesDeltaMax"
	DUMPED_FRAMES_DELTA_MIN = "dumpedFramesDeltaMin"
	DUPLICATE_TARGET = "duplicateTarget"
	DVS_DN = "dvsDn"
	DVS_GEN_PORT_ID = "dvsGenPortId"
	DVS_NAME = "dvsName"
	DVS_PORT_ID = "dvsPortId"
	DVS_SWITCH_ID = "dvsSwitchId"
	DYN_REALLOC = "dynRealloc"
	DYNAMIC_CON_POLICY_NAME = "dynamicConPolicyName"
	DYNAMIC_ETH = "dynamicEth"
	DYNAMIC_ID = "dynamicId"
	ECC_MULTIBIT_ERRORS = "eccMultibitErrors"
	ECC_MULTIBIT_ERRORS15_MIN = "eccMultibitErrors15Min"
	ECC_MULTIBIT_ERRORS15_MIN_H = "eccMultibitErrors15MinH"
	ECC_MULTIBIT_ERRORS1_DAY = "eccMultibitErrors1Day"
	ECC_MULTIBIT_ERRORS1_DAY_H = "eccMultibitErrors1DayH"
	ECC_MULTIBIT_ERRORS1_HOUR = "eccMultibitErrors1Hour"
	ECC_MULTIBIT_ERRORS1_HOUR_H = "eccMultibitErrors1HourH"
	ECC_MULTIBIT_ERRORS1_WEEK = "eccMultibitErrors1Week"
	ECC_MULTIBIT_ERRORS1_WEEK_H = "eccMultibitErrors1WeekH"
	ECC_MULTIBIT_ERRORS2_WEEKS = "eccMultibitErrors2Weeks"
	ECC_MULTIBIT_ERRORS2_WEEKS_H = "eccMultibitErrors2WeeksH"
	ECC_SINGLEBIT_ERRORS = "eccSinglebitErrors"
	ECC_SINGLEBIT_ERRORS15_MIN = "eccSinglebitErrors15Min"
	ECC_SINGLEBIT_ERRORS15_MIN_H = "eccSinglebitErrors15MinH"
	ECC_SINGLEBIT_ERRORS1_DAY = "eccSinglebitErrors1Day"
	ECC_SINGLEBIT_ERRORS1_DAY_H = "eccSinglebitErrors1DayH"
	ECC_SINGLEBIT_ERRORS1_HOUR = "eccSinglebitErrors1Hour"
	ECC_SINGLEBIT_ERRORS1_HOUR_H = "eccSinglebitErrors1HourH"
	ECC_SINGLEBIT_ERRORS1_WEEK = "eccSinglebitErrors1Week"
	ECC_SINGLEBIT_ERRORS1_WEEK_H = "eccSinglebitErrors1WeekH"
	ECC_SINGLEBIT_ERRORS2_WEEKS = "eccSinglebitErrors2Weeks"
	ECC_SINGLEBIT_ERRORS2_WEEKS_H = "eccSinglebitErrors2WeeksH"
	ECODE = "ecode"
	ELEMENT_LOAD_FAILURES = "elementLoadFailures"
	ELEMENTS_LOADED = "elementsLoaded"
	EMAIL = "email"
	ENABLE_HAFAILOVER = "enableHAFailover"
	ENABLE_LLDP_TRANSMIT = "enableLldpTransmit"
	ENABLE_SSL = "enableSSL"
	ENABLED_STATUS = "enabledStatus"
	ENACP = "enacp"
	ENC_KEY = "encKey"
	ENC_PWD = "encPwd"
	ENC_PWD_SET = "encPwdSet"
	ENC_SECRET = "encSecret"
	ENCAP = "encap"
	END_TIME = "endTime"
	END_TS = "endTs"
	END_TS_M = "endTsM"
	ENDS = "ends"
	ENFORCE_VNIC_NAME = "enforceVnicName"
	ENTITY_TYPE = "entityType"
	EP = "ep"
	EP_CLASS_ID = "epClassId"
	EP_CLOUD_TYPE = "epCloudType"
	EP_DN = "epDn"
	EP_NAME = "epName"
	EQ_TYPE = "eqType"
	EQPT_CLASS_ID = "eqptClassId"
	EQPT_INST_ID = "eqptInstId"
	EQPT_INST_ID_PROP_ID = "eqptInstIdPropId"
	EQUALS64 = "equals64"
	EQUALS64_DELTA = "equals64Delta"
	EQUALS64_DELTA_AVG = "equals64DeltaAvg"
	EQUALS64_DELTA_MAX = "equals64DeltaMax"
	EQUALS64_DELTA_MIN = "equals64DeltaMin"
	EQUIPMENT_DN = "equipmentDn"
	ERR_FATAL_ERRORS = "errFatalErrors"
	ERR_FATAL_ERRORS15_MIN = "errFatalErrors15Min"
	ERR_FATAL_ERRORS15_MIN_H = "errFatalErrors15MinH"
	ERR_FATAL_ERRORS1_DAY = "errFatalErrors1Day"
	ERR_FATAL_ERRORS1_DAY_H = "errFatalErrors1DayH"
	ERR_FATAL_ERRORS1_HOUR = "errFatalErrors1Hour"
	ERR_FATAL_ERRORS1_HOUR_H = "errFatalErrors1HourH"
	ERR_FATAL_ERRORS1_WEEK = "errFatalErrors1Week"
	ERR_FATAL_ERRORS1_WEEK_H = "errFatalErrors1WeekH"
	ERR_FATAL_ERRORS2_WEEKS = "errFatalErrors2Weeks"
	ERR_FATAL_ERRORS2_WEEKS_H = "errFatalErrors2WeeksH"
	ERR_NON_FATAL_ERRORS = "errNonFatalErrors"
	ERR_NON_FATAL_ERRORS15_MIN = "errNonFatalErrors15Min"
	ERR_NON_FATAL_ERRORS15_MIN_H = "errNonFatalErrors15MinH"
	ERR_NON_FATAL_ERRORS1_DAY = "errNonFatalErrors1Day"
	ERR_NON_FATAL_ERRORS1_DAY_H = "errNonFatalErrors1DayH"
	ERR_NON_FATAL_ERRORS1_HOUR = "errNonFatalErrors1Hour"
	ERR_NON_FATAL_ERRORS1_HOUR_H = "errNonFatalErrors1HourH"
	ERR_NON_FATAL_ERRORS1_WEEK = "errNonFatalErrors1Week"
	ERR_NON_FATAL_ERRORS1_WEEK_H = "errNonFatalErrors1WeekH"
	ERR_NON_FATAL_ERRORS2_WEEKS = "errNonFatalErrors2Weeks"
	ERR_NON_FATAL_ERRORS2_WEEKS_H = "errNonFatalErrors2WeeksH"
	ERR_VAL = "errVal"
	ERR_VALUE = "errValue"
	ERROR_CORRECTION = "errorCorrection"
	ERROR_DESCR = "errorDescr"
	ERROR_DETECT_TIMEOUT = "errorDetectTimeout"
	ERROR_FRAMES = "errorFrames"
	ERROR_FRAMES_DELTA = "errorFramesDelta"
	ERROR_FRAMES_DELTA_AVG = "errorFramesDeltaAvg"
	ERROR_FRAMES_DELTA_MAX = "errorFramesDeltaMax"
	ERROR_FRAMES_DELTA_MIN = "errorFramesDeltaMin"
	ERRORS_RX = "errorsRx"
	ERRORS_RX_DELTA = "errorsRxDelta"
	ERRORS_RX_DELTA_AVG = "errorsRxDeltaAvg"
	ERRORS_RX_DELTA_MAX = "errorsRxDeltaMax"
	ERRORS_RX_DELTA_MIN = "errorsRxDeltaMin"
	ERRORS_TX = "errorsTx"
	ERRORS_TX_DELTA = "errorsTxDelta"
	ERRORS_TX_DELTA_AVG = "errorsTxDeltaAvg"
	ERRORS_TX_DELTA_MAX = "errorsTxDeltaMax"
	ERRORS_TX_DELTA_MIN = "errorsTxDeltaMin"
	ERRORS_EG = "errors_eg"
	ERRORS_IN = "errors_in"
	ESCALATING = "escalating"
	ETH_EFIVERSION = "ethEFIVersion"
	ETH_EP_DN = "ethEpDn"
	ETH_LINK_PROFILE_NAME = "ethLinkProfileName"
	ETH_OPTION_ROM_VERSION = "ethOptionRomVersion"
	ETHERNET_PORT_SPEED = "ethernetPortSpeed"
	ETIME = "etime"
	EVALUATION_METHOD = "evaluationMethod"
	EVENT_READING_TYPE = "eventReadingType"
	EVENTS = "events"
	EXCESS_COLLISION = "excessCollision"
	EXCESS_COLLISION_DELTA = "excessCollisionDelta"
	EXCESS_COLLISION_DELTA_AVG = "excessCollisionDeltaAvg"
	EXCESS_COLLISION_DELTA_MAX = "excessCollisionDeltaMax"
	EXCESS_COLLISION_DELTA_MIN = "excessCollisionDeltaMin"
	EXIT_SIGNAL = "exitSignal"
	EXP = "exp"
	EXPIRATION = "expiration"
	EXPIRATION_WARN_TIME = "expirationWarnTime"
	EXPIRES = "expires"
	EXPORT_FAILURE_REASON = "exportFailureReason"
	EXPORT_INTERNAL = "exportInternal"
	EXPORT_STATUS = "exportStatus"
	EXPORTER_SOURCE_MAC = "exporterSourceMac"
	EXPORTER_STATS_TIMEOUT = "exporterStatsTimeout"
	EXT_BROADCAST = "extBroadcast"
	EXT_DEP = "extDep"
	EXT_GW = "extGw"
	EXT_IPPOOL_NAME = "extIPPoolName"
	EXT_IPSTATE = "extIPState"
	EXT_IP = "extIp"
	EXT_IP_POOL_NAME = "extIpPoolName"
	EXT_KEY = "extKey"
	EXT_MANAGED = "extManaged"
	EXT_MASK = "extMask"
	EXTERNAL_RESOLVE_NAME = "externalResolveName"
	FAB_EXT_ID = "fabExtId"
	FABRIC = "fabric"
	FABRIC_EP_DN = "fabricEpDn"
	FABRIC_ID = "fabricId"
	FABRIC_NETWORK_NAME = "fabricNetworkName"
	FAIL_REPORT_COUNT = "failReportCount"
	FAILED = "failed"
	FAILOVER = "failover"
	FAILURE_ACTION = "failureAction"
	FALSE_HITS = "falseHits"
	FAN_CAPACITY = "fanCapacity"
	FAN_CTRLR_INLET1 = "fanCtrlrInlet1"
	FAN_CTRLR_INLET1_AVG = "fanCtrlrInlet1Avg"
	FAN_CTRLR_INLET1_MAX = "fanCtrlrInlet1Max"
	FAN_CTRLR_INLET1_MIN = "fanCtrlrInlet1Min"
	FAN_CTRLR_INLET2 = "fanCtrlrInlet2"
	FAN_CTRLR_INLET2_AVG = "fanCtrlrInlet2Avg"
	FAN_CTRLR_INLET2_MAX = "fanCtrlrInlet2Max"
	FAN_CTRLR_INLET2_MIN = "fanCtrlrInlet2Min"
	FAN_CTRLR_INLET3 = "fanCtrlrInlet3"
	FAN_CTRLR_INLET3_AVG = "fanCtrlrInlet3Avg"
	FAN_CTRLR_INLET3_MAX = "fanCtrlrInlet3Max"
	FAN_CTRLR_INLET3_MIN = "fanCtrlrInlet3Min"
	FAN_CTRLR_INLET4 = "fanCtrlrInlet4"
	FAN_CTRLR_INLET4_AVG = "fanCtrlrInlet4Avg"
	FAN_CTRLR_INLET4_MAX = "fanCtrlrInlet4Max"
	FAN_CTRLR_INLET4_MIN = "fanCtrlrInlet4Min"
	FAN_MODULES_SUPPORTED = "fanModulesSupported"
	FAULT_MONITORING = "faultMonitoring"
	FAULTS = "faults"
	FC_FWVERSION = "fcFWVersion"
	FC_OPTION_ROM_VERSION = "fcOptionRomVersion"
	FC_ZONE_SHARING_MODE = "fcZoneSharingMode"
	FCOE_ID = "fcoeId"
	FCOE_STATE = "fcoeState"
	FCOE_STATE_REASON = "fcoeStateReason"
	FCOE_VLAN = "fcoeVlan"
	FCP_ERROR_RECOVERY = "fcpErrorRecovery"
	FCS = "fcs"
	FCS_DELTA = "fcsDelta"
	FCS_DELTA_AVG = "fcsDeltaAvg"
	FCS_DELTA_MAX = "fcsDeltaMax"
	FCS_DELTA_MIN = "fcsDeltaMin"
	FE_OFFLINE_TS = "feOfflineTs"
	FE_READY_TS = "feReadyTs"
	FEATURE = "feature"
	FEATURE_NAME = "featureName"
	FEATURE_STATUS = "featureStatus"
	FIBRE_CHANNEL_PORT_SPEED = "fibreChannelPortSpeed"
	FILE_DIR = "fileDir"
	FILE_HOST = "fileHost"
	FILE_NAME = "fileName"
	FILE_PARSE_FAILURES = "fileParseFailures"
	FILE_PASSWD = "filePasswd"
	FILE_PATH = "filePath"
	FILE_PORT = "filePort"
	FILE_PROTO = "fileProto"
	FILE_USER = "fileUser"
	FILES_PARSED = "filesParsed"
	FILL_PATTERN = "fillPattern"
	FILTER = "filter"
	FILTER_CLASS_ID = "filterClassId"
	FILTER_PROP_ID1 = "filterPropId1"
	FILTER_PROP_ID2 = "filterPropId2"
	FILTER_PROP_ID3 = "filterPropId3"
	FILTER_PROP_VALUE1 = "filterPropValue1"
	FILTER_PROP_VALUE2 = "filterPropValue2"
	FILTER_PROP_VALUE3 = "filterPropValue3"
	FIRST_INDEX = "firstIndex"
	FIRST_NAME = "firstName"
	FLAGS = "flags"
	FLAP_INTERVAL = "flapInterval"
	FLEX_FLASH_RAIDREPORTING_STATE = "flexFlashRAIDReportingState"
	FLEX_FLASH_SCRUB = "flexFlashScrub"
	FLEX_FLASH_STATE = "flexFlashState"
	FLEX_FLASH_TYPE = "flexFlashType"
	FLG_INITIAL_ACTIVE = "flgInitialActive"
	FLOW_CONTROL_ERRORS = "flowControlErrors"
	FLOW_CONTROL_ERRORS15_MIN = "flowControlErrors15Min"
	FLOW_CONTROL_ERRORS15_MIN_H = "flowControlErrors15MinH"
	FLOW_CONTROL_ERRORS1_DAY = "flowControlErrors1Day"
	FLOW_CONTROL_ERRORS1_DAY_H = "flowControlErrors1DayH"
	FLOW_CONTROL_ERRORS1_HOUR = "flowControlErrors1Hour"
	FLOW_CONTROL_ERRORS1_HOUR_H = "flowControlErrors1HourH"
	FLOW_CONTROL_ERRORS1_WEEK = "flowControlErrors1Week"
	FLOW_CONTROL_ERRORS1_WEEK_H = "flowControlErrors1WeekH"
	FLOW_CONTROL_ERRORS2_WEEKS = "flowControlErrors2Weeks"
	FLOW_CONTROL_ERRORS2_WEEKS_H = "flowControlErrors2WeeksH"
	FLOW_CTRL_POLICY = "flowCtrlPolicy"
	FLOW_EXP_PROFILE = "flowExpProfile"
	FLOW_MON_COLLECTOR = "flowMonCollector"
	FLOW_MON_PROTOCOL = "flowMonProtocol"
	FLOW_MON_RECORD_DEF = "flowMonRecordDef"
	FLOW_PROTOCOL = "flowProtocol"
	FLOW_RECORD_DEF_NAME = "flowRecordDefName"
	FLOW_TIMEOUT_POLICY = "flowTimeoutPolicy"
	FLT_AGGR = "fltAggr"
	FM_TEMP_SEN_IO = "fmTempSenIo"
	FM_TEMP_SEN_IO_AVG = "fmTempSenIoAvg"
	FM_TEMP_SEN_IO_MAX = "fmTempSenIoMax"
	FM_TEMP_SEN_IO_MIN = "fmTempSenIoMin"
	FM_TEMP_SEN_REAR = "fmTempSenRear"
	FM_TEMP_SEN_REAR_AVG = "fmTempSenRearAvg"
	FM_TEMP_SEN_REAR_L = "fmTempSenRearL"
	FM_TEMP_SEN_REAR_LAVG = "fmTempSenRearLAvg"
	FM_TEMP_SEN_REAR_LMAX = "fmTempSenRearLMax"
	FM_TEMP_SEN_REAR_LMIN = "fmTempSenRearLMin"
	FM_TEMP_SEN_REAR_MAX = "fmTempSenRearMax"
	FM_TEMP_SEN_REAR_MIN = "fmTempSenRearMin"
	FM_TEMP_SEN_REAR_R = "fmTempSenRearR"
	FM_TEMP_SEN_REAR_RAVG = "fmTempSenRearRAvg"
	FM_TEMP_SEN_REAR_RMAX = "fmTempSenRearRMax"
	FM_TEMP_SEN_REAR_RMIN = "fmTempSenRearRMin"
	FN_DEF_NAME = "fnDefName"
	FN_NAME = "fnName"
	FORCE_DEPLOY = "forceDeploy"
	FORCE_UPDATE_VERSION = "forceUpdateVersion"
	FORGE = "forge"
	FORGE_MAC = "forgeMac"
	FORM = "form"
	FORM_FACTOR = "formFactor"
	FORMAT = "format"
	FORWARDING_FACILITY = "forwardingFacility"
	FP = "fp"
	FROM = "from"
	FRONT_TEMP = "frontTemp"
	FRONT_TEMP_AVG = "frontTempAvg"
	FRONT_TEMP_MAX = "frontTempMax"
	FRONT_TEMP_MIN = "frontTempMin"
	FRU_CAP_DN = "fruCapDn"
	FRU_ID = "fruId"
	FRU_IDENT_TRIG_TS = "fruIdentTrigTs"
	FRU_MAJOR_TYPE = "fruMajorType"
	FRU_MINOR_TYPE = "fruMinorType"
	FSM_DESCR = "fsmDescr"
	FSM_FLAGS = "fsmFlags"
	FSM_PREV = "fsmPrev"
	FSM_PROGR = "fsmProgr"
	FSM_RMT_INV_ERR_CODE = "fsmRmtInvErrCode"
	FSM_RMT_INV_ERR_DESCR = "fsmRmtInvErrDescr"
	FSM_RMT_INV_RSLT = "fsmRmtInvRslt"
	FSM_STAGE_DESCR = "fsmStageDescr"
	FSM_STAMP = "fsmStamp"
	FSM_STATUS = "fsmStatus"
	FSM_TRY = "fsmTry"
	FTR_MO_CLASS_NAME = "ftrMoClassName"
	FULL_PATHNAME = "fullPathname"
	FUNCTIONAL_STATE = "functionalState"
	FW_UPDATE_TIMEOUT = "fwUpdateTimeout"
	FW_VERSION_HI = "fwVersionHi"
	FW_VERSION_LO = "fwVersionLo"
	FW_VERSION_OPR = "fwVersionOpr"
	FWD_LOOKUP_NO_HIT = "fwdLookupNoHit"
	FWD_LOOKUP_NO_HIT_DELTA = "fwdLookupNoHitDelta"
	FWD_LOOKUP_NO_HIT_DELTA_AVG = "fwdLookupNoHitDeltaAvg"
	FWD_LOOKUP_NO_HIT_DELTA_MAX = "fwdLookupNoHitDeltaMax"
	FWD_LOOKUP_NO_HIT_DELTA_MIN = "fwdLookupNoHitDeltaMin"
	GEN_NUM = "genNum"
	GEN_NUM_SYNC = "genNumSync"
	GENCOUNT = "gencount"
	GENERATION = "generation"
	GIANTS = "giants"
	GIANTS_DELTA = "giantsDelta"
	GIANTS_DELTA_AVG = "giantsDeltaAvg"
	GIANTS_DELTA_MAX = "giantsDeltaMax"
	GIANTS_DELTA_MIN = "giantsDeltaMin"
	GID = "gid"
	GLOBAL = "global"
	GLOBAL_ID = "globalId"
	GOOD_PACKETS = "goodPackets"
	GOOD_PACKETS_DELTA = "goodPacketsDelta"
	GOOD_PACKETS_DELTA_AVG = "goodPacketsDeltaAvg"
	GOOD_PACKETS_DELTA_MAX = "goodPacketsDeltaMax"
	GOOD_PACKETS_DELTA_MIN = "goodPacketsDeltaMin"
	GRACE_PERIOD = "gracePeriod"
	GRACE_PERIOD_USED = "gracePeriodUsed"
	GREATER_THAN_OR_EQUAL_TO9216 = "greaterThanOrEqualTo9216"
	GREATER_THAN_OR_EQUAL_TO9216_DELTA = "greaterThanOrEqualTo9216Delta"
	GREATER_THAN_OR_EQUAL_TO9216_DELTA_AVG = "greaterThanOrEqualTo9216DeltaAvg"
	GREATER_THAN_OR_EQUAL_TO9216_DELTA_MAX = "greaterThanOrEqualTo9216DeltaMax"
	GREATER_THAN_OR_EQUAL_TO9216_DELTA_MIN = "greaterThanOrEqualTo9216DeltaMin"
	GROUP = "group"
	GROUP_NAME = "groupName"
	GROUP_POLICY_NAME = "groupPolicyName"
	GUID = "guid"
	GW_ADDR = "gwAddr"
	GW_SUBNET = "gwSubnet"
	HA = "ha"
	HA_FAILURE_REASON = "haFailureReason"
	HA_READINESS = "haReadiness"
	HA_READY = "haReady"
	HAS_LAST_DEST = "hasLastDest"
	HBA_MODE = "hbaMode"
	HEALTH_LED_STATE = "healthLedState"
	HEALTH_LED_STATE_QUALIFIER = "healthLedStateQualifier"
	HEAP_SIZE = "heapSize"
	HEAP_SIZE16_GB = "heapSize16Gb"
	HEARTBEAT_REQUEST = "heartbeatRequest"
	HEARTBEAT_RESPONSE = "heartbeatResponse"
	HEIGHT = "height"
	HIERARCHICAL = "hierarchical"
	HIGHEST_SEVERITY = "highestSeverity"
	HISTORY_COUNT = "historyCount"
	HORIZONTAL_START_OFFSET = "horizontalStartOffset"
	HOST = "host"
	HOST_CONTROL = "hostControl"
	HOST_FW_POLICY_NAME = "hostFwPolicyName"
	HOST_ID = "hostId"
	HOST_IF_DN = "hostIfDn"
	HOST_NAME = "hostName"
	HOST_NVRAM = "hostNvram"
	HOST_NW_IOPERF = "hostNwIOPerf"
	HOST_REPORTED = "hostReported"
	HOST_VISIBLE = "hostVisible"
	HOSTNAME = "hostname"
	HOUR = "hour"
	HV_DN = "hvDn"
	HV_TYPE = "hvType"
	HV_UUID = "hvUuid"
	HW_MODEL = "hwModel"
	HW_REVISION = "hwRevision"
	HW_VENDOR = "hwVendor"
	HW_VERSION = "hwVersion"
	HYSTERISIS_DOWN = "hysterisisDown"
	HYSTERISIS_UP = "hysterisisUp"
	I_SCSIVNIC_NAME = "iSCSIVnicName"
	ID = "id"
	ID_COUNT = "idCount"
	IDENT_POOL_NAME = "identPoolName"
	IDENT_TYPE = "identType"
	IDENTITY = "identity"
	IDLE_POWER = "idlePower"
	IF_ROLE = "ifRole"
	IF_TYPE = "ifType"
	IGNORE_CAP = "ignoreCap"
	IGNORE_COMP_CHECK = "ignoreCompCheck"
	IMAGE = "image"
	IMAGE_DELETED = "imageDeleted"
	IMAGE_NAME = "imageName"
	IMAGE_PRESENCE = "imagePresence"
	IMAGE_SIZE = "imageSize"
	IMG_LOC = "imgLoc"
	IMG_NAME = "imgName"
	IMG_POLICY_NAME = "imgPolicyName"
	IMG_SEC_POLICY_NAME = "imgSecPolicyName"
	IMPACT_ANALYZER_ID = "impactAnalyzerId"
	IN = "in"
	IN_PROGRESS = "inProgress"
	INACTIVE_TIMEOUT = "inactiveTimeout"
	INBAND_IF_GW = "inbandIfGw"
	INBAND_IF_IP = "inbandIfIp"
	INBAND_IF_MASK = "inbandIfMask"
	INBAND_IF_VNET = "inbandIfVnet"
	IND = "ind"
	INDEX = "index"
	INFRA_BUNDLE_NAME = "infraBundleName"
	INFRA_BUNDLE_VERSION = "infraBundleVersion"
	INI_NAME = "iniName"
	INIT_NAME_SUFFIX = "initNameSuffix"
	INIT_SEQ = "initSeq"
	INIT_TS = "initTs"
	INITIATOR = "initiator"
	INITIATOR_DN = "initiatorDn"
	INITIATOR_NAME = "initiatorName"
	INLET = "inlet"
	INLET1 = "inlet1"
	INLET1_AVG = "inlet1Avg"
	INLET1_MAX = "inlet1Max"
	INLET1_MIN = "inlet1Min"
	INLET_AVG = "inletAvg"
	INLET_MAX = "inletMax"
	INLET_MIN = "inletMin"
	INLINE_GROUP_SEPARATION = "inlineGroupSeparation"
	INLINE_GROUP_SIZE = "inlineGroupSize"
	INLINE_OFFSET = "inlineOffset"
	INO = "ino"
	INPUT210V = "input210v"
	INPUT210V_AVG = "input210vAvg"
	INPUT210V_MAX = "input210vMax"
	INPUT210V_MIN = "input210vMin"
	INPUT_CURRENT = "inputCurrent"
	INPUT_CURRENT_AVG = "inputCurrentAvg"
	INPUT_CURRENT_MAX = "inputCurrentMax"
	INPUT_CURRENT_MIN = "inputCurrentMin"
	INPUT_MEGABYTES = "inputMegabytes"
	INPUT_MEGABYTES_DELTA = "inputMegabytesDelta"
	INPUT_MEGABYTES_DELTA_AVG = "inputMegabytesDeltaAvg"
	INPUT_MEGABYTES_DELTA_MAX = "inputMegabytesDeltaMax"
	INPUT_MEGABYTES_DELTA_MIN = "inputMegabytesDeltaMin"
	INPUT_POWER = "inputPower"
	INPUT_POWER_AVG = "inputPowerAvg"
	INPUT_POWER_MAX = "inputPowerMax"
	INPUT_POWER_MIN = "inputPowerMin"
	INPUT_POWER_STATE = "inputPowerState"
	INPUT_REQUESTS = "inputRequests"
	INPUT_REQUESTS_DELTA = "inputRequestsDelta"
	INPUT_REQUESTS_DELTA_AVG = "inputRequestsDeltaAvg"
	INPUT_REQUESTS_DELTA_MAX = "inputRequestsDeltaMax"
	INPUT_REQUESTS_DELTA_MIN = "inputRequestsDeltaMin"
	INPUT_STATUS = "inputStatus"
	INPUT_VOLTAGE = "inputVoltage"
	INPUT_VOLTAGE_AVG = "inputVoltageAvg"
	INPUT_VOLTAGE_MAX = "inputVoltageMax"
	INPUT_VOLTAGE_MIN = "inputVoltageMin"
	INST = "inst"
	INST_TYPE = "instType"
	INSTANCE = "instance"
	INSTANCE_ID = "instanceId"
	INSTANCE_MOD = "instanceMod"
	INT_DEL = "intDel"
	INT_ID = "intId"
	INT_MAC_RX = "intMacRx"
	INT_MAC_RX_DELTA = "intMacRxDelta"
	INT_MAC_RX_DELTA_AVG = "intMacRxDeltaAvg"
	INT_MAC_RX_DELTA_MAX = "intMacRxDeltaMax"
	INT_MAC_RX_DELTA_MIN = "intMacRxDeltaMin"
	INT_MAC_TX = "intMacTx"
	INT_MAC_TX_DELTA = "intMacTxDelta"
	INT_MAC_TX_DELTA_AVG = "intMacTxDeltaAvg"
	INT_MAC_TX_DELTA_MAX = "intMacTxDeltaMax"
	INT_MAC_TX_DELTA_MIN = "intMacTxDeltaMin"
	INT_TYPE = "intType"
	INTEGRATED = "integrated"
	INTENT = "intent"
	INTEREST = "interest"
	INTERFACE_TABLE_TIMEOUT = "interfaceTableTimeout"
	INTERNALPORTS = "internalports"
	INTERVAL = "interval"
	INTERVAL_DAYS = "intervalDays"
	INTERVALS = "intervals"
	INTF = "intf"
	INTR_COUNT = "intrCount"
	INV_TAG = "invTag"
	INVALID_CRCCOUNT = "invalidCRCCount"
	INVALID_CRCCOUNT_DELTA = "invalidCRCCountDelta"
	INVALID_CRCCOUNT_DELTA_AVG = "invalidCRCCountDeltaAvg"
	INVALID_CRCCOUNT_DELTA_MAX = "invalidCRCCountDeltaMax"
	INVALID_CRCCOUNT_DELTA_MIN = "invalidCRCCountDeltaMin"
	INVENTORY_STATUS = "inventoryStatus"
	IO_POLICY = "ioPolicy"
	IO_THROTTLE_COUNT = "ioThrottleCount"
	IOCARD_TYPE = "iocardType"
	IOH1_TEMP = "ioh1Temp"
	IOH1_TEMP_AVG = "ioh1TempAvg"
	IOH1_TEMP_MAX = "ioh1TempMax"
	IOH1_TEMP_MIN = "ioh1TempMin"
	IOH2_TEMP = "ioh2Temp"
	IOH2_TEMP_AVG = "ioh2TempAvg"
	IOH2_TEMP_MAX = "ioh2TempMax"
	IOH2_TEMP_MIN = "ioh2TempMin"
	IOM_EP = "iomEp"
	IP = "ip"
	IP_A = "ipA"
	IP_ADDRESS = "ipAddress"
	IP_B = "ipB"
	IP_HASH = "ipHash"
	IP_POOL_GUID = "ipPoolGuid"
	IP_POOL_NAME = "ipPoolName"
	IP_V4_STATE = "ipV4State"
	IP_V6_STATE = "ipV6State"
	IPV4KEYS = "ipv4keys"
	IPV6 = "ipv6"
	IPV6_A = "ipv6A"
	IPV6_ADDR = "ipv6Addr"
	IPV6_B = "ipv6B"
	IPV6_TARGET1 = "ipv6Target1"
	IPV6_TARGET2 = "ipv6Target2"
	IPV6_TARGET3 = "ipv6Target3"
	IPV6ADDR = "ipv6addr"
	IPV6KEYS = "ipv6keys"
	IQN = "iqn"
	IQN_IDENT_POOL_NAME = "iqnIdentPoolName"
	IS_CHANGED_OBJECT_UPDATE = "isChangedObjectUpdate"
	IS_CONFIG_SUCCESS = "isConfigSuccess"
	IS_DEFAULT = "isDefault"
	IS_DEFAULT_DERIVED = "isDefaultDerived"
	IS_DELETE = "isDelete"
	IS_DELETED = "isDeleted"
	IS_HOST_AGENT_PRESENT = "isHostAgentPresent"
	IS_IMPORTABLE = "isImportable"
	IS_NATIVE = "isNative"
	IS_NET_BIOSENABLED = "isNetBIOSEnabled"
	IS_PASSTHROUGH = "isPassthrough"
	IS_PORT_CHANNEL_MEMBER = "isPortChannelMember"
	IS_PRESENT = "isPresent"
	IS_SERVICE_TEMPLATE = "isServiceTemplate"
	IS_SET_SNMP_SECURE = "isSetSnmpSecure"
	IS_SUPPORTED = "isSupported"
	IS_SYNC = "isSync"
	IS_SYNC_ALLOWED = "isSyncAllowed"
	IS_VALID_CONFIG = "isValidConfig"
	ISCSI_CONFIG_ISSUES = "iscsiConfigIssues"
	ISONAME = "isoname"
	ISSUES = "issues"
	ITEM = "item"
	ITEM_DN = "itemDn"
	JOB = "job"
	JOB_COUNT = "jobCount"
	JUMBO_PACKETS = "jumboPackets"
	JUMBO_PACKETS_DELTA = "jumboPacketsDelta"
	JUMBO_PACKETS_DELTA_AVG = "jumboPacketsDeltaAvg"
	JUMBO_PACKETS_DELTA_MAX = "jumboPacketsDeltaMax"
	JUMBO_PACKETS_DELTA_MIN = "jumboPacketsDeltaMin"
	KERNEL_NAME = "kernelName"
	KERNEL_RELEASE = "kernelRelease"
	KERNEL_VERSION = "kernelVersion"
	KEY = "key"
	KEY_DESCR = "keyDescr"
	KEY_DN = "keyDn"
	KEY_INST = "keyInst"
	KEY_RING = "keyRing"
	KEY_SET = "keySet"
	KEY_TYPE = "keyType"
	KS_STARTUP_VERSION = "ksStartupVersion"
	KS_VERSION = "ksVersion"
	L2KEYS = "l2keys"
	LABEL = "label"
	LAN_CONN_POLICY_NAME = "lanConnPolicyName"
	LARGE_RECEIVE = "largeReceive"
	LARGETXS = "largetxs"
	LAST_BACKUP = "lastBackup"
	LAST_CMD = "lastCmd"
	LAST_DEADLINE = "lastDeadline"
	LAST_EVT = "lastEvt"
	LAST_EVT_TS = "lastEvtTs"
	LAST_EXIT_CODE = "lastExitCode"
	LAST_NAME = "lastName"
	LAST_OPER_STATE_REPORT = "lastOperStateReport"
	LAST_POLL_TS = "lastPollTs"
	LAST_TRANSITION = "lastTransition"
	LAST_UPDATE = "lastUpdate"
	LAST_UPDATE_TIME = "lastUpdateTime"
	LAST_UPDATED_TIME = "lastUpdatedTime"
	LATE_COLLISION = "lateCollision"
	LATE_COLLISION_DELTA = "lateCollisionDelta"
	LATE_COLLISION_DELTA_AVG = "lateCollisionDeltaAvg"
	LATE_COLLISION_DELTA_MAX = "lateCollisionDeltaMax"
	LATE_COLLISION_DELTA_MIN = "lateCollisionDeltaMin"
	LATENCY = "latency"
	LC = "lc"
	LC_NAME = "lcName"
	LC_TS = "lcTs"
	LEADERSHIP = "leadership"
	LEARN_CYCLE_REQUESTED = "learnCycleRequested"
	LEARN_MODE = "learnMode"
	LEARN_REQ_DROP = "learnReqDrop"
	LEARN_REQ_DROP_DELTA = "learnReqDropDelta"
	LEARN_REQ_DROP_DELTA_AVG = "learnReqDropDeltaAvg"
	LEARN_REQ_DROP_DELTA_MAX = "learnReqDropDeltaMax"
	LEARN_REQ_DROP_DELTA_MIN = "learnReqDropDeltaMin"
	LEFT_DATA = "leftData"
	LENGTH = "length"
	LESS_THAN1024 = "lessThan1024"
	LESS_THAN1024_DELTA = "lessThan1024Delta"
	LESS_THAN1024_DELTA_AVG = "lessThan1024DeltaAvg"
	LESS_THAN1024_DELTA_MAX = "lessThan1024DeltaMax"
	LESS_THAN1024_DELTA_MIN = "lessThan1024DeltaMin"
	LESS_THAN128 = "lessThan128"
	LESS_THAN128_DELTA = "lessThan128Delta"
	LESS_THAN128_DELTA_AVG = "lessThan128DeltaAvg"
	LESS_THAN128_DELTA_MAX = "lessThan128DeltaMax"
	LESS_THAN128_DELTA_MIN = "lessThan128DeltaMin"
	LESS_THAN2048 = "lessThan2048"
	LESS_THAN2048_DELTA = "lessThan2048Delta"
	LESS_THAN2048_DELTA_AVG = "lessThan2048DeltaAvg"
	LESS_THAN2048_DELTA_MAX = "lessThan2048DeltaMax"
	LESS_THAN2048_DELTA_MIN = "lessThan2048DeltaMin"
	LESS_THAN256 = "lessThan256"
	LESS_THAN256_DELTA = "lessThan256Delta"
	LESS_THAN256_DELTA_AVG = "lessThan256DeltaAvg"
	LESS_THAN256_DELTA_MAX = "lessThan256DeltaMax"
	LESS_THAN256_DELTA_MIN = "lessThan256DeltaMin"
	LESS_THAN4096 = "lessThan4096"
	LESS_THAN4096_DELTA = "lessThan4096Delta"
	LESS_THAN4096_DELTA_AVG = "lessThan4096DeltaAvg"
	LESS_THAN4096_DELTA_MAX = "lessThan4096DeltaMax"
	LESS_THAN4096_DELTA_MIN = "lessThan4096DeltaMin"
	LESS_THAN512 = "lessThan512"
	LESS_THAN512_DELTA = "lessThan512Delta"
	LESS_THAN512_DELTA_AVG = "lessThan512DeltaAvg"
	LESS_THAN512_DELTA_MAX = "lessThan512DeltaMax"
	LESS_THAN512_DELTA_MIN = "lessThan512DeltaMin"
	LESS_THAN64 = "lessThan64"
	LESS_THAN64_DELTA = "lessThan64Delta"
	LESS_THAN64_DELTA_AVG = "lessThan64DeltaAvg"
	LESS_THAN64_DELTA_MAX = "lessThan64DeltaMax"
	LESS_THAN64_DELTA_MIN = "lessThan64DeltaMin"
	LESS_THAN8192 = "lessThan8192"
	LESS_THAN8192_DELTA = "lessThan8192Delta"
	LESS_THAN8192_DELTA_AVG = "lessThan8192DeltaAvg"
	LESS_THAN8192_DELTA_MAX = "lessThan8192DeltaMax"
	LESS_THAN8192_DELTA_MIN = "lessThan8192DeltaMin"
	LESS_THAN9216 = "lessThan9216"
	LESS_THAN9216_DELTA = "lessThan9216Delta"
	LESS_THAN9216_DELTA_AVG = "lessThan9216DeltaAvg"
	LESS_THAN9216_DELTA_MAX = "lessThan9216DeltaMax"
	LESS_THAN9216_DELTA_MIN = "lessThan9216DeltaMin"
	LESS_THAN_OR_EQUAL_TO1518 = "lessThanOrEqualTo1518"
	LESS_THAN_OR_EQUAL_TO1518_DELTA = "lessThanOrEqualTo1518Delta"
	LESS_THAN_OR_EQUAL_TO1518_DELTA_AVG = "lessThanOrEqualTo1518DeltaAvg"
	LESS_THAN_OR_EQUAL_TO1518_DELTA_MAX = "lessThanOrEqualTo1518DeltaMax"
	LESS_THAN_OR_EQUAL_TO1518_DELTA_MIN = "lessThanOrEqualTo1518DeltaMin"
	LEVEL = "level"
	LEVEL_FLAG = "levelFlag"
	LIC_GP = "licGP"
	LIC_STATE = "licState"
	LIC_VENDOR = "licVendor"
	LIC_VERSION = "licVersion"
	LIFE_CYCLE = "lifeCycle"
	LIMIT = "limit"
	LINE = "line"
	LINK_AGGREGATION_PREF = "linkAggregationPref"
	LINK_DOWN_TIMEOUT = "linkDownTimeout"
	LINK_FAILURE_COUNT = "linkFailureCount"
	LINK_FAILURE_COUNT_DELTA = "linkFailureCountDelta"
	LINK_FAILURE_COUNT_DELTA_AVG = "linkFailureCountDeltaAvg"
	LINK_FAILURE_COUNT_DELTA_MAX = "linkFailureCountDeltaMax"
	LINK_FAILURE_COUNT_DELTA_MIN = "linkFailureCountDeltaMin"
	LINK_FAILURES = "linkFailures"
	LINK_FAILURES_DELTA = "linkFailuresDelta"
	LINK_FAILURES_DELTA_AVG = "linkFailuresDeltaAvg"
	LINK_FAILURES_DELTA_MAX = "linkFailuresDeltaMax"
	LINK_FAILURES_DELTA_MIN = "linkFailuresDeltaMin"
	LINK_SPEED = "linkSpeed"
	LINK_STATE = "linkState"
	LIP_COUNT = "lipCount"
	LIP_COUNT_DELTA = "lipCountDelta"
	LIP_COUNT_DELTA_AVG = "lipCountDeltaAvg"
	LIP_COUNT_DELTA_MAX = "lipCountDeltaMax"
	LIP_COUNT_DELTA_MIN = "lipCountDeltaMin"
	LLDP_MAC = "lldpMac"
	LLDP_MAC_OFFSET1 = "lldpMacOffset1"
	LLDP_MAC_OFFSET2 = "lldpMacOffset2"
	LOAD = "load"
	LOAD_AVG = "loadAvg"
	LOAD_ERRORS = "loadErrors"
	LOAD_MAX = "loadMax"
	LOAD_MIN = "loadMin"
	LOAD_WARNINGS = "loadWarnings"
	LOCAL = "local"
	LOCAL_DIR = "localDir"
	LOCAL_DISK_POLICY_NAME = "localDiskPolicyName"
	LOCAL_HOST = "localHost"
	LOCAL_ID = "localId"
	LOCALE = "locale"
	LOCALES = "locales"
	LOCALITY = "locality"
	LOCATION = "location"
	LOCATOR_BEACON_SUPPORTED = "locatorBeaconSupported"
	LOGIN_TIME = "loginTime"
	LOSS_OF_SIGNAL_COUNT = "lossOfSignalCount"
	LOSS_OF_SIGNAL_COUNT_DELTA = "lossOfSignalCountDelta"
	LOSS_OF_SIGNAL_COUNT_DELTA_AVG = "lossOfSignalCountDeltaAvg"
	LOSS_OF_SIGNAL_COUNT_DELTA_MAX = "lossOfSignalCountDeltaMax"
	LOSS_OF_SIGNAL_COUNT_DELTA_MIN = "lossOfSignalCountDeltaMin"
	LOSS_OF_SYNC_COUNT = "lossOfSyncCount"
	LOSS_OF_SYNC_COUNT_DELTA = "lossOfSyncCountDelta"
	LOSS_OF_SYNC_COUNT_DELTA_AVG = "lossOfSyncCountDeltaAvg"
	LOSS_OF_SYNC_COUNT_DELTA_MAX = "lossOfSyncCountDeltaMax"
	LOSS_OF_SYNC_COUNT_DELTA_MIN = "lossOfSyncCountDeltaMin"
	LOW_VOLTAGE_MEMORY = "lowVoltageMemory"
	LS_DN = "lsDn"
	LS_SERVER_NAME = "lsServerName"
	LS_SERVER_TMPL_NAME = "lsServerTmplName"
	LUN = "lun"
	LUN_BUSY_RETRY_COUNT = "lunBusyRetryCount"
	LUN_ID = "lunId"
	LUNS_PER_TARGET = "lunsPerTarget"
	MAC = "mac"
	MAC1 = "mac1"
	MAC2 = "mac2"
	MAC_ADDR = "macAddr"
	MAC_ADDR_TYPE = "macAddrType"
	MAC_ADDRESS = "macAddress"
	MAC_AGING = "macAging"
	MAC_DISCARDED_PACKETS = "macDiscardedPackets"
	MAC_DISCARDED_PACKETS_DELTA = "macDiscardedPacketsDelta"
	MAC_DISCARDED_PACKETS_DELTA_AVG = "macDiscardedPacketsDeltaAvg"
	MAC_DISCARDED_PACKETS_DELTA_MAX = "macDiscardedPacketsDeltaMax"
	MAC_DISCARDED_PACKETS_DELTA_MIN = "macDiscardedPacketsDeltaMin"
	MAC_LEFT = "macLeft"
	MAC_OFFSET1 = "macOffset1"
	MAC_OFFSET2 = "macOffset2"
	MAC_OFFSET_SUB00 = "macOffsetSub00"
	MAC_OFFSET_SUB01 = "macOffsetSub01"
	MAC_OFFSET_SUB02 = "macOffsetSub02"
	MAC_OFFSET_SUB03 = "macOffsetSub03"
	MAC_OFFSET_SUB10 = "macOffsetSub10"
	MAC_OFFSET_SUB11 = "macOffsetSub11"
	MAC_OFFSET_SUB12 = "macOffsetSub12"
	MAC_OFFSET_SUB13 = "macOffsetSub13"
	MAC_REGISTER_MODE = "macRegisterMode"
	MAC_RIGHT = "macRight"
	MAIN_BOARD_OUTLET1 = "mainBoardOutlet1"
	MAIN_BOARD_OUTLET1_AVG = "mainBoardOutlet1Avg"
	MAIN_BOARD_OUTLET1_MAX = "mainBoardOutlet1Max"
	MAIN_BOARD_OUTLET1_MIN = "mainBoardOutlet1Min"
	MAIN_BOARD_OUTLET2 = "mainBoardOutlet2"
	MAIN_BOARD_OUTLET2_AVG = "mainBoardOutlet2Avg"
	MAIN_BOARD_OUTLET2_MAX = "mainBoardOutlet2Max"
	MAIN_BOARD_OUTLET2_MIN = "mainBoardOutlet2Min"
	MAINT_POLICY_DN = "maintPolicyDn"
	MAINT_POLICY_NAME = "maintPolicyName"
	MAJOR_OPT_TYPE = "majorOptType"
	MALFORMED_TLPERRORS = "malformedTLPErrors"
	MALFORMED_TLPERRORS15_MIN = "malformedTLPErrors15Min"
	MALFORMED_TLPERRORS15_MIN_H = "malformedTLPErrors15MinH"
	MALFORMED_TLPERRORS1_DAY = "malformedTLPErrors1Day"
	MALFORMED_TLPERRORS1_DAY_H = "malformedTLPErrors1DayH"
	MALFORMED_TLPERRORS1_HOUR = "malformedTLPErrors1Hour"
	MALFORMED_TLPERRORS1_HOUR_H = "malformedTLPErrors1HourH"
	MALFORMED_TLPERRORS1_WEEK = "malformedTLPErrors1Week"
	MALFORMED_TLPERRORS1_WEEK_H = "malformedTLPErrors1WeekH"
	MALFORMED_TLPERRORS2_WEEKS = "malformedTLPErrors2Weeks"
	MALFORMED_TLPERRORS2_WEEKS_H = "malformedTLPErrors2WeeksH"
	MANAGER = "manager"
	MANAGING_INST = "managingInst"
	MASK = "mask"
	MAX_ACTIVE_SPAN_SESSION_COUNT = "maxActiveSpanSessionCount"
	MAX_BUS_ID_PER_SLOT = "maxBusIdPerSlot"
	MAX_CAP = "maxCap"
	MAX_CAPACITY = "maxCapacity"
	MAX_CORES = "maxCores"
	MAX_DATA_FIELD_SIZE = "maxDataFieldSize"
	MAX_DEADLINE_TIMEOUT = "maxDeadlineTimeout"
	MAX_DERIVABLE_WWPN = "maxDerivableWWPN"
	MAX_DEVICES = "maxDevices"
	MAX_ETH1G_PORT = "maxEth1gPort"
	MAX_ETH1G_SLOT = "maxEth1gSlot"
	MAX_ETH_PC_MEMBERS = "maxEthPcMembers"
	MAX_ETH_PCS = "maxEthPcs"
	MAX_FAIL_REPORT_COUNT = "maxFailReportCount"
	MAX_FC_SPEED = "maxFcSpeed"
	MAX_FCOE_PC_MEMBERS = "maxFcoePcMembers"
	MAX_FILES = "maxFiles"
	MAX_HITS = "maxHits"
	MAX_ID = "maxId"
	MAX_LOCAL_DISKS = "maxLocalDisks"
	MAX_PORT_ID = "maxPortId"
	MAX_PORTS = "maxPorts"
	MAX_PORTS_PER_NODE = "maxPortsPerNode"
	MAX_POWER = "maxPower"
	MAX_PRIMARY_VLAN_COUNT = "maxPrimaryVlanCount"
	MAX_PROCS = "maxProcs"
	MAX_RETRIES = "maxRetries"
	MAX_RETRY_COUNT = "maxRetryCount"
	MAX_SIZE = "maxSize"
	MAX_SPEED = "maxSpeed"
	MAX_SZ = "maxSz"
	MAX_THREADS = "maxThreads"
	MAX_UPLINK_PORTS = "maxUplinkPorts"
	MAX_VER = "maxVer"
	MAXIMUM = "maximum"
	MAXIMUM_POWER = "maximumPower"
	MAXIMUM_RETRY_COUNT = "maximumRetryCount"
	MAXIMUM_TEMPERATURE = "maximumTemperature"
	MCAST_POLICY_NAME = "mcastPolicyName"
	MEM_AVAILABLE = "memAvailable"
	MEM_AVAILABLE_AVG = "memAvailableAvg"
	MEM_AVAILABLE_MAX = "memAvailableMax"
	MEM_AVAILABLE_MIN = "memAvailableMin"
	MEM_CACHED = "memCached"
	MEM_CACHED_AVG = "memCachedAvg"
	MEM_CACHED_MAX = "memCachedMax"
	MEM_CACHED_MIN = "memCachedMin"
	MEMBER_STATUS = "memberStatus"
	MEMBERSHIP = "membership"
	MEMORY_SPEED = "memorySpeed"
	MENLO_ETH_INDEX = "menloEthIndex"
	MENLO_FC_INDEX = "menloFcIndex"
	MENLO_MCPU_INDEX = "menloMcpuIndex"
	MENLO_NET_INDEX = "menloNetIndex"
	MENLO_PORT_INDEX = "menloPortIndex"
	MENLO_QUEUE_COMPONENT = "menloQueueComponent"
	MENLO_QUEUE_INDEX = "menloQueueIndex"
	MESSAGE = "message"
	MESSAGE_SUBTYPE = "messageSubtype"
	MESSAGE_TYPE = "messageType"
	METHOD = "method"
	MEZZ_MAPPING = "mezzMapping"
	MFG_DATE = "mfgDate"
	MFG_ID = "mfgId"
	MFG_TIME = "mfgTime"
	MGMT_ACCESS_POLICY_NAME = "mgmtAccessPolicyName"
	MGMT_DAUGHTER_CARD_SLOT_ID = "mgmtDaughterCardSlotId"
	MGMT_FW_POLICY_NAME = "mgmtFwPolicyName"
	MGMT_PLANE = "mgmtPlane"
	MGMT_PLANE_VER = "mgmtPlaneVer"
	MGMT_SERVICES_STATE = "mgmtServicesState"
	MGMT_TRANSPORT = "mgmtTransport"
	MIN_BIOS_VERSION = "minBiosVersion"
	MIN_CAP = "minCap"
	MIN_CIMC_VERSION = "minCimcVersion"
	MIN_CMC_VERSION = "minCmcVersion"
	MIN_CORES = "minCores"
	MIN_ID = "minId"
	MIN_PORT_ID = "minPortId"
	MIN_POWER = "minPower"
	MIN_PROCS = "minProcs"
	MIN_REQ_POWER = "minReqPower"
	MIN_SZ = "minSz"
	MIN_THREADS = "minThreads"
	MIN_VER = "minVer"
	MIN_VER1 = "minVer1"
	MIN_VER2 = "minVer2"
	MINIMUM_POWER = "minimumPower"
	MINIMUM_SEND_NOW_INTERVAL_SECONDS = "minimumSendNowIntervalSeconds"
	MINIMUM_TEMPERATURE = "minimumTemperature"
	MINUTE = "minute"
	MIRRORING_INTER_SOCK_ERRORS = "mirroringInterSockErrors"
	MIRRORING_INTER_SOCK_ERRORS15_MIN = "mirroringInterSockErrors15Min"
	MIRRORING_INTER_SOCK_ERRORS15_MIN_H = "mirroringInterSockErrors15MinH"
	MIRRORING_INTER_SOCK_ERRORS1_DAY = "mirroringInterSockErrors1Day"
	MIRRORING_INTER_SOCK_ERRORS1_DAY_H = "mirroringInterSockErrors1DayH"
	MIRRORING_INTER_SOCK_ERRORS1_HOUR = "mirroringInterSockErrors1Hour"
	MIRRORING_INTER_SOCK_ERRORS1_HOUR_H = "mirroringInterSockErrors1HourH"
	MIRRORING_INTER_SOCK_ERRORS1_WEEK = "mirroringInterSockErrors1Week"
	MIRRORING_INTER_SOCK_ERRORS1_WEEK_H = "mirroringInterSockErrors1WeekH"
	MIRRORING_INTER_SOCK_ERRORS2_WEEKS = "mirroringInterSockErrors2Weeks"
	MIRRORING_INTER_SOCK_ERRORS2_WEEKS_H = "mirroringInterSockErrors2WeeksH"
	MIRRORING_INTRA_SOCK_ERRORS = "mirroringIntraSockErrors"
	MIRRORING_INTRA_SOCK_ERRORS15_MIN = "mirroringIntraSockErrors15Min"
	MIRRORING_INTRA_SOCK_ERRORS15_MIN_H = "mirroringIntraSockErrors15MinH"
	MIRRORING_INTRA_SOCK_ERRORS1_DAY = "mirroringIntraSockErrors1Day"
	MIRRORING_INTRA_SOCK_ERRORS1_DAY_H = "mirroringIntraSockErrors1DayH"
	MIRRORING_INTRA_SOCK_ERRORS1_HOUR = "mirroringIntraSockErrors1Hour"
	MIRRORING_INTRA_SOCK_ERRORS1_HOUR_H = "mirroringIntraSockErrors1HourH"
	MIRRORING_INTRA_SOCK_ERRORS1_WEEK = "mirroringIntraSockErrors1Week"
	MIRRORING_INTRA_SOCK_ERRORS1_WEEK_H = "mirroringIntraSockErrors1WeekH"
	MIRRORING_INTRA_SOCK_ERRORS2_WEEKS = "mirroringIntraSockErrors2Weeks"
	MIRRORING_INTRA_SOCK_ERRORS2_WEEKS_H = "mirroringIntraSockErrors2WeeksH"
	MISMATCH_ERRORS = "mismatchErrors"
	MISMATCH_ERRORS15_MIN = "mismatchErrors15Min"
	MISMATCH_ERRORS15_MIN_H = "mismatchErrors15MinH"
	MISMATCH_ERRORS1_DAY = "mismatchErrors1Day"
	MISMATCH_ERRORS1_DAY_H = "mismatchErrors1DayH"
	MISMATCH_ERRORS1_HOUR = "mismatchErrors1Hour"
	MISMATCH_ERRORS1_HOUR_H = "mismatchErrors1HourH"
	MISMATCH_ERRORS1_WEEK = "mismatchErrors1Week"
	MISMATCH_ERRORS1_WEEK_H = "mismatchErrors1WeekH"
	MISMATCH_ERRORS2_WEEKS = "mismatchErrors2Weeks"
	MISMATCH_ERRORS2_WEEKS_H = "mismatchErrors2WeeksH"
	MO_CLASS_ID = "moClassId"
	MODE = "mode"
	MODEL = "model"
	MODIFIED = "modified"
	MODULE = "module"
	MODULUS = "modulus"
	MON_TRAF_DIR = "monTrafDir"
	MONITOR_MECHANISM = "monitorMechanism"
	MOST_RECENT = "mostRecent"
	MSG_INTERVAL = "msgInterval"
	MTIME = "mtime"
	MTU = "mtu"
	MULTI_COLLISION = "multiCollision"
	MULTI_COLLISION_DELTA = "multiCollisionDelta"
	MULTI_COLLISION_DELTA_AVG = "multiCollisionDeltaAvg"
	MULTI_COLLISION_DELTA_MAX = "multiCollisionDeltaMax"
	MULTI_COLLISION_DELTA_MIN = "multiCollisionDeltaMin"
	MULTICAST_OPTIMIZE = "multicastOptimize"
	MULTICAST_PACKETS = "multicastPackets"
	MULTICAST_PACKETS_DELTA = "multicastPacketsDelta"
	MULTICAST_PACKETS_DELTA_AVG = "multicastPacketsDeltaAvg"
	MULTICAST_PACKETS_DELTA_MAX = "multicastPacketsDeltaMax"
	MULTICAST_PACKETS_DELTA_MIN = "multicastPacketsDeltaMin"
	N_OSCOUNT = "nOSCount"
	N_OSCOUNT_DELTA = "nOSCountDelta"
	N_OSCOUNT_DELTA_AVG = "nOSCountDeltaAvg"
	N_OSCOUNT_DELTA_MAX = "nOSCountDeltaMax"
	N_OSCOUNT_DELTA_MIN = "nOSCountDeltaMin"
	NAME = "name"
	NAMING_PREFIX = "namingPrefix"
	NATIVE_NET = "nativeNet"
	NATIVE_NET_DN = "nativeNetDn"
	NEED_RECOVERY = "needRecovery"
	NETFLOW_ACTIVE_TIMEOUT = "netflowActiveTimeout"
	NETFLOW_INACTIVE_TIMEOUT = "netflowInactiveTimeout"
	NETMASK = "netmask"
	NETWORK_CONFIG_ISSUES = "networkConfigIssues"
	NETWORK_TYPE = "networkType"
	NEW_FE_TS = "newFeTs"
	NEXT_DEADLINE = "nextDeadline"
	NEXT_LEARN_CYCLE_TS = "nextLearnCycleTs"
	NEXT_REQ_ID = "nextReqId"
	NF_MON_EXPORTER_NAME = "nfMonExporterName"
	NF_MONITOR_NAME = "nfMonitorName"
	NIC_DN = "nicDn"
	NLINK = "nlink"
	NO_BREAKDOWN_GREATER_THAN1518 = "noBreakdownGreaterThan1518"
	NO_BREAKDOWN_GREATER_THAN1518_DELTA = "noBreakdownGreaterThan1518Delta"
	NO_BREAKDOWN_GREATER_THAN1518_DELTA_AVG = "noBreakdownGreaterThan1518DeltaAvg"
	NO_BREAKDOWN_GREATER_THAN1518_DELTA_MAX = "noBreakdownGreaterThan1518DeltaMax"
	NO_BREAKDOWN_GREATER_THAN1518_DELTA_MIN = "noBreakdownGreaterThan1518DeltaMin"
	NO_CHANGE_INTERVAL = "noChangeInterval"
	NODE_ADDR = "nodeAddr"
	NODE_WWN = "nodeWwn"
	NOMINAL_POWER = "nominalPower"
	NOMINAL_TEMPERATURE = "nominalTemperature"
	NON_COMP_DESCR = "nonCompDescr"
	NON_COMP_DNS = "nonCompDns"
	NONKEYS = "nonkeys"
	NORMAL_VALUE = "normalValue"
	NOTIFICATION_TYPE = "notificationType"
	NS_SIZE = "nsSize"
	NUM_CERTS = "numCerts"
	NUM_DCE_PORTS = "numDcePorts"
	NUM_GPU = "numGpu"
	NUM_OF_ADAPTORS = "numOfAdaptors"
	NUM_OF_CORES = "numOfCores"
	NUM_OF_CORES_ENABLED = "numOfCoresEnabled"
	NUM_OF_CPUS = "numOfCpus"
	NUM_OF_ETH_HOST_IFS = "numOfEthHostIfs"
	NUM_OF_FC_HOST_IFS = "numOfFcHostIfs"
	NUM_OF_PHYS_SLOTS = "numOfPhysSlots"
	NUM_OF_THREADS = "numOfThreads"
	NUM_PORTS = "numPorts"
	NUM_SLOTS = "numSlots"
	NUMBER_OF_ARP_REQUESTS = "numberOfArpRequests"
	NUMBER_OF_BLOCKS = "numberOfBlocks"
	NUMBER_OF_FLEX_FLASH_CARDS = "numberOfFlexFlashCards"
	NUMBER_OF_NDISC_REQUESTS = "numberOfNdiscRequests"
	NUMBER_OF_PING_REQUESTS = "numberOfPingRequests"
	NUMBER_OF_PORTS = "numberOfPorts"
	NUMBER_OF_SLOTS = "numberOfSlots"
	NUMBER_OF_SLOTS_SPANNED = "numberOfSlotsSpanned"
	NW_CTRL_POLICY_NAME = "nwCtrlPolicyName"
	NW_TEMPL_NAME = "nwTemplName"
	OBJECT_CLASS_NAME = "objectClassName"
	OBSERVED_DN = "observedDn"
	OCCUR = "occur"
	OEM_ID = "oemId"
	OEM_NAME = "oemName"
	OEM_PART_NUMBER = "oemPartNumber"
	OFFLOAD_SUPPORT = "offloadSupport"
	OFFLOAD_TYPE = "offloadType"
	OLD_CENTRALE_MO_DN = "oldCentraleMoDn"
	OLD_CENTRALE_VNET_EP_DN = "oldCentraleVnetEpDn"
	OLD_INITIATOR_NAME = "oldInitiatorName"
	OLD_IP_V4_ADDR = "oldIpV4Addr"
	OLD_IP_V6_ADDR = "oldIpV6Addr"
	OLD_PN_DN = "oldPnDn"
	OLD_STR_TYPE = "oldStrType"
	OLD_ZONE_PREFIX = "oldZonePrefix"
	OLDADDR = "oldaddr"
	OLDUUID = "olduuid"
	OLDWWNN = "oldwwnn"
	ON_BEHALF_OF_IDENT = "onBehalfOfIdent"
	ON_BEHALF_OF_TYPE = "onBehalfOfType"
	OOB_CONTROLLER_ID = "oobControllerId"
	OOB_IF_GW = "oobIfGw"
	OOB_IF_IP = "oobIfIp"
	OOB_IF_MASK = "oobIfMask"
	OOB_INTERFACE_SUPPORTED = "oobInterfaceSupported"
	OPER_ADAPTOR_PROFILE_NAME = "operAdaptorProfileName"
	OPER_AUTH_PROFILE_NAME = "operAuthProfileName"
	OPER_BIOS_PROFILE_NAME = "operBiosProfileName"
	OPER_BOOT_POLICY_NAME = "operBootPolicyName"
	OPER_BORDER_PORT_ID = "operBorderPortId"
	OPER_BORDER_SLOT_ID = "operBorderSlotId"
	OPER_CDP_LINK_POLICY_NAME = "operCdpLinkPolicyName"
	OPER_COMMITTED = "operCommitted"
	OPER_CON_POLICY_NAME = "operConPolicyName"
	OPER_CONN = "operConn"
	OPER_DYNAMIC_CON_POLICY_NAME = "operDynamicConPolicyName"
	OPER_ETH_LINK_PROFILE_NAME = "operEthLinkProfileName"
	OPER_EXT_IPPOOL_NAME = "operExtIPPoolName"
	OPER_EXT_IP_POOL_NAME = "operExtIpPoolName"
	OPER_FABRIC_NETWORK_NAME = "operFabricNetworkName"
	OPER_FLOW_EXP_PROFILE = "operFlowExpProfile"
	OPER_FLOW_MON_RECORD_DEF = "operFlowMonRecordDef"
	OPER_FLOW_TIMEOUT_POLICY = "operFlowTimeoutPolicy"
	OPER_FN_DEF_NAME = "operFnDefName"
	OPER_HOST_FW_POLICY_NAME = "operHostFwPolicyName"
	OPER_IDENT_POOL_NAME = "operIdentPoolName"
	OPER_IQN_IDENT_POOL_NAME = "operIqnIdentPoolName"
	OPER_LAN_CONN_POLICY_NAME = "operLanConnPolicyName"
	OPER_LOCAL_DISK_POLICY_NAME = "operLocalDiskPolicyName"
	OPER_MAINT_POLICY_NAME = "operMaintPolicyName"
	OPER_MCAST_POLICY_NAME = "operMcastPolicyName"
	OPER_MGMT_ACCESS_POLICY_NAME = "operMgmtAccessPolicyName"
	OPER_MGMT_FW_POLICY_NAME = "operMgmtFwPolicyName"
	OPER_MIN = "operMin"
	OPER_NAME = "operName"
	OPER_NF_MON_EXPORTER_NAME = "operNfMonExporterName"
	OPER_NF_MONITOR_NAME = "operNfMonitorName"
	OPER_NW_CTRL_POLICY_NAME = "operNwCtrlPolicyName"
	OPER_NW_TEMPL_NAME = "operNwTemplName"
	OPER_ORDER = "operOrder"
	OPER_PEAK = "operPeak"
	OPER_PIN_TO_GROUP_NAME = "operPinToGroupName"
	OPER_PORT = "operPort"
	OPER_POWER = "operPower"
	OPER_POWER_POLICY_NAME = "operPowerPolicyName"
	OPER_POWER_REQUIREMENT = "operPowerRequirement"
	OPER_PRIO = "operPrio"
	OPER_PROP_MASK = "operPropMask"
	OPER_PROTOCOL = "operProtocol"
	OPER_PROVIDER_GROUP = "operProviderGroup"
	OPER_QOS_POLICY_NAME = "operQosPolicyName"
	OPER_QUALIFIER = "operQualifier"
	OPER_QUALIFIER_REASON = "operQualifierReason"
	OPER_REALM = "operRealm"
	OPER_SAN_CONN_POLICY_NAME = "operSanConnPolicyName"
	OPER_SCHED_NAME = "operSchedName"
	OPER_SCHEDULER = "operScheduler"
	OPER_SCRUB_POLICY_NAME = "operScrubPolicyName"
	OPER_SOL_POLICY_NAME = "operSolPolicyName"
	OPER_SPEED = "operSpeed"
	OPER_SRC_TEMPL_NAME = "operSrcTemplName"
	OPER_STATE = "operState"
	OPER_STATE_DESC = "operStateDesc"
	OPER_STATE_DESCR = "operStateDescr"
	OPER_STATE_QUAL = "operStateQual"
	OPER_STATE_REASON = "operStateReason"
	OPER_STATS_POLICY_NAME = "operStatsPolicyName"
	OPER_STATUS = "operStatus"
	OPER_STORAGE_CONN_POLICY_NAME = "operStorageConnPolicyName"
	OPER_SUPPRESS_POLICY_NAME = "operSuppressPolicyName"
	OPER_TIMEZONE = "operTimezone"
	OPER_UDLD_LINK_POLICY_NAME = "operUdldLinkPolicyName"
	OPER_VCON = "operVcon"
	OPER_VCON_PROFILE_NAME = "operVconProfileName"
	OPER_VERSION = "operVersion"
	OPER_VM_NETWORK_DEF_NAME = "operVmNetworkDefName"
	OPER_VNET_DN = "operVnetDn"
	OPER_VNET_NAME = "operVnetName"
	OPERABILITY = "operability"
	OPERABILITY_QUALIFIER = "operabilityQualifier"
	OPERABILITY_QUALIFIER_REASON = "operabilityQualifierReason"
	OPERATING_VOLTAGES = "operatingVoltages"
	OPERATION = "operation"
	OPERATION_TIMEOUT = "operationTimeout"
	ORDER = "order"
	ORG_DN = "orgDn"
	ORG_NAME = "orgName"
	ORG_PATH = "orgPath"
	ORG_UNIT_NAME = "orgUnitName"
	ORIENTATION = "orientation"
	ORIG_SEVERITY = "origSeverity"
	ORIGINAL_MAC = "originalMac"
	ORIGINAL_NODE_WWN = "originalNodeWwn"
	ORIGINAL_UUID = "originalUuid"
	ORIGINAL_WWN = "originalWwn"
	OUT = "out"
	OUT_DISCARD = "outDiscard"
	OUT_DISCARD_DELTA = "outDiscardDelta"
	OUT_DISCARD_DELTA_AVG = "outDiscardDeltaAvg"
	OUT_DISCARD_DELTA_MAX = "outDiscardDeltaMax"
	OUT_DISCARD_DELTA_MIN = "outDiscardDeltaMin"
	OUTLET1 = "outlet1"
	OUTLET1_AVG = "outlet1Avg"
	OUTLET1_MAX = "outlet1Max"
	OUTLET1_MIN = "outlet1Min"
	OUTLET2 = "outlet2"
	OUTLET2_AVG = "outlet2Avg"
	OUTLET2_MAX = "outlet2Max"
	OUTLET2_MIN = "outlet2Min"
	OUTPUT12V = "output12v"
	OUTPUT12V_AVG = "output12vAvg"
	OUTPUT12V_MAX = "output12vMax"
	OUTPUT12V_MIN = "output12vMin"
	OUTPUT3V3 = "output3v3"
	OUTPUT3V3_AVG = "output3v3Avg"
	OUTPUT3V3_MAX = "output3v3Max"
	OUTPUT3V3_MIN = "output3v3Min"
	OUTPUT_CURRENT = "outputCurrent"
	OUTPUT_CURRENT_AVG = "outputCurrentAvg"
	OUTPUT_CURRENT_MAX = "outputCurrentMax"
	OUTPUT_CURRENT_MIN = "outputCurrentMin"
	OUTPUT_MEGABYTES = "outputMegabytes"
	OUTPUT_MEGABYTES_DELTA = "outputMegabytesDelta"
	OUTPUT_MEGABYTES_DELTA_AVG = "outputMegabytesDeltaAvg"
	OUTPUT_MEGABYTES_DELTA_MAX = "outputMegabytesDeltaMax"
	OUTPUT_MEGABYTES_DELTA_MIN = "outputMegabytesDeltaMin"
	OUTPUT_POWER = "outputPower"
	OUTPUT_POWER_AVG = "outputPowerAvg"
	OUTPUT_POWER_MAX = "outputPowerMax"
	OUTPUT_POWER_MIN = "outputPowerMin"
	OUTPUT_POWER_STATE = "outputPowerState"
	OUTPUT_REQUESTS = "outputRequests"
	OUTPUT_REQUESTS_DELTA = "outputRequestsDelta"
	OUTPUT_REQUESTS_DELTA_AVG = "outputRequestsDeltaAvg"
	OUTPUT_REQUESTS_DELTA_MAX = "outputRequestsDeltaMax"
	OUTPUT_REQUESTS_DELTA_MIN = "outputRequestsDeltaMin"
	OUTPUT_STATUS = "outputStatus"
	OUTPUT_VOLTAGE = "outputVoltage"
	OUTPUT_VOLTAGE_AVG = "outputVoltageAvg"
	OUTPUT_VOLTAGE_MAX = "outputVoltageMax"
	OUTPUT_VOLTAGE_MIN = "outputVoltageMin"
	OVERLAPPING_VLANS = "overlappingVlans"
	OVERSIZED_BAD_CRC_PACKETS = "oversizedBadCrcPackets"
	OVERSIZED_BAD_CRC_PACKETS_DELTA = "oversizedBadCrcPacketsDelta"
	OVERSIZED_BAD_CRC_PACKETS_DELTA_AVG = "oversizedBadCrcPacketsDeltaAvg"
	OVERSIZED_BAD_CRC_PACKETS_DELTA_MAX = "oversizedBadCrcPacketsDeltaMax"
	OVERSIZED_BAD_CRC_PACKETS_DELTA_MIN = "oversizedBadCrcPacketsDeltaMin"
	OVERSIZED_GOOD_CRC_PACKETS = "oversizedGoodCrcPackets"
	OVERSIZED_GOOD_CRC_PACKETS_DELTA = "oversizedGoodCrcPacketsDelta"
	OVERSIZED_GOOD_CRC_PACKETS_DELTA_AVG = "oversizedGoodCrcPacketsDeltaAvg"
	OVERSIZED_GOOD_CRC_PACKETS_DELTA_MAX = "oversizedGoodCrcPacketsDeltaMax"
	OVERSIZED_GOOD_CRC_PACKETS_DELTA_MIN = "oversizedGoodCrcPacketsDeltaMin"
	OVERSIZED_PACKETS = "oversizedPackets"
	OVERSIZED_PACKETS_DELTA = "oversizedPacketsDelta"
	OVERSIZED_PACKETS_DELTA_AVG = "oversizedPacketsDeltaAvg"
	OVERSIZED_PACKETS_DELTA_MAX = "oversizedPacketsDeltaMax"
	OVERSIZED_PACKETS_DELTA_MIN = "oversizedPacketsDeltaMin"
	OWN = "own"
	OWNER = "owner"
	OWNER_POLICY = "ownerPolicy"
	OWNERSHIP = "ownership"
	PACKAGE_VERSION = "packageVersion"
	PACKETS_RX = "packetsRx"
	PACKETS_RX_DELTA = "packetsRxDelta"
	PACKETS_RX_DELTA_AVG = "packetsRxDeltaAvg"
	PACKETS_RX_DELTA_MAX = "packetsRxDeltaMax"
	PACKETS_RX_DELTA_MIN = "packetsRxDeltaMin"
	PACKETS_TX = "packetsTx"
	PACKETS_TX_DELTA = "packetsTxDelta"
	PACKETS_TX_DELTA_AVG = "packetsTxDeltaAvg"
	PACKETS_TX_DELTA_MAX = "packetsTxDeltaMax"
	PACKETS_TX_DELTA_MIN = "packetsTxDeltaMin"
	PAK = "pak"
	PARENT_ADAPTOR_SLOT_NUM = "parentAdaptorSlotNum"
	PARENT_CONTEXT = "parentContext"
	PART_NUMBER = "partNumber"
	PASS_THRU = "passThru"
	PASSWORD = "password"
	PASSWORD_STATE = "passwordState"
	PATH = "path"
	PAUSE_PACKETS = "pausePackets"
	PAUSE_PACKETS_DELTA = "pausePacketsDelta"
	PAUSE_PACKETS_DELTA_AVG = "pausePacketsDeltaAvg"
	PAUSE_PACKETS_DELTA_MAX = "pausePacketsDeltaMax"
	PAUSE_PACKETS_DELTA_MIN = "pausePacketsDeltaMin"
	PC_GLOBAL_ID = "pcGlobalId"
	PC_ID = "pcId"
	PC_LOCAL_ID = "pcLocalId"
	PCI_ADDR = "pciAddr"
	PCI_ENUM = "pciEnum"
	PCI_FUNC = "pciFunc"
	PCI_SLOT = "pciSlot"
	PEER_CHASSIS_ID = "peerChassisId"
	PEER_COMM_STATUS = "peerCommStatus"
	PEER_DN = "peerDn"
	PEER_ENCAP = "peerEncap"
	PEER_ID = "peerId"
	PEER_MAC = "peerMac"
	PEER_PORT_ID = "peerPortId"
	PEER_REQ_CONFLICT = "peerReqConflict"
	PEER_SLOT_ID = "peerSlotId"
	PEER_STATE = "peerState"
	PEER_STATUS = "peerStatus"
	PER_DISK_CAP = "perDiskCap"
	PER_PRIORITY_PAUSE_PACKETS = "perPriorityPausePackets"
	PER_PRIORITY_PAUSE_PACKETS_DELTA = "perPriorityPausePacketsDelta"
	PER_PRIORITY_PAUSE_PACKETS_DELTA_AVG = "perPriorityPausePacketsDeltaAvg"
	PER_PRIORITY_PAUSE_PACKETS_DELTA_MAX = "perPriorityPausePacketsDeltaMax"
	PER_PRIORITY_PAUSE_PACKETS_DELTA_MIN = "perPriorityPausePacketsDeltaMin"
	PERF = "perf"
	PERM_ACCESS = "permAccess"
	PERS_BIND = "persBind"
	PERS_BIND_CLEAR = "persBindClear"
	PERSIST = "persist"
	PERSIST_TIME = "persistTime"
	PF_DN = "pfDn"
	PG_NAME = "pgName"
	PH_SWITCH_ID = "phSwitchId"
	PHONE = "phone"
	PHS_ACCESS_CARD_ID = "phsAccessCardId"
	PHS_ACCESS_PORT_ID = "phsAccessPortId"
	PHS_BORDER_CARD_ID = "phsBorderCardId"
	PHS_BORDER_PORT_ID = "phsBorderPortId"
	PHY_ID = "phyId"
	PHYS_EP_DN = "physEpDn"
	PHYSICAL_DRIVE_COUNT = "physicalDriveCount"
	PID = "pid"
	PIF_ID = "pifId"
	PIN_GROUP_NAME = "pinGroupName"
	PIN_TO_GROUP_NAME = "pinToGroupName"
	PKTS_EG = "pkts_eg"
	PKTS_IN = "pkts_in"
	PLACEMENT = "placement"
	PLATFORM = "platform"
	PN_DN = "pnDn"
	PN_POOL_DN = "pnPoolDn"
	POISONED_TLPERRORS = "poisonedTLPErrors"
	POISONED_TLPERRORS15_MIN = "poisonedTLPErrors15Min"
	POISONED_TLPERRORS15_MIN_H = "poisonedTLPErrors15MinH"
	POISONED_TLPERRORS1_DAY = "poisonedTLPErrors1Day"
	POISONED_TLPERRORS1_DAY_H = "poisonedTLPErrors1DayH"
	POISONED_TLPERRORS1_HOUR = "poisonedTLPErrors1Hour"
	POISONED_TLPERRORS1_HOUR_H = "poisonedTLPErrors1HourH"
	POISONED_TLPERRORS1_WEEK = "poisonedTLPErrors1Week"
	POISONED_TLPERRORS1_WEEK_H = "poisonedTLPErrors1WeekH"
	POISONED_TLPERRORS2_WEEKS = "poisonedTLPErrors2Weeks"
	POISONED_TLPERRORS2_WEEKS_H = "poisonedTLPErrors2WeeksH"
	POL_DN = "polDn"
	POL_NAME = "polName"
	POLICY_DN = "policyDn"
	POLICY_LEVEL = "policyLevel"
	POLICY_NAME = "policyName"
	POLICY_OWNER = "policyOwner"
	POLICY_TYPE = "policyType"
	POLL_INTERVAL = "pollInterval"
	POLL_INTERVAL_SECONDS = "pollIntervalSeconds"
	POOL_DN = "poolDn"
	POOL_NAME = "poolName"
	POOL_ORG_DN = "poolOrgDn"
	POOLABLE_DN = "poolableDn"
	POOLED_ID = "pooledId"
	POP_ERRORS = "popErrors"
	POP_ERRORS_DELTA = "popErrorsDelta"
	POP_ERRORS_DELTA_AVG = "popErrorsDeltaAvg"
	POP_ERRORS_DELTA_MAX = "popErrorsDeltaMax"
	POP_ERRORS_DELTA_MIN = "popErrorsDeltaMin"
	POPULATED = "populated"
	PORT = "port"
	PORT_BANDWIDTH = "portBandwidth"
	PORT_CAPACITY = "portCapacity"
	PORT_DOWN_IO_RETRY_COUNT = "portDownIoRetryCount"
	PORT_DOWN_TIMEOUT = "portDownTimeout"
	PORT_FAMILY = "portFamily"
	PORT_ID = "portId"
	PORT_MAC = "portMac"
	PORT_MODE = "portMode"
	PORT_MODE_BEACON = "portModeBeacon"
	PORT_NUMBER = "portNumber"
	PORT_PROFILE_UUID = "portProfileUuid"
	PORT_VALUE = "portValue"
	PORT_VSAN_ID = "portVsanId"
	POST_ACTION = "postAction"
	POWER = "power"
	POWER_AVG = "powerAvg"
	POWER_MAX = "powerMax"
	POWER_MIN = "powerMin"
	POWER_POLICY_NAME = "powerPolicyName"
	POWER_STATE = "powerState"
	POWER_STATE_QUALIFIER = "powerStateQualifier"
	POWER_USAGE = "powerUsage"
	PPP_PACKETS = "pppPackets"
	PPP_PACKETS_DELTA = "pppPacketsDelta"
	PPP_PACKETS_DELTA_AVG = "pppPacketsDeltaAvg"
	PPP_PACKETS_DELTA_MAX = "pppPacketsDeltaMax"
	PPP_PACKETS_DELTA_MIN = "pppPacketsDeltaMin"
	PREBOOT = "preboot"
	PREF = "pref"
	PREFIX = "prefix"
	PRESENCE = "presence"
	PRESERVE_POOLED_VALUES = "preservePooledValues"
	PREV_ASSIGNED_TO_DN = "prevAssignedToDn"
	PREV_CMD = "prevCmd"
	PREV_EVT = "prevEvt"
	PREV_OPER_STATE = "prevOperState"
	PREV_SEVERITY = "prevSeverity"
	PREV_VERSION = "prevVersion"
	PRIM_DNS = "primDns"
	PRIMARY_SLOT_NUMBER = "primarySlotNumber"
	PRIMARY_VLAN_COUNT = "primaryVlanCount"
	PRIMARY_VLAN_COUNT_STATUS = "primaryVlanCountStatus"
	PRIMARY_VLAN_ID = "primaryVlanId"
	PRIO = "prio"
	PRIO_SHARE = "prioShare"
	PRIORITY = "priority"
	PRIORITY_FLOW_CTRL = "priorityFlowCtrl"
	PRIV = "priv"
	PRIV_PWD_SET = "privPwdSet"
	PRIVPWD = "privpwd"
	PROBLEMS = "problems"
	PROC_BREAK = "procBreak"
	PROC_CAP = "procCap"
	PRODUCT_ASSET_TAG = "productAssetTag"
	PRODUCT_MANUFACTURER = "productManufacturer"
	PRODUCT_NAME = "productName"
	PRODUCT_PART_NO = "productPartNo"
	PRODUCT_SERIAL_NO = "productSerialNo"
	PRODUCT_VERSION_NO = "productVersionNo"
	PROF_DN = "profDn"
	PROFILE_DN = "profileDn"
	PROFILE_ID = "profileId"
	PROFILE_NAME = "profileName"
	PROFILE_TYPE = "profileType"
	PROGRESS = "progress"
	PROM_CARD_TYPE = "promCardType"
	PROP_ID = "propId"
	PROP_TYPE = "propType"
	PROPERTY_NAME = "propertyName"
	PROT = "prot"
	PROT_PEER_ID = "protPeerId"
	PROT_ROLE = "protRole"
	PROT_STATE = "protState"
	PROTECT_CONFIG = "protectConfig"
	PROTECTION = "protection"
	PROTO = "proto"
	PROTOCOL = "protocol"
	PROV_INT_ID = "provIntId"
	PROV_SRV_POLICY_NAME = "provSrvPolicyName"
	PROVIDER = "provider"
	PROVIDER_GROUP = "providerGroup"
	PROVIDER_LOAD_FAILURES = "providerLoadFailures"
	PROVIDERS_LOADED = "providersLoaded"
	PSU_CAPACITY = "psuCapacity"
	PSU_CTRLR_INLET1 = "psuCtrlrInlet1"
	PSU_CTRLR_INLET1_AVG = "psuCtrlrInlet1Avg"
	PSU_CTRLR_INLET1_MAX = "psuCtrlrInlet1Max"
	PSU_CTRLR_INLET1_MIN = "psuCtrlrInlet1Min"
	PSU_CTRLR_INLET2 = "psuCtrlrInlet2"
	PSU_CTRLR_INLET2_AVG = "psuCtrlrInlet2Avg"
	PSU_CTRLR_INLET2_MAX = "psuCtrlrInlet2Max"
	PSU_CTRLR_INLET2_MIN = "psuCtrlrInlet2Min"
	PSU_FIRMWARE_VERSION = "psuFirmwareVersion"
	PSU_STATE = "psuState"
	PSU_TEMP1 = "psuTemp1"
	PSU_TEMP2 = "psuTemp2"
	PUB_NW_DN = "pubNwDn"
	PUB_NW_ID = "pubNwId"
	PUB_NW_NAME = "pubNwName"
	PURGE_WINDOW = "purgeWindow"
	PURPOSE = "purpose"
	PUSH_ERRORS = "pushErrors"
	PUSH_ERRORS_DELTA = "pushErrorsDelta"
	PUSH_ERRORS_DELTA_AVG = "pushErrorsDeltaAvg"
	PUSH_ERRORS_DELTA_MAX = "pushErrorsDeltaMax"
	PUSH_ERRORS_DELTA_MIN = "pushErrorsDeltaMin"
	PWD = "pwd"
	PWD_CHANGE_COUNT = "pwdChangeCount"
	PWD_CHANGE_INTERVAL_BEGIN = "pwdChangeIntervalBegin"
	PWD_CHANGED_DATE = "pwdChangedDate"
	PWD_HISTORY = "pwdHistory"
	PWD_LIFE_TIME = "pwdLifeTime"
	PWD_SET = "pwdSet"
	PWD_STRENGTH_CHECK = "pwdStrengthCheck"
	QOS_CONTROL = "qosControl"
	QOS_POLICY_DN = "qosPolicyDn"
	QOS_POLICY_ID = "qosPolicyId"
	QOS_POLICY_NAME = "qosPolicyName"
	QUALIFIER = "qualifier"
	QUANT = "quant"
	QUERIER_IP_ADDR = "querierIpAddr"
	QUERIER_IP_ADDRS = "querierIpAddrs"
	QUERIER_STATE = "querierState"
	RACK_BUNDLE_NAME = "rackBundleName"
	RACK_BUNDLE_VERSION = "rackBundleVersion"
	RACK_SERVER_ADAPTER_ID = "rackServerAdapterId"
	RACK_SERVER_ID = "rackServerId"
	RAID_HEALTH = "raidHealth"
	RAID_STATE = "raidState"
	RAID_SUPPORT = "raidSupport"
	RAID_SYNC_SUPPORT = "raidSyncSupport"
	RATE = "rate"
	RCV = "rcv"
	RCV_DELTA = "rcvDelta"
	RCV_DELTA_AVG = "rcvDeltaAvg"
	RCV_DELTA_MAX = "rcvDeltaMax"
	RCV_DELTA_MIN = "rcvDeltaMin"
	RDEV = "rdev"
	REACHABILITY = "reachability"
	READ_ERROR_THRESHOLD = "readErrorThreshold"
	READ_IOERROR_COUNT = "readIOErrorCount"
	READ_POLICY = "readPolicy"
	REALLOC = "realloc"
	REALM = "realm"
	REAR_TEMP = "rearTemp"
	REAR_TEMP_AVG = "rearTempAvg"
	REAR_TEMP_MAX = "rearTempMax"
	REAR_TEMP_MIN = "rearTempMin"
	REBALANCE = "rebalance"
	REBOOT_ACTION_ON_DESTRUCTIVE = "rebootActionOnDestructive"
	REBOOT_ON_UPDATE = "rebootOnUpdate"
	REBOOT_POLICY = "rebootPolicy"
	REBOOT_REQUIRED = "rebootRequired"
	REBUILD_RATE = "rebuildRate"
	RECEIVE_SIDE_SCALING = "receiveSideScaling"
	RECORD_TYPE = "recordType"
	RECOVERABLE = "recoverable"
	RECOVERY_ACTION = "recoveryAction"
	RECURSIVE = "recursive"
	RECV_FLOW_CTRL = "recvFlowCtrl"
	RECV_PAUSE = "recvPause"
	RECV_PAUSE_DELTA = "recvPauseDelta"
	RECV_PAUSE_DELTA_AVG = "recvPauseDeltaAvg"
	RECV_PAUSE_DELTA_MAX = "recvPauseDeltaMax"
	RECV_PAUSE_DELTA_MIN = "recvPauseDeltaMin"
	REDIRECT_STATE = "redirectState"
	REDUNDANCY = "redundancy"
	REF_CONVERTED_DN = "refConvertedDn"
	REF_DN = "refDn"
	REF_NAME = "refName"
	REF_OBJ_STATUS = "refObjStatus"
	REF_OPER_STATE = "refOperState"
	REF_POLICY_DN = "refPolicyDn"
	REFRESH_PERIOD = "refreshPeriod"
	REGEN = "regen"
	REGISTRATION_STATE = "registrationState"
	RELATIONSHIP = "relationship"
	REMOTE = "remote"
	REMOTE_DIR = "remoteDir"
	REMOTE_EP_REF = "remoteEpRef"
	REMOTE_FILE = "remoteFile"
	REMOTE_HOST = "remoteHost"
	REMOTE_PATH = "remotePath"
	REMOVABLE = "removable"
	REMOVAL_CONDITIONS = "removalConditions"
	REPAIR_STATE = "repairState"
	REPLICATE_IF_NO_CHILD = "replicateIfNoChild"
	REPLY_TO = "replyTo"
	REPORTING_INTERVAL = "reportingInterval"
	REQ = "req"
	REQ_DN = "reqDn"
	REQ_ID = "reqId"
	REQUEST_SIZE = "requestSize"
	REQUESTOR_OWNERSHIP = "requestorOwnership"
	RES_PROB = "resProb"
	RESERVED_POWER = "reservedPower"
	RESERVED_POWER_AVG = "reservedPowerAvg"
	RESERVED_POWER_MAX = "reservedPowerMax"
	RESERVED_POWER_MIN = "reservedPowerMin"
	RESET = "reset"
	RESET_ON = "resetOn"
	RESET_ON_ACTIVATE = "resetOnActivate"
	RESETS = "resets"
	RESETS_DELTA = "resetsDelta"
	RESETS_DELTA_AVG = "resetsDeltaAvg"
	RESETS_DELTA_MAX = "resetsDeltaMax"
	RESETS_DELTA_MIN = "resetsDeltaMin"
	RESOLVE_REMOTE = "resolveRemote"
	RESOLVE_TYPE = "resolveType"
	RESOLVED_CLASS_TYPE = "resolvedClassType"
	RESOURCE_ALLOCATION_TIMEOUT = "resourceAllocationTimeout"
	RESTRICT_MIGRATION = "restrictMigration"
	RESULT = "result"
	RET_STATUS = "retStatus"
	RETENTION_INTERVAL = "retentionInterval"
	RETRIED = "retried"
	RETRIES = "retries"
	RETRY = "retry"
	RETRY_COUNT = "retryCount"
	RETRY_DELAY_MINUTES = "retryDelayMinutes"
	RETRY_INTERVAL = "retryInterval"
	REVERT_TIMEOUT = "revertTimeout"
	REVISION = "revision"
	REVISION_MODIFIER = "revisionModifier"
	RIGHT_DATA = "rightData"
	RING_SIZE = "ringSize"
	RMT_DISK_CFG_NAME = "rmtDiskCfgName"
	RMT_ERR_CODE = "rmtErrCode"
	RMT_ERR_DESCR = "rmtErrDescr"
	RMT_RSLT = "rmtRslt"
	RN = "rn"
	ROLE = "role"
	ROOTDN = "rootdn"
	ROTATIONAL_SPEED = "rotationalSpeed"
	ROUTE_IP = "routeIP"
	RSLT_STATUS = "rsltStatus"
	RULE = "rule"
	RUN_POLICY_NAME = "runPolicyName"
	RX = "rx"
	RX_BAD_FRAMES = "rxBadFrames"
	RX_BAD_FRAMES_DELTA = "rxBadFramesDelta"
	RX_BAD_FRAMES_DELTA_AVG = "rxBadFramesDeltaAvg"
	RX_BAD_FRAMES_DELTA_MAX = "rxBadFramesDeltaMax"
	RX_BAD_FRAMES_DELTA_MIN = "rxBadFramesDeltaMin"
	RX_BYTES = "rxBytes"
	RX_BYTES_DELTA = "rxBytesDelta"
	RX_BYTES_DELTA_AVG = "rxBytesDeltaAvg"
	RX_BYTES_DELTA_MAX = "rxBytesDeltaMax"
	RX_BYTES_DELTA_MIN = "rxBytesDeltaMin"
	RX_DELTA = "rxDelta"
	RX_DELTA_AVG = "rxDeltaAvg"
	RX_DELTA_MAX = "rxDeltaMax"
	RX_DELTA_MIN = "rxDeltaMin"
	RX_DROPPED = "rxDropped"
	RX_DROPPED_DELTA = "rxDroppedDelta"
	RX_DROPPED_DELTA_AVG = "rxDroppedDeltaAvg"
	RX_DROPPED_DELTA_MAX = "rxDroppedDeltaMax"
	RX_DROPPED_DELTA_MIN = "rxDroppedDeltaMin"
	RX_ERRORS = "rxErrors"
	RX_ERRORS_DELTA = "rxErrorsDelta"
	RX_ERRORS_DELTA_AVG = "rxErrorsDeltaAvg"
	RX_ERRORS_DELTA_MAX = "rxErrorsDeltaMax"
	RX_ERRORS_DELTA_MIN = "rxErrorsDeltaMin"
	RX_FRAMES = "rxFrames"
	RX_FRAMES_DELTA = "rxFramesDelta"
	RX_FRAMES_DELTA_AVG = "rxFramesDeltaAvg"
	RX_FRAMES_DELTA_MAX = "rxFramesDeltaMax"
	RX_FRAMES_DELTA_MIN = "rxFramesDeltaMin"
	RX_PACKETS = "rxPackets"
	RX_PACKETS_DELTA = "rxPacketsDelta"
	RX_PACKETS_DELTA_AVG = "rxPacketsDeltaAvg"
	RX_PACKETS_DELTA_MAX = "rxPacketsDeltaMax"
	RX_PACKETS_DELTA_MIN = "rxPacketsDeltaMin"
	RX_PAUSE_CFC = "rxPauseCFC"
	RX_PAUSE_CFCDELTA = "rxPauseCFCDelta"
	RX_PAUSE_CFCDELTA_AVG = "rxPauseCFCDeltaAvg"
	RX_PAUSE_CFCDELTA_MAX = "rxPauseCFCDeltaMax"
	RX_PAUSE_CFCDELTA_MIN = "rxPauseCFCDeltaMin"
	RX_PAUSE_PFC = "rxPausePFC"
	RX_PAUSE_PFCDELTA = "rxPausePFCDelta"
	RX_PAUSE_PFCDELTA_AVG = "rxPausePFCDeltaAvg"
	RX_PAUSE_PFCDELTA_MAX = "rxPausePFCDeltaMax"
	RX_PAUSE_PFCDELTA_MIN = "rxPausePFCDeltaMin"
	SAN_CONN_POLICY_NAME = "sanConnPolicyName"
	SCALED_WT = "scaledWt"
	SCAN_ORDER = "scanOrder"
	SCHED_NAME = "schedName"
	SCHEDULE = "schedule"
	SCHEDULER = "scheduler"
	SCOPE = "scope"
	SCRUB_POLICY_NAME = "scrubPolicyName"
	SEC_DNS = "secDns"
	SECONDS_SINCE_LAST_RESET = "secondsSinceLastReset"
	SECONDS_SINCE_LAST_RESET_DELTA = "secondsSinceLastResetDelta"
	SECONDS_SINCE_LAST_RESET_DELTA_AVG = "secondsSinceLastResetDeltaAvg"
	SECONDS_SINCE_LAST_RESET_DELTA_MAX = "secondsSinceLastResetDeltaMax"
	SECONDS_SINCE_LAST_RESET_DELTA_MIN = "secondsSinceLastResetDeltaMin"
	SECRET = "secret"
	SECURE_BIOS = "secureBios"
	SECURE_BOOT = "secureBoot"
	SEEK_AVERAGE_READ_WRITE = "seekAverageReadWrite"
	SEEK_TRACK_TO_TRACK_READ_WRITE = "seekTrackToTrackReadWrite"
	SEEPROM_OPER_STATE = "seepromOperState"
	SELECT = "select"
	SELECTOR = "selector"
	SELF_REQ_CONFLICT = "selfReqConflict"
	SEND_FLOW_CTRL = "sendFlowCtrl"
	SEND_NOW = "sendNow"
	SENSITIVITY = "sensitivity"
	SENSOR_ID = "sensorId"
	SENSOR_NAME = "sensorName"
	SENSOR_TYPE = "sensorType"
	SEQ_ID = "seqId"
	SEQ_NUM = "seqNum"
	SEQ_PROTOCOL_ERR_COUNT = "seqProtocolErrCount"
	SEQ_PROTOCOL_ERR_COUNT_DELTA = "seqProtocolErrCountDelta"
	SEQ_PROTOCOL_ERR_COUNT_DELTA_AVG = "seqProtocolErrCountDeltaAvg"
	SEQ_PROTOCOL_ERR_COUNT_DELTA_MAX = "seqProtocolErrCountDeltaMax"
	SEQ_PROTOCOL_ERR_COUNT_DELTA_MIN = "seqProtocolErrCountDeltaMin"
	SERENO_NETFLOW_SUPPORTED = "serenoNetflowSupported"
	SERIAL = "serial"
	SERIES = "series"
	SERVER = "server"
	SERVER_CONFIG_ISSUES = "serverConfigIssues"
	SERVER_DN = "serverDn"
	SERVER_ID = "serverId"
	SERVICE = "service"
	SERVICE_PHILOSOPHY = "servicePhilosophy"
	SERVICE_PROFILE_DN = "serviceProfileDn"
	SESSION = "session"
	SESSION_ID = "sessionId"
	SESSION_TIMEOUT = "sessionTimeout"
	SESSIONS_PER_USER = "sessionsPerUser"
	SET = "set"
	SEVERITY = "severity"
	SHARE = "share"
	SHARING = "sharing"
	SIDE = "side"
	SIG = "sig"
	SIGNAL_LOSSES = "signalLosses"
	SIGNAL_LOSSES_DELTA = "signalLossesDelta"
	SIGNAL_LOSSES_DELTA_AVG = "signalLossesDeltaAvg"
	SIGNAL_LOSSES_DELTA_MAX = "signalLossesDeltaMax"
	SIGNAL_LOSSES_DELTA_MIN = "signalLossesDeltaMin"
	SINGLE_COLLISION = "singleCollision"
	SINGLE_COLLISION_DELTA = "singleCollisionDelta"
	SINGLE_COLLISION_DELTA_AVG = "singleCollisionDeltaAvg"
	SINGLE_COLLISION_DELTA_MAX = "singleCollisionDeltaMax"
	SINGLE_COLLISION_DELTA_MIN = "singleCollisionDeltaMin"
	SINGLETON = "singleton"
	SITE = "site"
	SIZE = "size"
	SIZE_LIMIT = "sizeLimit"
	SKIP_VALIDATION = "skipValidation"
	SKU = "sku"
	SLEEP_DELAY = "sleepDelay"
	SLOT_ID = "slotId"
	SLOT_NUMBER = "slotNumber"
	SLOT_SPAN_ORIENTATION = "slotSpanOrientation"
	SLOTS_PER_LINE = "slotsPerLine"
	SMBIOS_ID = "smbiosId"
	SMBIOSNAME = "smbiosname"
	SMI_LINK_CORR_ERRORS = "smiLinkCorrErrors"
	SMI_LINK_CORR_ERRORS15_MIN = "smiLinkCorrErrors15Min"
	SMI_LINK_CORR_ERRORS15_MIN_H = "smiLinkCorrErrors15MinH"
	SMI_LINK_CORR_ERRORS1_DAY = "smiLinkCorrErrors1Day"
	SMI_LINK_CORR_ERRORS1_DAY_H = "smiLinkCorrErrors1DayH"
	SMI_LINK_CORR_ERRORS1_HOUR = "smiLinkCorrErrors1Hour"
	SMI_LINK_CORR_ERRORS1_HOUR_H = "smiLinkCorrErrors1HourH"
	SMI_LINK_CORR_ERRORS1_WEEK = "smiLinkCorrErrors1Week"
	SMI_LINK_CORR_ERRORS1_WEEK_H = "smiLinkCorrErrors1WeekH"
	SMI_LINK_CORR_ERRORS2_WEEKS = "smiLinkCorrErrors2Weeks"
	SMI_LINK_CORR_ERRORS2_WEEKS_H = "smiLinkCorrErrors2WeeksH"
	SMI_LINK_UNCORR_ERRORS = "smiLinkUncorrErrors"
	SMI_LINK_UNCORR_ERRORS15_MIN = "smiLinkUncorrErrors15Min"
	SMI_LINK_UNCORR_ERRORS15_MIN_H = "smiLinkUncorrErrors15MinH"
	SMI_LINK_UNCORR_ERRORS1_DAY = "smiLinkUncorrErrors1Day"
	SMI_LINK_UNCORR_ERRORS1_DAY_H = "smiLinkUncorrErrors1DayH"
	SMI_LINK_UNCORR_ERRORS1_HOUR = "smiLinkUncorrErrors1Hour"
	SMI_LINK_UNCORR_ERRORS1_HOUR_H = "smiLinkUncorrErrors1HourH"
	SMI_LINK_UNCORR_ERRORS1_WEEK = "smiLinkUncorrErrors1Week"
	SMI_LINK_UNCORR_ERRORS1_WEEK_H = "smiLinkUncorrErrors1WeekH"
	SMI_LINK_UNCORR_ERRORS2_WEEKS = "smiLinkUncorrErrors2Weeks"
	SMI_LINK_UNCORR_ERRORS2_WEEKS_H = "smiLinkUncorrErrors2WeeksH"
	SND = "snd"
	SNOOPING_ENABLED = "snoopingEnabled"
	SNOOPING_STATE = "snoopingState"
	SOAK_INTERVAL = "soakInterval"
	SOAKING_SEVERITY = "soakingSeverity"
	SOCKET_DESIGNATION = "socketDesignation"
	SOL_POLICY_NAME = "solPolicyName"
	SORT_CLASS = "sortClass"
	SORT_PROP = "sortProp"
	SOURCE = "source"
	SOURCE_ADDR = "sourceAddr"
	SOURCE_CONNECTOR_ID = "sourceConnectorId"
	SOURCE_DN = "sourceDn"
	SOURCE_TYPE = "sourceType"
	SOURCE_VLAN = "sourceVlan"
	SOURCE_VLAN_DN = "sourceVlanDn"
	SPARING_ERRORS = "sparingErrors"
	SPARING_ERRORS15_MIN = "sparingErrors15Min"
	SPARING_ERRORS15_MIN_H = "sparingErrors15MinH"
	SPARING_ERRORS1_DAY = "sparingErrors1Day"
	SPARING_ERRORS1_DAY_H = "sparingErrors1DayH"
	SPARING_ERRORS1_HOUR = "sparingErrors1Hour"
	SPARING_ERRORS1_HOUR_H = "sparingErrors1HourH"
	SPARING_ERRORS1_WEEK = "sparingErrors1Week"
	SPARING_ERRORS1_WEEK_H = "sparingErrors1WeekH"
	SPARING_ERRORS2_WEEKS = "sparingErrors2Weeks"
	SPARING_ERRORS2_WEEKS_H = "sparingErrors2WeeksH"
	SPEED = "speed"
	SPEED_AVG = "speedAvg"
	SPEED_MAX = "speedMax"
	SPEED_MIN = "speedMin"
	SPURIOUS_RETRIES = "spuriousRetries"
	SRC_FILT_DN = "srcFiltDn"
	SRC_TEMPL_NAME = "srcTemplName"
	SSH_AUTH_KEYS_CSUM = "sshAuthKeysCsum"
	SSH_AUTH_KEYS_SIZE = "sshAuthKeysSize"
	SSH_KEY_STATUS = "sshKeyStatus"
	SSH_ROOT_PUB_KEY_CSUM = "sshRootPubKeyCsum"
	SSH_ROOT_PUB_KEY_SIZE = "sshRootPubKeySize"
	STAGE_SIZE = "stageSize"
	STAGE_STATUS = "stageStatus"
	START_EVENT = "startEvent"
	START_TIME = "startTime"
	START_TS = "startTs"
	START_TS_M = "startTsM"
	STARTS = "starts"
	STARTS_WITH = "startsWith"
	STATE = "state"
	STATE_QUAL = "stateQual"
	STATS_CLASS_ID = "statsClassId"
	STATS_POLICY_NAME = "statsPolicyName"
	STATS_PROP_ID = "statsPropId"
	STATS_UPDATE_ID = "statsUpdateId"
	STATUS = "status"
	STATUS_CHANGE_TS = "statusChangeTs"
	STATUS_DESCR = "statusDescr"
	STDBY_VIF_ID = "stdbyVifId"
	STEPPING = "stepping"
	STORAGE_CONFIG_ISSUES = "storageConfigIssues"
	STORAGE_CONN_POLICY_NAME = "storageConnPolicyName"
	STORAGE_METHOD = "storageMethod"
	STORAGE_OOB_INTERFACE_SUPPORTED = "storageOobInterfaceSupported"
	STORAGE_SUBSYSTEM_STATE = "storageSubsystemState"
	STR_TYPE = "strType"
	STRIP_SIZE = "stripSize"
	STYLE = "style"
	SUB_DEVICE_ID = "subDeviceId"
	SUB_VENDOR_ID = "subVendorId"
	SUBDEVICE = "subdevice"
	SUBJ_NAME = "subjName"
	SUBJECT = "subject"
	SUBNET = "subnet"
	SUBVENDOR = "subvendor"
	SUCCESS_ACTION = "successAction"
	SUCCESSFULL = "successfull"
	SUFFIX = "suffix"
	SUPPL_ID1 = "supplId1"
	SUPPL_ID2 = "supplId2"
	SUPPL_ID3 = "supplId3"
	SUPPL_ID4 = "supplId4"
	SUPPORT = "support"
	SUPPORTED_ALGORITHM = "supportedAlgorithm"
	SUPPORTS_DHCP = "supportsDHCP"
	SUPPRESS_POLICY_NAME = "suppressPolicyName"
	SURPRISE_LINK_DOWN_ERRORS = "surpriseLinkDownErrors"
	SURPRISE_LINK_DOWN_ERRORS15_MIN = "surpriseLinkDownErrors15Min"
	SURPRISE_LINK_DOWN_ERRORS15_MIN_H = "surpriseLinkDownErrors15MinH"
	SURPRISE_LINK_DOWN_ERRORS1_DAY = "surpriseLinkDownErrors1Day"
	SURPRISE_LINK_DOWN_ERRORS1_DAY_H = "surpriseLinkDownErrors1DayH"
	SURPRISE_LINK_DOWN_ERRORS1_HOUR = "surpriseLinkDownErrors1Hour"
	SURPRISE_LINK_DOWN_ERRORS1_HOUR_H = "surpriseLinkDownErrors1HourH"
	SURPRISE_LINK_DOWN_ERRORS1_WEEK = "surpriseLinkDownErrors1Week"
	SURPRISE_LINK_DOWN_ERRORS1_WEEK_H = "surpriseLinkDownErrors1WeekH"
	SURPRISE_LINK_DOWN_ERRORS2_WEEKS = "surpriseLinkDownErrors2Weeks"
	SURPRISE_LINK_DOWN_ERRORS2_WEEKS_H = "surpriseLinkDownErrors2WeeksH"
	SUSPECT = "suspect"
	SUSPEND_STATE = "suspendState"
	SVC_REG_IP = "svcRegIP"
	SVC_REG_NAME = "svcRegName"
	SW_ABORDER_PORT = "swABorderPort"
	SW_ABORDER_SLOT = "swABorderSlot"
	SW_BBORDER_PORT = "swBBorderPort"
	SW_BBORDER_SLOT = "swBBorderSlot"
	SW_BACKUP_VERSION = "swBackupVersion"
	SW_COMPLEX_CAPACITY = "swComplexCapacity"
	SW_COMPLEX_ID = "swComplexId"
	SW_INT_ID = "swIntId"
	SW_NAME = "swName"
	SW_STARTUP_VERSION = "swStartupVersion"
	SW_UUID = "swUuid"
	SW_VERSION = "swVersion"
	SWITCH_ID = "switchId"
	SWITCH_PORT_MUX_OFFSET = "switchPortMuxOffset"
	SYMBOL = "symbol"
	SYMBOL_DELTA = "symbolDelta"
	SYMBOL_DELTA_AVG = "symbolDeltaAvg"
	SYMBOL_DELTA_MAX = "symbolDeltaMax"
	SYMBOL_DELTA_MIN = "symbolDeltaMin"
	SYNC_LOSSES = "syncLosses"
	SYNC_LOSSES_DELTA = "syncLossesDelta"
	SYNC_LOSSES_DELTA_AVG = "syncLossesDeltaAvg"
	SYNC_LOSSES_DELTA_MAX = "syncLossesDeltaMax"
	SYNC_LOSSES_DELTA_MIN = "syncLossesDeltaMin"
	SYNC_STATE = "syncState"
	SYNC_TRIGGER = "syncTrigger"
	SYS_CONTACT = "sysContact"
	SYS_ID = "sysId"
	SYS_LOCATION = "sysLocation"
	SYS_NAME = "sysName"
	SYS_STARTUP_VERSION = "sysStartupVersion"
	SYS_VERSION = "sysVersion"
	SYSID = "sysid"
	SYSTEM_UP_TIME = "systemUpTime"
	TAG = "tag"
	TAGS = "tags"
	TARGET = "target"
	TARGET_ATTR = "targetAttr"
	TARGET_DN = "targetDn"
	TARGET_IP1 = "targetIp1"
	TARGET_IP2 = "targetIp2"
	TARGET_IP3 = "targetIp3"
	TARGET_LUN = "targetLun"
	TARGET_STATUS = "targetStatus"
	TARGET_WWN = "targetWWN"
	TARGETWWPN = "targetwwpn"
	TCP_HASH = "tcpHash"
	TCP_RX_CHECKSUM = "tcpRxChecksum"
	TCP_SEGMENT = "tcpSegment"
	TCP_TIME_STAMP = "tcpTimeStamp"
	TCP_TX_CHECKSUM = "tcpTxChecksum"
	TECHNOLOGY = "technology"
	TEMP = "temp"
	TEMP_AVG = "tempAvg"
	TEMP_MAX = "tempMax"
	TEMP_MIN = "tempMin"
	TEMPERATURE = "temperature"
	TEMPERATURE_AVG = "temperatureAvg"
	TEMPERATURE_MAX = "temperatureMax"
	TEMPERATURE_MIN = "temperatureMin"
	TEMPL_TYPE = "templType"
	TEMPLATE_DATA_TIMEOUT = "templateDataTimeout"
	TERM = "term"
	THERMAL = "thermal"
	THERMAL_STATE_QUALIFIER = "thermalStateQualifier"
	THREADS = "threads"
	THRESHOLD = "threshold"
	THRESHOLD_LC = "thresholdLc"
	THRESHOLD_LNC = "thresholdLnc"
	THRESHOLD_LNR = "thresholdLnr"
	THRESHOLD_UC = "thresholdUc"
	THRESHOLD_UNC = "thresholdUnc"
	THRESHOLD_UNR = "thresholdUnr"
	THRESHOLDED = "thresholded"
	TIME = "time"
	TIME_CAP = "timeCap"
	TIME_COLLECTED = "timeCollected"
	TIME_OF_DAY_HOUR = "timeOfDayHour"
	TIME_OF_DAY_MINUTE = "timeOfDayMinute"
	TIME_OF_LAST_ATTEMPT = "timeOfLastAttempt"
	TIME_OF_LAST_SUCCESS = "timeOfLastSuccess"
	TIME_STAMP = "timeStamp"
	TIMEOUT = "timeout"
	TIMEZONE = "timezone"
	TO = "to"
	TOKEN = "token"
	TOO_LONG_RX = "tooLongRx"
	TOO_LONG_RX_DELTA = "tooLongRxDelta"
	TOO_LONG_RX_DELTA_AVG = "tooLongRxDeltaAvg"
	TOO_LONG_RX_DELTA_MAX = "tooLongRxDeltaMax"
	TOO_LONG_RX_DELTA_MIN = "tooLongRxDeltaMin"
	TOO_SHORT_RX = "tooShortRx"
	TOO_SHORT_RX_DELTA = "tooShortRxDelta"
	TOO_SHORT_RX_DELTA_AVG = "tooShortRxDeltaAvg"
	TOO_SHORT_RX_DELTA_MAX = "tooShortRxDeltaMax"
	TOO_SHORT_RX_DELTA_MIN = "tooShortRxDeltaMin"
	TOTAL = "total"
	TOTAL_AVG = "totalAvg"
	TOTAL_BYTES = "totalBytes"
	TOTAL_BYTES_DELTA = "totalBytesDelta"
	TOTAL_BYTES_DELTA_AVG = "totalBytesDeltaAvg"
	TOTAL_BYTES_DELTA_MAX = "totalBytesDeltaMax"
	TOTAL_BYTES_DELTA_MIN = "totalBytesDeltaMin"
	TOTAL_FAULTS = "totalFaults"
	TOTAL_MAX = "totalMax"
	TOTAL_MEMORY = "totalMemory"
	TOTAL_MIN = "totalMin"
	TOTAL_PACKETS = "totalPackets"
	TOTAL_PACKETS_DELTA = "totalPacketsDelta"
	TOTAL_PACKETS_DELTA_AVG = "totalPacketsDeltaAvg"
	TOTAL_PACKETS_DELTA_MAX = "totalPacketsDeltaMax"
	TOTAL_PACKETS_DELTA_MIN = "totalPacketsDeltaMin"
	TOTAL_PASSES = "totalPasses"
	TOTAL_POWER = "totalPower"
	TOTAL_POWER_AVG = "totalPowerAvg"
	TOTAL_POWER_MAX = "totalPowerMax"
	TOTAL_POWER_MIN = "totalPowerMin"
	TOTAL_QUANT = "totalQuant"
	TOTAL_SESSIONS = "totalSessions"
	TP = "tp"
	TPM_REVISION = "tpmRevision"
	TR_DN = "trDn"
	TR_ID = "trId"
	TRAFFIC_DIRECTION = "trafficDirection"
	TRANSFER_STATE = "transferState"
	TRANSPORT = "transport"
	TRANSPORT_PROTOCOL = "transportProtocol"
	TRANSVERSE_GROUP_SEPARATION = "transverseGroupSeparation"
	TRANSVERSE_GROUP_SIZE = "transverseGroupSize"
	TRANSVERSE_OFFSET = "transverseOffset"
	TRAVERSAL = "traversal"
	TRAY = "tray"
	TRIG = "trig"
	TRIG_TIME = "trigTime"
	TRUE_HITS = "trueHits"
	TRUNCATE_OVERRUN = "truncateOverrun"
	TRUNCATE_OVERRUN_DELTA = "truncateOverrunDelta"
	TRUNCATE_OVERRUN_DELTA_AVG = "truncateOverrunDeltaAvg"
	TRUNCATE_OVERRUN_DELTA_MAX = "truncateOverrunDeltaMax"
	TRUNCATE_OVERRUN_DELTA_MIN = "truncateOverrunDeltaMin"
	TRUNCATE_OVERRUN_N0 = "truncateOverrunN0"
	TRUNCATE_OVERRUN_N0_DELTA = "truncateOverrunN0Delta"
	TRUNCATE_OVERRUN_N0_DELTA_AVG = "truncateOverrunN0DeltaAvg"
	TRUNCATE_OVERRUN_N0_DELTA_MAX = "truncateOverrunN0DeltaMax"
	TRUNCATE_OVERRUN_N0_DELTA_MIN = "truncateOverrunN0DeltaMin"
	TRUNCATE_OVERRUN_N1 = "truncateOverrunN1"
	TRUNCATE_OVERRUN_N1_DELTA = "truncateOverrunN1Delta"
	TRUNCATE_OVERRUN_N1_DELTA_AVG = "truncateOverrunN1DeltaAvg"
	TRUNCATE_OVERRUN_N1_DELTA_MAX = "truncateOverrunN1DeltaMax"
	TRUNCATE_OVERRUN_N1_DELTA_MIN = "truncateOverrunN1DeltaMin"
	TS = "ts"
	TX = "tx"
	TX_BAD_FRAMES = "txBadFrames"
	TX_BAD_FRAMES_DELTA = "txBadFramesDelta"
	TX_BAD_FRAMES_DELTA_AVG = "txBadFramesDeltaAvg"
	TX_BAD_FRAMES_DELTA_MAX = "txBadFramesDeltaMax"
	TX_BAD_FRAMES_DELTA_MIN = "txBadFramesDeltaMin"
	TX_BYTES = "txBytes"
	TX_BYTES_DELTA = "txBytesDelta"
	TX_BYTES_DELTA_AVG = "txBytesDeltaAvg"
	TX_BYTES_DELTA_MAX = "txBytesDeltaMax"
	TX_BYTES_DELTA_MIN = "txBytesDeltaMin"
	TX_DELTA = "txDelta"
	TX_DELTA_AVG = "txDeltaAvg"
	TX_DELTA_MAX = "txDeltaMax"
	TX_DELTA_MIN = "txDeltaMin"
	TX_DROPPED = "txDropped"
	TX_DROPPED_DELTA = "txDroppedDelta"
	TX_DROPPED_DELTA_AVG = "txDroppedDeltaAvg"
	TX_DROPPED_DELTA_MAX = "txDroppedDeltaMax"
	TX_DROPPED_DELTA_MIN = "txDroppedDeltaMin"
	TX_ERRORS = "txErrors"
	TX_ERRORS_DELTA = "txErrorsDelta"
	TX_ERRORS_DELTA_AVG = "txErrorsDeltaAvg"
	TX_ERRORS_DELTA_MAX = "txErrorsDeltaMax"
	TX_ERRORS_DELTA_MIN = "txErrorsDeltaMin"
	TX_FRAMES = "txFrames"
	TX_FRAMES_DELTA = "txFramesDelta"
	TX_FRAMES_DELTA_AVG = "txFramesDeltaAvg"
	TX_FRAMES_DELTA_MAX = "txFramesDeltaMax"
	TX_FRAMES_DELTA_MIN = "txFramesDeltaMin"
	TX_ID = "txId"
	TX_PACKETS = "txPackets"
	TX_PACKETS_DELTA = "txPacketsDelta"
	TX_PACKETS_DELTA_AVG = "txPacketsDeltaAvg"
	TX_PACKETS_DELTA_MAX = "txPacketsDeltaMax"
	TX_PACKETS_DELTA_MIN = "txPacketsDeltaMin"
	TX_PAUSE_CFC = "txPauseCFC"
	TX_PAUSE_CFCDELTA = "txPauseCFCDelta"
	TX_PAUSE_CFCDELTA_AVG = "txPauseCFCDeltaAvg"
	TX_PAUSE_CFCDELTA_MAX = "txPauseCFCDeltaMax"
	TX_PAUSE_CFCDELTA_MIN = "txPauseCFCDeltaMin"
	TX_PAUSE_PFC = "txPausePFC"
	TX_PAUSE_PFCDELTA = "txPausePFCDelta"
	TX_PAUSE_PFCDELTA_AVG = "txPausePFCDeltaAvg"
	TX_PAUSE_PFCDELTA_MAX = "txPausePFCDeltaMax"
	TX_PAUSE_PFCDELTA_MIN = "txPausePFCDeltaMin"
	TYPE = "type"
	UCSM_MO_DN = "ucsmMoDn"
	UCSM_VNET_EP_DN = "ucsmVnetEpDn"
	UDLD_ADMIN_STATE = "udldAdminState"
	UDLD_LINK_POLICY_NAME = "udldLinkPolicyName"
	UDLD_MODE = "udldMode"
	UDLD_MSG_INTERVAL = "udldMsgInterval"
	UDLD_OPER_STATE = "udldOperState"
	UDLD_RECOVERY_ACTION = "udldRecoveryAction"
	UI = "ui"
	UID = "uid"
	UMBILICAL_STATE = "umbilicalState"
	UNCORRECTABLE_ERRORS = "uncorrectableErrors"
	UNCORRECTABLE_ERRORS_DELTA = "uncorrectableErrorsDelta"
	UNCORRECTABLE_ERRORS_DELTA_AVG = "uncorrectableErrorsDeltaAvg"
	UNCORRECTABLE_ERRORS_DELTA_MAX = "uncorrectableErrorsDeltaMax"
	UNCORRECTABLE_ERRORS_DELTA_MIN = "uncorrectableErrorsDeltaMin"
	UNDER_SIZE = "underSize"
	UNDER_SIZE_DELTA = "underSizeDelta"
	UNDER_SIZE_DELTA_AVG = "underSizeDeltaAvg"
	UNDER_SIZE_DELTA_MAX = "underSizeDeltaMax"
	UNDER_SIZE_DELTA_MIN = "underSizeDeltaMin"
	UNDERSIZED_BAD_CRC_PACKETS = "undersizedBadCrcPackets"
	UNDERSIZED_BAD_CRC_PACKETS_DELTA = "undersizedBadCrcPacketsDelta"
	UNDERSIZED_BAD_CRC_PACKETS_DELTA_AVG = "undersizedBadCrcPacketsDeltaAvg"
	UNDERSIZED_BAD_CRC_PACKETS_DELTA_MAX = "undersizedBadCrcPacketsDeltaMax"
	UNDERSIZED_BAD_CRC_PACKETS_DELTA_MIN = "undersizedBadCrcPacketsDeltaMin"
	UNDERSIZED_GOOD_CRC_PACKETS = "undersizedGoodCrcPackets"
	UNDERSIZED_GOOD_CRC_PACKETS_DELTA = "undersizedGoodCrcPacketsDelta"
	UNDERSIZED_GOOD_CRC_PACKETS_DELTA_AVG = "undersizedGoodCrcPacketsDeltaAvg"
	UNDERSIZED_GOOD_CRC_PACKETS_DELTA_MAX = "undersizedGoodCrcPacketsDeltaMax"
	UNDERSIZED_GOOD_CRC_PACKETS_DELTA_MIN = "undersizedGoodCrcPacketsDeltaMin"
	UNEXPECTED_ERRORS = "unexpectedErrors"
	UNEXPECTED_ERRORS15_MIN = "unexpectedErrors15Min"
	UNEXPECTED_ERRORS15_MIN_H = "unexpectedErrors15MinH"
	UNEXPECTED_ERRORS1_DAY = "unexpectedErrors1Day"
	UNEXPECTED_ERRORS1_DAY_H = "unexpectedErrors1DayH"
	UNEXPECTED_ERRORS1_HOUR = "unexpectedErrors1Hour"
	UNEXPECTED_ERRORS1_HOUR_H = "unexpectedErrors1HourH"
	UNEXPECTED_ERRORS1_WEEK = "unexpectedErrors1Week"
	UNEXPECTED_ERRORS1_WEEK_H = "unexpectedErrors1WeekH"
	UNEXPECTED_ERRORS2_WEEKS = "unexpectedErrors2Weeks"
	UNEXPECTED_ERRORS2_WEEKS_H = "unexpectedErrors2WeeksH"
	UNICAST_PACKETS = "unicastPackets"
	UNICAST_PACKETS_DELTA = "unicastPacketsDelta"
	UNICAST_PACKETS_DELTA_AVG = "unicastPacketsDeltaAvg"
	UNICAST_PACKETS_DELTA_MAX = "unicastPacketsDeltaMax"
	UNICAST_PACKETS_DELTA_MIN = "unicastPacketsDeltaMin"
	UNIFIED_PORT = "unifiedPort"
	UNITS = "units"
	UNSUPPORTED_REQUEST_ERRORS = "unsupportedRequestErrors"
	UNSUPPORTED_REQUEST_ERRORS15_MIN = "unsupportedRequestErrors15Min"
	UNSUPPORTED_REQUEST_ERRORS15_MIN_H = "unsupportedRequestErrors15MinH"
	UNSUPPORTED_REQUEST_ERRORS1_DAY = "unsupportedRequestErrors1Day"
	UNSUPPORTED_REQUEST_ERRORS1_DAY_H = "unsupportedRequestErrors1DayH"
	UNSUPPORTED_REQUEST_ERRORS1_HOUR = "unsupportedRequestErrors1Hour"
	UNSUPPORTED_REQUEST_ERRORS1_HOUR_H = "unsupportedRequestErrors1HourH"
	UNSUPPORTED_REQUEST_ERRORS1_WEEK = "unsupportedRequestErrors1Week"
	UNSUPPORTED_REQUEST_ERRORS1_WEEK_H = "unsupportedRequestErrors1WeekH"
	UNSUPPORTED_REQUEST_ERRORS2_WEEKS = "unsupportedRequestErrors2Weeks"
	UNSUPPORTED_REQUEST_ERRORS2_WEEKS_H = "unsupportedRequestErrors2WeeksH"
	UPDATE = "update"
	UPDATE_METHOD = "updateMethod"
	UPDATE_TIME = "updateTime"
	UPDATE_TRIGGER = "updateTrigger"
	UPDATE_TS = "updateTs"
	UPDATE_TYPE = "updateType"
	UPGRADE_STATUS = "upgradeStatus"
	UPLINK_FAIL_ACTION = "uplinkFailAction"
	UPLINK_PORT_ID = "uplinkPortId"
	UPLINK_PORT_TYPE = "uplinkPortType"
	UPLINK_TRUNKING = "uplinkTrunking"
	UPTIME = "uptime"
	UPTIME_DISR = "uptimeDisr"
	URGENCY = "urgency"
	URI = "uri"
	USAGE = "usage"
	USE2_FACTOR = "use2Factor"
	USE_AES = "useAes"
	USE_PRIMARY_GROUP = "usePrimaryGroup"
	USED = "used"
	USED_QUANT = "usedQuant"
	USER = "user"
	USER_ID = "userId"
	USER_TYPE = "userType"
	USNIC_COUNT = "usnicCount"
	USR_LBL = "usrLbl"
	UUID = "uuid"
	UUID_SUFFIX = "uuidSuffix"
	V3_PRIVILEGE = "v3Privilege"
	V_STATUS = "vStatus"
	V_SWITCH_ID = "vSwitchId"
	V_SWITCH_NAME = "vSwitchName"
	VALIDATE_STATUS = "validateStatus"
	VALUE = "value"
	VAR_NAME = "varName"
	VAR_VALUE = "varValue"
	VC_DN = "vcDn"
	VCON_MAP = "vconMap"
	VCON_PROFILE_NAME = "vconProfileName"
	VENDOR = "vendor"
	VENDOR_DAEMON_PATH = "vendorDaemonPath"
	VENDOR_EQUIPMENT_TYPE = "vendorEquipmentType"
	VENDOR_ID = "vendorId"
	VENDOR_TYPE = "vendorType"
	VER = "ver"
	VER_RAW = "verRaw"
	VERSION = "version"
	VERSION_HOLDER = "versionHolder"
	VERSION_MISMATCH = "versionMismatch"
	VERTICAL_START_OFFSET = "verticalStartOffset"
	VID = "vid"
	VIF_CAPACITY = "vifCapacity"
	VIF_ID = "vifId"
	VIF_TYPE = "vifType"
	VIRTUAL_DRIVE_COUNT = "virtualDriveCount"
	VIRTUALIZATION_PREFERENCE = "virtualizationPreference"
	VISIBILITY = "visibility"
	VISIBLE = "visible"
	VLAN_COMP_OFF_LIMIT = "vlanCompOffLimit"
	VLAN_COMP_ON_LIMIT = "vlanCompOnLimit"
	VLAN_COMPRESSION = "vlanCompression"
	VLAN_FOR_BOOT = "vlanForBoot"
	VLAN_ID = "vlanId"
	VLAN_NAME = "vlanName"
	VLAN_PACKETS = "vlanPackets"
	VLAN_PACKETS_DELTA = "vlanPacketsDelta"
	VLAN_PACKETS_DELTA_AVG = "vlanPacketsDeltaAvg"
	VLAN_PACKETS_DELTA_MAX = "vlanPacketsDeltaMax"
	VLAN_PACKETS_DELTA_MIN = "vlanPacketsDeltaMin"
	VLAN_STATUS = "vlanStatus"
	VLAN_TYPE = "vlanType"
	VM_NETWORK_DEF_NAME = "vmNetworkDefName"
	VM_RETENTION = "vmRetention"
	VM_WARE = "vmWare"
	VMND_GUID = "vmndGuid"
	VMND_NAME = "vmndName"
	VMQ_COUNT = "vmqCount"
	VNET = "vnet"
	VNET_ID = "vnetId"
	VNIC = "vnic"
	VNIC_CONFIG_ISSUES = "vnicConfigIssues"
	VNIC_DEF_TYPE = "vnicDefType"
	VNIC_DN = "vnicDn"
	VNIC_MAP = "vnicMap"
	VNIC_NAME = "vnicName"
	VNIC_ORDER = "vnicOrder"
	VNIC_RETENTION = "vnicRetention"
	VNTAG = "vntag"
	VOLTAGE = "voltage"
	VOLTAGE_AVG = "voltageAvg"
	VOLTAGE_MAX = "voltageMax"
	VOLTAGE_MIN = "voltageMin"
	VP_ACPI10_SUPPORT = "vpACPI10Support"
	VP_ASSERT_NMION_PERR = "vpAssertNMIOnPERR"
	VP_ASSERT_NMION_SERR = "vpAssertNMIOnSERR"
	VP_BAUD_RATE = "vpBaudRate"
	VP_BOOT_OPTION_RETRY = "vpBootOptionRetry"
	VP_CPUPERFORMANCE = "vpCPUPerformance"
	VP_CONSOLE_REDIRECTION = "vpConsoleRedirection"
	VP_CORE_MULTI_PROCESSING = "vpCoreMultiProcessing"
	VP_DIRECT_CACHE_ACCESS = "vpDirectCacheAccess"
	VP_DRAM_REFRESH_RATE = "vpDramRefreshRate"
	VP_ENHANCED_INTEL_SPEED_STEP_TECH = "vpEnhancedIntelSpeedStepTech"
	VP_EXECUTE_DISABLE_BIT = "vpExecuteDisableBit"
	VP_FLOW_CONTROL = "vpFlowControl"
	VP_FRONT_PANEL_LOCKOUT = "vpFrontPanelLockout"
	VP_INTEL_HYPER_THREADING_TECH = "vpIntelHyperThreadingTech"
	VP_INTEL_TURBO_BOOST_TECH = "vpIntelTurboBoostTech"
	VP_INTEL_VTDATSSUPPORT = "vpIntelVTDATSSupport"
	VP_INTEL_VTDCOHERENCY_SUPPORT = "vpIntelVTDCoherencySupport"
	VP_INTEL_VTDINTERRUPT_REMAPPING = "vpIntelVTDInterruptRemapping"
	VP_INTEL_VTDPASS_THROUGH_DMASUPPORT = "vpIntelVTDPassThroughDMASupport"
	VP_INTEL_VTFOR_DIRECTED_IO = "vpIntelVTForDirectedIO"
	VP_INTEL_VIRTUALIZATION_TECHNOLOGY = "vpIntelVirtualizationTechnology"
	VP_LEGACY_OSREDIRECTION = "vpLegacyOSRedirection"
	VP_LEGACY_USBSUPPORT = "vpLegacyUSBSupport"
	VP_LOAD = "vpLoad"
	VP_LOCAL_X2_APIC = "vpLocalX2Apic"
	VP_LV_DDRMODE = "vpLvDDRMode"
	VP_MAKE_DEVICE_NON_BOOTABLE = "vpMakeDeviceNonBootable"
	VP_MAXIMUM_MEMORY_BELOW4_GB = "vpMaximumMemoryBelow4GB"
	VP_MEMORY_MAPPED_IOABOVE4_GB = "vpMemoryMappedIOAbove4GB"
	VP_MIRRORING_MODE = "vpMirroringMode"
	VP_NUMAOPTIMIZED = "vpNUMAOptimized"
	VP_OSBOOT_WATCHDOG_TIMER = "vpOSBootWatchdogTimer"
	VP_OSBOOT_WATCHDOG_TIMER_POLICY = "vpOSBootWatchdogTimerPolicy"
	VP_OSBOOT_WATCHDOG_TIMER_TIMEOUT = "vpOSBootWatchdogTimerTimeout"
	VP_ONBOARD_SATACONTROLLER = "vpOnboardSATAController"
	VP_ONBOARD_SCUSTORAGE_SUPPORT = "vpOnboardSCUStorageSupport"
	VP_POSTERROR_PAUSE = "vpPOSTErrorPause"
	VP_PACKAGE_CSTATE_LIMIT = "vpPackageCStateLimit"
	VP_PROCESSOR_C1_E = "vpProcessorC1E"
	VP_PROCESSOR_C3_REPORT = "vpProcessorC3Report"
	VP_PROCESSOR_C6_REPORT = "vpProcessorC6Report"
	VP_PROCESSOR_C7_REPORT = "vpProcessorC7Report"
	VP_PROCESSOR_CSTATE = "vpProcessorCState"
	VP_PROCESSOR_MTRR = "vpProcessorMtrr"
	VP_QUIET_BOOT = "vpQuietBoot"
	VP_RESUME_ON_ACPOWER_LOSS = "vpResumeOnACPowerLoss"
	VP_SASRAID = "vpSASRAID"
	VP_SASRAIDMODULE = "vpSASRAIDModule"
	VP_SATAMODE = "vpSATAMode"
	VP_SELECT_MEMORY_RASCONFIGURATION = "vpSelectMemoryRASConfiguration"
	VP_SERIAL_PORT_AENABLE = "vpSerialPortAEnable"
	VP_SLOT1_STATE = "vpSlot1State"
	VP_SLOT2_STATE = "vpSlot2State"
	VP_SLOT3_STATE = "vpSlot3State"
	VP_SLOT4_STATE = "vpSlot4State"
	VP_SLOT5_STATE = "vpSlot5State"
	VP_SLOT6_STATE = "vpSlot6State"
	VP_SLOT7_STATE = "vpSlot7State"
	VP_SLOT_MEZZ_STATE = "vpSlotMezzState"
	VP_SPARING_MODE = "vpSparingMode"
	VP_SRIOV = "vpSriov"
	VP_STATE = "vpState"
	VP_TERMINAL_TYPE = "vpTerminalType"
	VP_UCSMBOOT_ORDER_RULE = "vpUCSMBootOrderRule"
	VP_UEFIBOOT_MODE = "vpUEFIBootMode"
	VP_UEFIOSUSE_LEGACY_VIDEO = "vpUEFIOSUseLegacyVideo"
	VP_USBFRONT_PANEL_LOCK = "vpUSBFrontPanelLock"
	VP_USBIDLE_POWER_OPTIMIZING = "vpUSBIdlePowerOptimizing"
	VSAN_ID = "vsanId"
	WARNINGS = "warnings"
	WEIGHT = "weight"
	WIDTH = "width"
	WINDOW_DN = "windowDn"
	WORKING_DIRECTORY = "workingDirectory"
	WRITE_ENABLE = "writeEnable"
	WRITE_ERROR_THRESHOLD = "writeErrorThreshold"
	WRITE_IOERROR_COUNT = "writeIOErrorCount"
	WWN = "wwn"
	WWN_REVERSE_MASK_A = "wwnReverseMaskA"
	WWN_REVERSE_MASK_B = "wwnReverseMaskB"
	WWNN = "wwnn"
	WWNN_REVERSE_MASK_A = "wwnnReverseMaskA"
	WWNN_REVERSE_MASK_B = "wwnnReverseMaskB"
	WWPN = "wwpn"
	XCVR_TYPE = "xcvrType"
	XMIT = "xmit"
	XMIT_DELTA = "xmitDelta"
	XMIT_DELTA_AVG = "xmitDeltaAvg"
	XMIT_DELTA_MAX = "xmitDeltaMax"
	XMIT_DELTA_MIN = "xmitDeltaMin"
	XMIT_PAUSE = "xmitPause"
	XMIT_PAUSE_DELTA = "xmitPauseDelta"
	XMIT_PAUSE_DELTA_AVG = "xmitPauseDeltaAvg"
	XMIT_PAUSE_DELTA_MAX = "xmitPauseDeltaMax"
	XMIT_PAUSE_DELTA_MIN = "xmitPauseDeltaMin"
	ZONE_COUNT = "zoneCount"
	ZONING_STATE = "zoningState"
	ZONING_TYPE = "zoningType"

class Status:
	CREATED = "created"
	DELETED = "deleted"
	MODIFIED = "modified"
	REMOVED = "removed"

